window.Gleam.initSearch([{"doc":"chrobot","title":"chrobot","content":"&lt;p align=&quot;center&quot;&gt; \n&lt;img src=&quot;https://raw.githubusercontent.com/JonasGruenwald/chrobot/main/doc_assets/header_1.png&quot; alt=&quot;&quot; style=&quot;max-width: 450px; width: 100%;&quot;&gt;\n&lt;/p&gt;\n\n&lt;h1 align=&quot;center&quot;&gt;Chrobot&lt;/h1&gt;\n\n&lt;p align=&quot;center&quot;&gt;\n⛭ Typed browser automation for the BEAM ⛭\n&lt;/p&gt;\n&lt;p align=&quot;center&quot;&gt;\n&lt;a href=&quot;https://hex.pm/packages/chrobot&quot;&gt;\n  &lt;img src=&quot;https://img.shields.io/hexpm/v/chrobot&quot; alt=&quot;Package Version&quot;&gt;\n&lt;/a&gt;\n&lt;a href=&quot;https://hexdocs.pm/chrobot/&quot;&gt;\n  &lt;img src=&quot;https://img.shields.io/badge/hex-docs-ffaff3&quot; alt=&quot;Hex Docs&quot;&gt;\n&lt;/a&gt;\n&lt;img alt=&quot;Target: Erlang&quot; src=&quot;https://img.shields.io/badge/target-erlang-red?logo=erlang&quot;&gt;\n&lt;/p&gt;\n\n## About\n\nChrobot provides a set of typed bindings to the stable version of the [Chrome Devtools Protocol](https://chromedevtools.github.io/devtools-protocol/), based on its published JSON specification.\n\nThe typed interface is achieved by generating Gleam code for type definitions as well as encoder / decoder functions from the parsed JSON specification file.\n\nChrobot also exposes some handy high level abstractions for browser automation, and handles managing a browser instance via an Erlang Port and communicating with it for you.\n\nYou could use it for \n\n* Generating PDFs from HTML\n* Web scraping\n* Web archiving\n* Browser integration tests\n\n&gt; 🦝 The generated protocol bindings are largely untested and I would consider this package experimental, use at your own peril!\n\n## Setup\n\n### Package\n\nInstall as a Gleam package\n\n```sh\ngleam add chrobot\n```\n\nInstall as an Elixir dependency with mix\n\n```elixir\n# in your mix.exs\ndefp deps do\n  [\n    {:chrobot, &quot;~&gt; 2.2.3&quot;, app: false, manager: :rebar3}\n  ]\nend\n```\n\n### Browser\n\n#### System Installation\n\nChrobot can use an existing system installation of Google Chrome or Chromium, if you already have one.\n\n\n#### Browser Install Tool\n\nChrobot comes with a simple utility to install a version of [Google Chrome for Testing](https://github.com/GoogleChromeLabs/chrome-for-testing) directly inside your project.\nChrobot will automatically pick up this local installation when started via the `launch` command, and will prioritise it over a system installation of Google Chrome.\n\nYou can run the browser installer tool from gleam like so:\n\n```sh\ngleam run -m browser_install\n```\n\nOr when using Elixir with Mix:\n\n```sh\nmix run -e :browser_install.main\n```\n\nPlease [check the `install` docs for more information](https://hexdocs.pm/chrobot/browser_install.html) – this installation method will not work everywhere and comes with some caveats!\n\n#### GitHub Actions\n\nIf you want to use chrobot inside a Github Action, for example to run integration tests, \nyou can use the [setup-chrome](https://github.com/browser-actions/setup-chrome) action to get a Chrome installation, like so:\n\n```yml\n# -- snip --\n- uses: browser-actions/setup-chrome@v1\n  id: setup-chrome\n- run: gleam deps download\n- run: gleam test\n  env:\n    CHROBOT_BROWSER_PATH: ${{ steps.setup-chrome.outputs.chrome-path }}\n```\n\nIf you are using `launch` to start chrobot, it should pick up the Chrome executable from `CHROBOT_BROWSER_PATH`.\n\n## Examples\n\n### Take a screenshot of a website\n\n```gleam\nimport chrobot\n\npub fn main() {\n  // Open the browser and navigate to the gleam homepage\n  let assert Ok(browser) = chrobot.launch()\n  let assert Ok(page) =\n    browser\n    |&gt; chrobot.open(&quot;https://gleam.run&quot;, 30_000)\n  let assert Ok(_) = chrobot.await_selector(page, &quot;body&quot;)\n  \n  // Take a screenshot and save it as &#39;hi_lucy.png&#39;\n  let assert Ok(screenshot) = chrobot.screenshot(page)\n  let assert Ok(_) = chrobot.to_file(screenshot, &quot;hi_lucy&quot;)\n  let assert Ok(_) = chrobot.quit(browser)\n}\n```\n\n### Generate a PDF document with [lustre](http://lustre.build/)\n\n```gleam\nimport chrobot\nimport lustre/element.{text}\nimport lustre/element/html\n\nfn build_page() {\n  html.body([], [\n    html.h1([], [text(&quot;Spanakorizo&quot;)]),\n    html.h2([], [text(&quot;Ingredients&quot;)]),\n    html.ul([], [\n      html.li([], [text(&quot;1 onion&quot;)]),\n      html.li([], [text(&quot;1 clove(s) of garlic&quot;)]),\n      html.li([], [text(&quot;70 g olive oil&quot;)]),\n      html.li([], [text(&quot;salt&quot;)]),\n      html.li([], [text(&quot;pepper&quot;)]),\n      html.li([], [text(&quot;2 spring onions&quot;)]),\n      html.li([], [text(&quot;1/2 bunch dill&quot;)]),\n      html.li([], [text(&quot;250 g round grain rice&quot;)]),\n      html.li([], [text(&quot;150 g white wine&quot;)]),\n      html.li([], [text(&quot;1 liter vegetable stock&quot;)]),\n      html.li([], [text(&quot;1 kilo spinach&quot;)]),\n      html.li([], [text(&quot;lemon zest, of 2 lemons&quot;)]),\n      html.li([], [text(&quot;lemon juice, of 2 lemons&quot;)]),\n    ]),\n    html.h2([], [text(&quot;To serve&quot;)]),\n    html.ul([], [\n      html.li([], [text(&quot;1 lemon&quot;)]),\n      html.li([], [text(&quot;feta cheese&quot;)]),\n      html.li([], [text(&quot;olive oil&quot;)]),\n      html.li([], [text(&quot;pepper&quot;)]),\n      html.li([], [text(&quot;oregano&quot;)]),\n    ]),\n  ])\n  |&gt; element.to_document_string()\n}\n\npub fn main() {\n  let assert Ok(browser) = chrobot.launch()\n  let assert Ok(page) =\n    browser\n    |&gt; chrobot.create_page(build_page(), 10_000)\n\n  // Store as &#39;recipe.pdf&#39;\n  let assert Ok(doc) = chrobot.pdf(page)\n  let assert Ok(_) = chrobot.to_file(doc, &quot;recipe&quot;)\n  let assert Ok(_) = chrobot.quit(browser)\n}\n```\n\n### Scrape a Website\n\n&gt; 🍄‍🟫 **Just a quick reminder:**  \n&gt; Please be mindful of the load you are putting on other people&#39;s web services when you are scraping them programmatically!  \n\n\n```gleam\nimport chrobot\nimport gleam/io\nimport gleam/list\nimport gleam/result\n\npub fn main() {\n  let assert Ok(browser) = chrobot.launch()\n  let assert Ok(page) =\n    browser\n    |&gt; chrobot.open(&quot;https://books.toscrape.com/&quot;, 30_000)\n\n  let assert Ok(_) = chrobot.await_selector(page, &quot;body&quot;)\n  let assert Ok(page_items) = chrobot.select_all(page, &quot;.product_pod h3 a&quot;)\n  let assert Ok(title_results) =\n    list.map(page_items, fn(i) { chrobot.get_attribute(page, i, &quot;title&quot;) })\n    |&gt; result.all()\n  io.debug(title_results)\n  let assert Ok(_) = chrobot.quit(browser)\n}\n\n```\n\n### Write an Integration Test for a WebApp\n\n```gleam\nimport chrobot\nimport gleam/dynamic\nimport gleeunit/should\n\npub fn package_search_test() {\n  let assert Ok(browser) = chrobot.launch()\n  use &lt;- chrobot.defer_quit(browser)\n  let assert Ok(page) = chrobot.open(browser, &quot;https://hexdocs.pm/&quot;, 10_000)\n  let assert Ok(input_field) = chrobot.await_selector(page, &quot;input#search&quot;)\n  let assert Ok(Nil) = chrobot.focus(page, input_field)\n  let assert Ok(Nil) = chrobot.type_text(page, &quot;chrobot&quot;)\n  let assert Ok(Nil) = chrobot.press_key(page, &quot;Enter&quot;)\n  let assert Ok(result_link) = chrobot.await_selector(page, &quot;#search-results a&quot;)\n  let assert Ok(package_href) =\n    chrobot.get_property(page, result_link, &quot;href&quot;, dynamic.string)\n  package_href\n  |&gt; should.equal(&quot;https://hexdocs.pm/chrobot/&quot;)\n}\n```\n\n### Use from Elixir\n\n```elixir\n# ( output / logging removed for brevity )\niex(1)&gt; {:ok, browser} = :chrobot.launch()\niex(2)&gt; {:ok, page} = :chrobot.open(browser, &quot;https://example.com&quot;, 10_000)\niex(3)&gt; {:ok, object} = :chrobot.select(page, &quot;h1&quot;)\niex(4)&gt; {:ok,text} = :chrobot.get_text(page, object)\niex(5)&gt; text\n&quot;Example Domain&quot;\n```\n\n\n## Documentation &amp; Guide\n\nThe full documentation can be found at &lt;https://hexdocs.pm/chrobot&gt;.\n\n🗼 To learn about the high level abstractions, look at the [`chrobot` module documentation](https://hexdocs.pm/chrobot/chrobot.html).\n\n📠 To learn how to use the protocol bindings directly, look at the [`protocol` module documentation](https://hexdocs.pm/chrobot/protocol.html).\n\n","url":"index.html"},{"doc":"chrobot","title":"chrobot","content":"## [2.2.5] 2024-08-12\n\n- Upgrade to Gleam 1.4.1\n- Upgrade `simplifile` to 2.0.0\n\n## [2.2.4] 2024-06-22\n\n- Implement more accurate polling\n- Make `poll` function part of the public `chrobot` API\n\n## [2.2.3] 2024-06-08\n\n- Add `launch_window` function to launch browser in headful mode\n\n## [2.2.2] 2024-06-07\n\nThis update brings basic utilities for integration testing and some conveniences in the high level `chrobot` module\n\n- Add `click` and `focus` functions\n- Add `press_key`, `type_text`, and text input related functions\n\n## [2.1.2] 2024-05-29  \n\n- Improve message parsing performance A LOT 🚀\n  - This should have a big impact on the speed of generating PDFs and taking screenshots\n\n## [2.1.1] 2024-05-25\n\n- Rename the install module to browser_install \n\n## [2.1.0] 2024-05-25\n\n- Allow setting launch config through environment\n- Make logging prettier\n- Add browser installation script\n\n## [2.0.0] 2024-05-17\n\n- **Breaking Change:** Added `log_level` to `chrome.BrowserConfig`, this means any `launch_with_config` calls must \nbe amended with this extra parameter\n\n- Adjusted browser logging behaviour\n\n## [1.2.0] 2024-05-16\n\n- Move codegen scripts to `/test` to fix published package \n\n## [1.1.0] 2024-05-16\n\n- Remove unused `glexec` dependency\n- Trying to pass a dynamic value to an enocder now logs a warning \n\n## [1.0.0] 2024-05-16\n\nInitial release","url":"changelog.html"},{"doc":"chrome","title":"BrowserConfig","content":"pub type BrowserConfig {\n  BrowserConfig(\n    path: String,\n    args: List(String),\n    start_timeout: Int,\n    log_level: LogLevel,\n  )\n}\n\nBrowserConfig(\n  path: String,\n  args: List(String),\n  start_timeout: Int,\n  log_level: LogLevel,\n)\n\n\nSynonyms:\nchrome.BrowserConfig\nchrome BrowserConfig","url":"chrome.html#BrowserConfig"},{"doc":"chrome","title":"BrowserInstance","content":"pub type BrowserInstance {\n  BrowserInstance(port: Port)\n}\n\nBrowserInstance(port: Port)\n\n\nSynonyms:\nchrome.BrowserInstance\nchrome BrowserInstance","url":"chrome.html#BrowserInstance"},{"doc":"chrome","title":"BrowserVersion","content":"pub type BrowserVersion {\n  BrowserVersion(\n    protocol_version: String,\n    product: String,\n    revision: String,\n    user_agent: String,\n    js_version: String,\n  )\n}\n\nBrowserVersion(\n  protocol_version: String,\n  product: String,\n  revision: String,\n  user_agent: String,\n  js_version: String,\n)\n\n\nSynonyms:\nchrome.BrowserVersion\nchrome BrowserVersion","url":"chrome.html#BrowserVersion"},{"doc":"chrome","title":"LaunchError","content":"pub type LaunchError {\n  UnknowOperatingSystem\n  CouldNotFindExecutable\n  FailedToStart\n  UnresponsiveAfterStart\n  ProtocolVersionMismatch(\n    supported_version: String,\n    got_version: String,\n  )\n}\n Errors that may occur during launch of the browser instance\nUnknowOperatingSystem\n\n\nCouldNotFindExecutable\n\n\nFailedToStart\n\n\nUnresponsiveAfterStart\n This is used by the launch functions of the root `chrobot` module\n\nProtocolVersionMismatch(\n  supported_version: String,\n  got_version: String,\n)\n\nsupported_version\n&lt;p&gt;Version supported by the protocol&lt;/p&gt;\n\ngot_version\n&lt;p&gt;Version the browser reported&lt;/p&gt;\n\nSynonyms:\nchrome.LaunchError\nchrome LaunchError","url":"chrome.html#LaunchError"},{"doc":"chrome","title":"LogLevel","content":"pub type LogLevel {\n  LogLevelSilent\n  LogLevelWarnings\n  LogLevelInfo\n  LogLevelDebug\n}\n The log level the browser is using.  \nLogLevelSilent\n Log nothing\n\nLogLevelWarnings\n Log only warnings, this is the default\n\nLogLevelInfo\n Log normal but uncommon events, like buffering a long message, shutdown\n\nLogLevelDebug\n Log everything, including protocol payloads\n\nSynonyms:\nchrome.LogLevel\nchrome LogLevel","url":"chrome.html#LogLevel"},{"doc":"chrome","title":"Message","content":"pub type Message {\n  Shutdown(reply_with: Subject(Nil))\n  Kill\n  Call(\n    reply_with: Subject(Result(d.Dynamic, RequestError)),\n    method: String,\n    params: Option(Json),\n    session_id: Option(String),\n  )\n  Send(method: String, params: Option(Json))\n  AddListener(listener: Subject(d.Dynamic), method: String)\n  RemoveListener(listener: Subject(d.Dynamic))\n  UnexpectedPortMessage(d.Dynamic)\n  PortResponse(String)\n  SetLogLevel(LogLevel)\n  PortExit(Int)\n}\n\nShutdown(reply_with: Subject(Nil))\n Initiate graceful shutdown of the browser\n\nKill\n Kill by shutting down actor\n\nCall(\n  reply_with: Subject(Result(d.Dynamic, RequestError)),\n  method: String,\n  params: Option(Json),\n  session_id: Option(String),\n)\n Make a protocol call and receive response\n\nSend(method: String, params: Option(Json))\n Make a protocol call and ignore response\n\nAddListener(listener: Subject(d.Dynamic), method: String)\n\n\nRemoveListener(listener: Subject(d.Dynamic))\n\n\nUnexpectedPortMessage(d.Dynamic)\n (From Port) Message that could not be matched\n\nPortResponse(String)\n (From Port) Protocol Message\n\nSetLogLevel(LogLevel)\n Allows you to set the log level of the running instance\n\nPortExit(Int)\n (From Port) Port has exited\n\nSynonyms:\nchrome.Message\nchrome Message","url":"chrome.html#Message"},{"doc":"chrome","title":"RequestError","content":"pub type RequestError {\n  PortError\n  ChromeAgentTimeout\n  ChromeAgentDown\n  ProtocolError\n  BrowserError(code: Int, message: String, data: String)\n  NotFoundError\n  RuntimeException(text: String, line: Int, column: Int)\n}\n Errors that may occur when a protocol request is made\nPortError\n\n\nChromeAgentTimeout\n OTP actor timeout\n\nChromeAgentDown\n OTP actor down\n\nProtocolError\n The ProtocolError variant is used by `/protocol` domains \n to return a homogeneous error type for all requests.\n\nBrowserError(code: Int, message: String, data: String)\n This is an error response from the browser itself\n\nNotFoundError\n A requested resource could not be found\n\nRuntimeException(text: String, line: Int, column: Int)\n A runtime exception thrown by JavaScript code being evaluated in the browser\n\nSynonyms:\nchrome.RequestError\nchrome RequestError","url":"chrome.html#RequestError"},{"doc":"chrome","title":"default_timeout","content":"pub const default_timeout: Int\n\nSynonyms:\nchrome.default_timeout\nchrome default_timeout","url":"chrome.html#default_timeout"},{"doc":"chrome","title":"add_listener","content":"pub fn add_listener(\n  browser: Subject(Message),\n  method: String,\n) -&gt; Subject(Dynamic)\n Add an event listener\n (Experimental! Event forwarding is not really supported yet)\nSynonyms:\nchrome.add_listener\nchrome add_listener","url":"chrome.html#add_listener"},{"doc":"chrome","title":"call","content":"pub fn call(\n  browser: Subject(Message),\n  method: String,\n  params: Option(Json),\n  session_id: Option(String),\n  time_out: Int,\n) -&gt; Result(Dynamic, RequestError)\n Issue a protocol call to the browser and expect a response\nSynonyms:\nchrome.call\nchrome call","url":"chrome.html#call"},{"doc":"chrome","title":"get_default_chrome_args","content":"pub fn get_default_chrome_args() -&gt; List(String)\n Get the default arguments the browser should be started with,\n to be used inside the `launch_with_config` function\nSynonyms:\nchrome.get_default_chrome_args\nchrome get_default_chrome_args","url":"chrome.html#get_default_chrome_args"},{"doc":"chrome","title":"get_local_chrome_path","content":"pub fn get_local_chrome_path() -&gt; Result(String, LaunchError)\n Try to find a hermetic chrome installation in the current directory,\n of the kind installed by `browser_install` or the puppeteer install script.\n The installation must be in a directory called `chrome`.\nSynonyms:\nchrome.get_local_chrome_path\nchrome get_local_chrome_path","url":"chrome.html#get_local_chrome_path"},{"doc":"chrome","title":"get_system_chrome_path","content":"pub fn get_system_chrome_path() -&gt; Result(String, LaunchError)\n Try to find a system chrome installation in some obvious places.\nSynonyms:\nchrome.get_system_chrome_path\nchrome get_system_chrome_path","url":"chrome.html#get_system_chrome_path"},{"doc":"chrome","title":"get_version","content":"pub fn get_version(\n  browser: Subject(Message),\n) -&gt; Result(BrowserVersion, RequestError)\n Hardcoded protocol call to get the browser version\n See: https://chromedevtools.github.io/devtools-protocol/tot/Browser/#method-getVersion \nSynonyms:\nchrome.get_version\nchrome get_version","url":"chrome.html#get_version"},{"doc":"chrome","title":"is_local_chrome_path","content":"pub fn is_local_chrome_path(\n  relative_path: String,\n  os_family: OsFamily,\n) -&gt; Bool\n Returns whether the given path is a local chrome installation, of the kind\n created by `browser_install` or the puppeteer install script.\n This can be used to scan a directory with `simplifile.get_files`.\nSynonyms:\nchrome.is_local_chrome_path\nchrome is_local_chrome_path","url":"chrome.html#is_local_chrome_path"},{"doc":"chrome","title":"launch","content":"pub fn launch() -&gt; Result(Subject(Message), LaunchError)\n Cleverly try to find a chrome installation and launch it with reasonable defaults.\n \n 1. If `CHROBOT_BROWSER_PATH` is set, use that\n 2. If a local chrome installation is found, use that\n 3. If a system chrome installation is found, use that\n 4. If none of the above, return an error\n \n If you want to always use a specific chrome installation, take a look at `launch_with_config` or \n `launch_with_env` to set the path explicitly.\n  \n Be aware that this function will not validate that the browser launched successfully,\n please use the higher level functions from the root chrobot module instead if you want these guarantees.\nSynonyms:\nchrome.launch\nchrome launch","url":"chrome.html#launch"},{"doc":"chrome","title":"launch_window","content":"pub fn launch_window() -&gt; Result(Subject(Message), LaunchError)\n Like [`launch`](#launch), but launches the browser with a visible window, not\n in headless mode, which is useful for debugging and development.  \nSynonyms:\nchrome.launch_window\nchrome launch_window","url":"chrome.html#launch_window"},{"doc":"chrome","title":"launch_with_config","content":"pub fn launch_with_config(\n  cfg: BrowserConfig,\n) -&gt; Result(Subject(Message), LaunchError)\n Launch a browser with the given configuration,\n to populate the arguments, use `get_default_chrome_args`.\n \n Be aware that this function will not validate that the browser launched successfully,\n please use the higher level functions from the root chrobot module instead if you want these guarantees.\n \n ## Example\n \n let config =\n BrowserConfig(\n   path: &quot;chrome/linux-116.0.5793.0/chrome-linux64/chrome&quot;,\n   args: get_default_chrome_args(),\n   start_timeout: 5000,\n )\n let assert Ok(browser_subject) = launch_with_config(config)\n \nSynonyms:\nchrome.launch_with_config\nchrome launch_with_config","url":"chrome.html#launch_with_config"},{"doc":"chrome","title":"launch_with_env","content":"pub fn launch_with_env() -&gt; Result(Subject(Message), LaunchError)\n Launch a browser, and read the configuration from environment variables.\n The browser path variable must be set, all others will fall back to a default.\n \n Be aware that this function will not validate that the browser launched successfully,\n please use the higher level functions from the root chrobot module instead if you want these guarantees.\n \n Configuration variables:\n - `CHROBOT_BROWSER_PATH` - The path to the browser executable\n - `CHROBOT_BROWSER_ARGS` - The arguments to pass to the browser, separated by spaces\n - `CHROBOT_BROWSER_TIMEOUT` - The timeout in milliseconds to wait for the browser to start, must be an integer\n - `CHROBOT_LOG_LEVEL` - The log level to use, one of `silent`, `warnings`, `info`, `debug`\nSynonyms:\nchrome.launch_with_env\nchrome launch_with_env","url":"chrome.html#launch_with_env"},{"doc":"chrome","title":"listen_once","content":"pub fn listen_once(\n  browser: Subject(Message),\n  method: String,\n  time_out: Int,\n) -&gt; Result(Dynamic, RequestError)\n A blocking call that waits for a specified event to arrive once,\n and then resolves, removing the event listener.\nSynonyms:\nchrome.listen_once\nchrome listen_once","url":"chrome.html#listen_once"},{"doc":"chrome","title":"quit","content":"pub fn quit(\n  browser: Subject(Message),\n) -&gt; Result(Nil, CallError(Nil))\n Quit the browser and shut down the actor.  \n This function will attempt graceful shutdown, if the browser does not respond in time,\n it will also send a kill signal to the actor to force it to shut down.\n The result typing reflects the success of graceful shutdown.\nSynonyms:\nchrome.quit\nchrome quit","url":"chrome.html#quit"},{"doc":"chrome","title":"remove_listener","content":"pub fn remove_listener(\n  browser: Subject(Message),\n  listener: Subject(Dynamic),\n) -&gt; Nil\n Remove an event listener\n (Experimental! Event forwarding is not really supported yet)\nSynonyms:\nchrome.remove_listener\nchrome remove_listener","url":"chrome.html#remove_listener"},{"doc":"chrome","title":"send","content":"pub fn send(\n  browser: Subject(Message),\n  method: String,\n  params: Option(Json),\n) -&gt; Nil\n Issue a protocol call to the browser without waiting for a response,\n when the response arrives, it will be discarded.\n It&#39;s probably best to not use this and instead just use `call` and discard unneeded responses.\n All protocol calls yield a response and can be used with `call`, even if they\n don&#39;t specify any response parameters.\nSynonyms:\nchrome.send\nchrome send","url":"chrome.html#send"},{"doc":"chrome","title":"set_log_level","content":"pub fn set_log_level(\n  browser: Subject(Message),\n  level: LogLevel,\n) -&gt; Nil\n Allows you to set the log level of a running browser instance\nSynonyms:\nchrome.set_log_level\nchrome set_log_level","url":"chrome.html#set_log_level"},{"doc":"chrome","title":"chrome","content":" An actor that manages an instance of the chrome browser via an erlang port.\n The browser is started to allow remote debugging via pipes, once the pipe is disconnected,\n chrome should quit automatically.\n \n All messages to the browser are sent through this actor to the port, and responses are returned to the sender.\n The actor manages associating responses with the correct request by adding auto-incrementing ids to the requests,\n so callers don&#39;t need to worry about this.\n \n When the browser managed by this actor is closed, the actor will also exit.\n \n To start a browser, it&#39;s preferrable to use the launch functions from the root chrobot module,\n which perform additional checks and validations.\n ","url":"chrome.html"},{"doc":"browser_install","title":"InstallationError","content":"pub type InstallationError {\n  InstallationError\n}\n\nInstallationError\n\n\nSynonyms:\nbrowser_install.InstallationError\nbrowser_install InstallationError","url":"browser_install.html#InstallationError"},{"doc":"browser_install","title":"install","content":"pub fn install() -&gt; Result(String, InstallationError)\n Install a local version of Google Chrome for Testing.\n This function is meant to be called in a script, it will log errors and warnings to the console.\n and return a generic error if installation fails.\nSynonyms:\nbrowser_install.install\nbrowser_install install","url":"browser_install.html#install"},{"doc":"browser_install","title":"install_with_config","content":"pub fn install_with_config(\n  to target_path: String,\n  version target_version: String,\n) -&gt; Result(String, InstallationError)\n Install a specific local version of Google Chrome for Testing to a specific directory.\n This function is meant to be called in a script, it will log errors and warnings to the console.\n and return a generic error if installation fails.\nSynonyms:\nbrowser_install.install_with_config\nbrowser_install install_with_config","url":"browser_install.html#install_with_config"},{"doc":"browser_install","title":"main","content":"pub fn main() -&gt; Result(String, InstallationError)\n\nSynonyms:\nbrowser_install.main\nbrowser_install main","url":"browser_install.html#main"},{"doc":"browser_install","title":"browser_install","content":" This module provides basic browser installation functionality, allowing you\n to install a local version of [Google Chrome for Testing](https://github.com/GoogleChromeLabs/chrome-for-testing) in the current directory on macOS and Linux.\n \n ## Usage\n  \n You may run browser installation directly with \n \n ```sh\n gleam run -m browser_install\n ```\n When running directly, you can configure the browser version to install by setting the `CHROBOT_TARGET_VERSION` environment variable,\n it will default to `latest`. \n You may also set the directory to install under, with `CHROBOT_TARGET_PATH`.\n \n The browser will be installed into a directory called `chrome` under the target directory.\n There is no support for managing multiple browser installations, if an installation is already present for the same version,\n the script will overwrite it.\n \n To uninstall browsers installed by this tool just remove the `chrome` directory created by it, or delete an individual browser\n installation from inside it.\n \n ## Caveats\n \n This module attempts to rudimentarily mimic the functionality of the [puppeteer install script](https://pptr.dev/browsers-api),\n the only goal is to have a quick and convenient way to install browsers locally, for more advanced management of browser\n installations, please seek out other tools.\n \n Supported platforms are limited by what the Google Chrome for Testing distribution supports, which is currently:\n \n * linux64\n * mac-arm64\n * mac-x64\n * win32\n * win64\n \n Notably, this distribution **unfortunately does not support ARM64 on Linux**.\n \n ### Linux Dependencies\n \n The tool does **not** install dependencies on Linux, you must install them yourself.\n \n On debian / ubuntu based systems you may install dependencies with the following command:\n \n ```sh\n sudo apt-get update &amp;&amp; sudo apt-get install -y \\\n ca-certificates \\\n fonts-liberation \\\n libasound2 \\\n libatk-bridge2.0-0 \\\n libatk1.0-0 \\\n libc6 \\\n libcairo2 \\\n libcups2 \\\n libdbus-1-3 \\\n libexpat1 \\\n libfontconfig1 \\\n libgbm1 \\\n libgcc1 \\\n libglib2.0-0 \\\n libgtk-3-0 \\\n libnspr4 \\\n libnss3 \\\n libpango-1.0-0 \\\n libpangocairo-1.0-0 \\\n libstdc++6 \\\n libx11-6 \\\n libx11-xcb1 \\\n libxcb1 \\\n libxcomposite1 \\\n libxcursor1 \\\n libxdamage1 \\\n libxext6 \\\n libxfixes3 \\\n libxi6 \\\n libxrandr2 \\\n libxrender1 \\\n libxss1 \\\n libxtst6 \\\n lsb-release \\\n wget \\\n xdg-utils\n ```","url":"browser_install.html"},{"doc":"protocol","title":"version","content":"pub fn version() -&gt; #(String, String)\n Get the protocol version as a tuple of major and minor version\nSynonyms:\nprotocol.version\nprotocol version","url":"protocol.html#version"},{"doc":"protocol","title":"protocol","content":" &gt; ⚙️  This module was generated from the Chrome DevTools Protocol version **1.3**\n For reference: [See the DevTools Protocol API Docs](https://chromedevtools.github.io/devtools-protocol/1-3/)\n \n This is the protocol definition entrypoint, it contains an overview of the protocol structure,\n and a function to retrieve the version of the protocol used to generate the current bindings.  \n The protocol version is also displayed in the box above, which appears on every generated module.  \n \n ## ⚠️ Really Important Notes\n    \n 1) It&#39;s best never to work with the DOM domain for automation, \n [an explanation of why can be found here](https://github.com/puppeteer/puppeteer/pull/71#issuecomment-314599749).  \n Instead, to automate DOM interaction, JavaScript can be injected using the Runtime domain.\n   \n 2) Unfortunately, I haven&#39;t found a good way to map dynamic properties to gleam attributes bidirectionally.  \n **This means all dynamic values you supply to commands will be silently dropped**!  \n It&#39;s important to realize this to avoid confusion, for example in `runtime.call_function_on` \n you may want to supply arguments which can be any value, but it won&#39;t work.  \n The only path to do that as far as I can tell, is write the protocol call logic yourself,\n perhaps taking the codegen code as a basis.  \n Check the `call_custom_function_on` function from `chrobot` which does this for the mentioned function\n \n ## Structure\n \n Each domain in the protocol is represented as a module under `protocol/`. \n \n In general, the bindings are generated through codegen, directly from the JSON protocol schema [published here](https://github.com/ChromeDevTools/devtools-protocol), \n however there are some little adjustments that needed to be made, to make the protocol schema usable, mainly due to\n what I believe are minor bugs in the protocol.  \n To see these changes, check the `apply_protocol_patches` function in `chrobot/internal/generate_bindings`.\n \n Domains may depend on the types of other domains, these dependencies are mirrored in the generated bindings where possible.\n In some case, type references to other modules have been replaced by the respective inner type, because the references would\n create a circular dependency.\n \n ## Types \n \n The generated bindings include a mirror of the type defitions of each type in the protocol spec,\n alongside with an `encode__` function to encode the type into JSON in order to send it to the browser\n and a `decode__` function in order to decode the type out of a payload sent from the browser. Encoders and\n decoders are marked internal and should be used through command functions which are described below.\n \n Notes:  \n - Some object properties in the protocol have the type `any`, in this case the value is considered as dynamic\n by decoders, and encoders will not encode it, setting it to `null` instead in the payload\n - Object types that don&#39;t specify any properties are treated as a `Dict(String,String)` \n \n Additional type definitions and encoders / decoders are generated, \n for any enumerable property in the protocol, as well as the return values of commands.  \n These special type definitions are marked with a comment to indicate \n the fact that they are not part of the protocol spec, but rather generated dynamically to support the bindings.\n \n \n ## Commands\n \n A function is generated for each command, named after the command (in snake case).  \n The function handles both encoding the parameters to sent to the browser via the protocol, and decoding the response.\n A `ProtocolError` error is returned if the decoding fails, this would mean there is a bug in the protocol\n or the generated bindings.\n \n The first parameter to the command function is always a `callback` of the form\n \n ```gleam\n fn(method: String, parameters: Option(Json)) -&gt; Result(Dynamic, RequestError)\n ```\n \n By using this callback you can take advantage of the generated protocol encoders/decoders \n while also passing in your browser subject to direct the command to, and passing along additional\n arguments, like the `sessionId` which is required for some operations.\n \n \n ## Events\n \n Events are not implemented yet!\n \n \n ","url":"protocol.html"},{"doc":"protocol/input","title":"DispatchKeyEventType","content":"pub type DispatchKeyEventType {\n  DispatchKeyEventTypeKeyDown\n  DispatchKeyEventTypeKeyUp\n  DispatchKeyEventTypeRawKeyDown\n  DispatchKeyEventTypeChar\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `type` of `dispatchKeyEvent`\nDispatchKeyEventTypeKeyDown\n\n\nDispatchKeyEventTypeKeyUp\n\n\nDispatchKeyEventTypeRawKeyDown\n\n\nDispatchKeyEventTypeChar\n\n\nSynonyms:\nprotocol/input.DispatchKeyEventType\nprotocol/input DispatchKeyEventType","url":"protocol/input.html#DispatchKeyEventType"},{"doc":"protocol/input","title":"DispatchMouseEventPointerType","content":"pub type DispatchMouseEventPointerType {\n  DispatchMouseEventPointerTypeMouse\n  DispatchMouseEventPointerTypePen\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `pointerType` of `dispatchMouseEvent`\nDispatchMouseEventPointerTypeMouse\n\n\nDispatchMouseEventPointerTypePen\n\n\nSynonyms:\nprotocol/input.DispatchMouseEventPointerType\nprotocol/input DispatchMouseEventPointerType","url":"protocol/input.html#DispatchMouseEventPointerType"},{"doc":"protocol/input","title":"DispatchMouseEventType","content":"pub type DispatchMouseEventType {\n  DispatchMouseEventTypeMousePressed\n  DispatchMouseEventTypeMouseReleased\n  DispatchMouseEventTypeMouseMoved\n  DispatchMouseEventTypeMouseWheel\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `type` of `dispatchMouseEvent`\nDispatchMouseEventTypeMousePressed\n\n\nDispatchMouseEventTypeMouseReleased\n\n\nDispatchMouseEventTypeMouseMoved\n\n\nDispatchMouseEventTypeMouseWheel\n\n\nSynonyms:\nprotocol/input.DispatchMouseEventType\nprotocol/input DispatchMouseEventType","url":"protocol/input.html#DispatchMouseEventType"},{"doc":"protocol/input","title":"DispatchTouchEventType","content":"pub type DispatchTouchEventType {\n  DispatchTouchEventTypeTouchStart\n  DispatchTouchEventTypeTouchEnd\n  DispatchTouchEventTypeTouchMove\n  DispatchTouchEventTypeTouchCancel\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `type` of `dispatchTouchEvent`\nDispatchTouchEventTypeTouchStart\n\n\nDispatchTouchEventTypeTouchEnd\n\n\nDispatchTouchEventTypeTouchMove\n\n\nDispatchTouchEventTypeTouchCancel\n\n\nSynonyms:\nprotocol/input.DispatchTouchEventType\nprotocol/input DispatchTouchEventType","url":"protocol/input.html#DispatchTouchEventType"},{"doc":"protocol/input","title":"MouseButton","content":"pub type MouseButton {\n  MouseButtonNone\n  MouseButtonLeft\n  MouseButtonMiddle\n  MouseButtonRight\n  MouseButtonBack\n  MouseButtonForward\n}\n\nMouseButtonNone\n\n\nMouseButtonLeft\n\n\nMouseButtonMiddle\n\n\nMouseButtonRight\n\n\nMouseButtonBack\n\n\nMouseButtonForward\n\n\nSynonyms:\nprotocol/input.MouseButton\nprotocol/input MouseButton","url":"protocol/input.html#MouseButton"},{"doc":"protocol/input","title":"TimeSinceEpoch","content":"pub type TimeSinceEpoch {\n  TimeSinceEpoch(Float)\n}\n UTC time in seconds, counted from January 1, 1970.\nTimeSinceEpoch(Float)\n\n\nSynonyms:\nprotocol/input.TimeSinceEpoch\nprotocol/input TimeSinceEpoch","url":"protocol/input.html#TimeSinceEpoch"},{"doc":"protocol/input","title":"TouchPoint","content":"pub type TouchPoint {\n  TouchPoint(\n    x: Float,\n    y: Float,\n    radius_x: option.Option(Float),\n    radius_y: option.Option(Float),\n    rotation_angle: option.Option(Float),\n    force: option.Option(Float),\n    tilt_x: option.Option(Float),\n    tilt_y: option.Option(Float),\n    id: option.Option(Float),\n  )\n}\n\nTouchPoint(\n  x: Float,\n  y: Float,\n  radius_x: option.Option(Float),\n  radius_y: option.Option(Float),\n  rotation_angle: option.Option(Float),\n  force: option.Option(Float),\n  tilt_x: option.Option(Float),\n  tilt_y: option.Option(Float),\n  id: option.Option(Float),\n)\n\nx\n&lt;p&gt;X coordinate of the event relative to the main frame’s viewport in CSS pixels.&lt;/p&gt;\n\ny\n&lt;p&gt;Y coordinate of the event relative to the main frame’s viewport in CSS pixels. 0 refers to\nthe top of the viewport and Y increases as it proceeds towards the bottom of the viewport.&lt;/p&gt;\n\nradius_x\n&lt;p&gt;X radius of the touch area (default: 1.0).&lt;/p&gt;\n\nradius_y\n&lt;p&gt;Y radius of the touch area (default: 1.0).&lt;/p&gt;\n\nrotation_angle\n&lt;p&gt;Rotation angle (default: 0.0).&lt;/p&gt;\n\nforce\n&lt;p&gt;Force (default: 1.0).&lt;/p&gt;\n\ntilt_x\n&lt;p&gt;The plane angle between the Y-Z plane and the plane containing both the stylus axis and the Y axis, in degrees of the range [-90,90], a positive tiltX is to the right (default: 0)&lt;/p&gt;\n\ntilt_y\n&lt;p&gt;The plane angle between the X-Z plane and the plane containing both the stylus axis and the X axis, in degrees of the range [-90,90], a positive tiltY is towards the user (default: 0).&lt;/p&gt;\n\nid\n&lt;p&gt;Identifier used to track touch sources between events, must be unique within an event.&lt;/p&gt;\n\nSynonyms:\nprotocol/input.TouchPoint\nprotocol/input TouchPoint","url":"protocol/input.html#TouchPoint"},{"doc":"protocol/input","title":"cancel_dragging","content":"pub fn cancel_dragging(\n  callback__: fn(String, Option(a)) -&gt; b,\n) -&gt; b\n Cancels any active dragging in the page.\n \nSynonyms:\nprotocol/input.cancel_dragging\nprotocol/input cancel_dragging","url":"protocol/input.html#cancel_dragging"},{"doc":"protocol/input","title":"dispatch_key_event","content":"pub fn dispatch_key_event(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  type_ type_: DispatchKeyEventType,\n  modifiers modifiers: Option(Int),\n  timestamp timestamp: Option(TimeSinceEpoch),\n  text text: Option(String),\n  unmodified_text unmodified_text: Option(String),\n  key_identifier key_identifier: Option(String),\n  code code: Option(String),\n  key key: Option(String),\n  windows_virtual_key_code windows_virtual_key_code: Option(Int),\n  native_virtual_key_code native_virtual_key_code: Option(Int),\n  auto_repeat auto_repeat: Option(Bool),\n  is_keypad is_keypad: Option(Bool),\n  is_system_key is_system_key: Option(Bool),\n  location location: Option(Int),\n) -&gt; a\n Dispatches a key event to the page.\n \n Parameters:  \n  - `type_` : Type of the key event.\n  - `modifiers` : Bit field representing pressed modifier keys. Alt=1, Ctrl=2, Meta/Command=4, Shift=8\n (default: 0).\n  - `timestamp` : Time at which the event occurred.\n  - `text` : Text as generated by processing a virtual key code with a keyboard layout. Not needed for\n for `keyUp` and `rawKeyDown` events (default: &quot;&quot;)\n  - `unmodified_text` : Text that would have been generated by the keyboard if no modifiers were pressed (except for\n shift). Useful for shortcut (accelerator) key handling (default: &quot;&quot;).\n  - `key_identifier` : Unique key identifier (e.g., &#39;U+0041&#39;) (default: &quot;&quot;).\n  - `code` : Unique DOM defined string value for each physical key (e.g., &#39;KeyA&#39;) (default: &quot;&quot;).\n  - `key` : Unique DOM defined string value describing the meaning of the key in the context of active\n modifiers, keyboard layout, etc (e.g., &#39;AltGr&#39;) (default: &quot;&quot;).\n  - `windows_virtual_key_code` : Windows virtual key code (default: 0).\n  - `native_virtual_key_code` : Native virtual key code (default: 0).\n  - `auto_repeat` : Whether the event was generated from auto repeat (default: false).\n  - `is_keypad` : Whether the event was generated from the keypad (default: false).\n  - `is_system_key` : Whether the event was a system key event (default: false).\n  - `location` : Whether the event was from the left or right side of the keyboard. 1=Left, 2=Right (default:\n 0).\n \n Returns:  \n \nSynonyms:\nprotocol/input.dispatch_key_event\nprotocol/input dispatch_key_event","url":"protocol/input.html#dispatch_key_event"},{"doc":"protocol/input","title":"dispatch_mouse_event","content":"pub fn dispatch_mouse_event(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  type_ type_: DispatchMouseEventType,\n  x x: Float,\n  y y: Float,\n  modifiers modifiers: Option(Int),\n  timestamp timestamp: Option(TimeSinceEpoch),\n  button button: Option(MouseButton),\n  buttons buttons: Option(Int),\n  click_count click_count: Option(Int),\n  tilt_x tilt_x: Option(Float),\n  tilt_y tilt_y: Option(Float),\n  delta_x delta_x: Option(Float),\n  delta_y delta_y: Option(Float),\n  pointer_type pointer_type: Option(DispatchMouseEventPointerType),\n) -&gt; a\n Dispatches a mouse event to the page.\n \n Parameters:  \n  - `type_` : Type of the mouse event.\n  - `x` : X coordinate of the event relative to the main frame&#39;s viewport in CSS pixels.\n  - `y` : Y coordinate of the event relative to the main frame&#39;s viewport in CSS pixels. 0 refers to\n the top of the viewport and Y increases as it proceeds towards the bottom of the viewport.\n  - `modifiers` : Bit field representing pressed modifier keys. Alt=1, Ctrl=2, Meta/Command=4, Shift=8\n (default: 0).\n  - `timestamp` : Time at which the event occurred.\n  - `button` : Mouse button (default: &quot;none&quot;).\n  - `buttons` : A number indicating which buttons are pressed on the mouse when a mouse event is triggered.\n Left=1, Right=2, Middle=4, Back=8, Forward=16, None=0.\n  - `click_count` : Number of times the mouse button was clicked (default: 0).\n  - `tilt_x` : The plane angle between the Y-Z plane and the plane containing both the stylus axis and the Y axis, in degrees of the range [-90,90], a positive tiltX is to the right (default: 0).\n  - `tilt_y` : The plane angle between the X-Z plane and the plane containing both the stylus axis and the X axis, in degrees of the range [-90,90], a positive tiltY is towards the user (default: 0).\n  - `delta_x` : X delta in CSS pixels for mouse wheel event (default: 0).\n  - `delta_y` : Y delta in CSS pixels for mouse wheel event (default: 0).\n  - `pointer_type` : Pointer type (default: &quot;mouse&quot;).\n \n Returns:  \n \nSynonyms:\nprotocol/input.dispatch_mouse_event\nprotocol/input dispatch_mouse_event","url":"protocol/input.html#dispatch_mouse_event"},{"doc":"protocol/input","title":"dispatch_touch_event","content":"pub fn dispatch_touch_event(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  type_ type_: DispatchTouchEventType,\n  touch_points touch_points: List(TouchPoint),\n  modifiers modifiers: Option(Int),\n  timestamp timestamp: Option(TimeSinceEpoch),\n) -&gt; a\n Dispatches a touch event to the page.\n \n Parameters:  \n  - `type_` : Type of the touch event. TouchEnd and TouchCancel must not contain any touch points, while\n TouchStart and TouchMove must contains at least one.\n  - `touch_points` : Active touch points on the touch device. One event per any changed point (compared to\n previous touch event in a sequence) is generated, emulating pressing/moving/releasing points\n one by one.\n  - `modifiers` : Bit field representing pressed modifier keys. Alt=1, Ctrl=2, Meta/Command=4, Shift=8\n (default: 0).\n  - `timestamp` : Time at which the event occurred.\n \n Returns:  \n \nSynonyms:\nprotocol/input.dispatch_touch_event\nprotocol/input dispatch_touch_event","url":"protocol/input.html#dispatch_touch_event"},{"doc":"protocol/input","title":"set_ignore_input_events","content":"pub fn set_ignore_input_events(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  ignore ignore: Bool,\n) -&gt; a\n Ignores input events (useful while auditing page).\n \n Parameters:  \n  - `ignore` : Ignores input events processing when set to true.\n \n Returns:  \n \nSynonyms:\nprotocol/input.set_ignore_input_events\nprotocol/input set_ignore_input_events","url":"protocol/input.html#set_ignore_input_events"},{"doc":"protocol/input","title":"protocol/input","content":" &gt; ⚙️  This module was generated from the Chrome DevTools Protocol version **1.3**\n ## Input Domain  \n\n This protocol domain has no description.  \n\n [📖   View this domain on the DevTools Protocol API Docs](https://chromedevtools.github.io/devtools-protocol/1-3/Input/)","url":"protocol/input.html"},{"doc":"protocol/runtime","title":"AwaitPromiseResponse","content":"pub type AwaitPromiseResponse {\n  AwaitPromiseResponse(\n    result: RemoteObject,\n    exception_details: option.Option(ExceptionDetails),\n  )\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `await_promise`\nAwaitPromiseResponse(\n  result: RemoteObject,\n  exception_details: option.Option(ExceptionDetails),\n)\n\nresult\n&lt;p&gt;Promise result. Will contain rejected value if promise was rejected.&lt;/p&gt;\n\nexception_details\n&lt;p&gt;Exception details if stack strace is available.&lt;/p&gt;\n\nSynonyms:\nprotocol/runtime.AwaitPromiseResponse\nprotocol/runtime AwaitPromiseResponse","url":"protocol/runtime.html#AwaitPromiseResponse"},{"doc":"protocol/runtime","title":"CallArgument","content":"pub type CallArgument {\n  CallArgument(\n    value: option.Option(dynamic.Dynamic),\n    unserializable_value: option.Option(UnserializableValue),\n    object_id: option.Option(RemoteObjectId),\n  )\n}\n Represents function call argument. Either remote object id `objectId`, primitive `value`,\n unserializable primitive value or neither of (for undefined) them should be specified.\nCallArgument(\n  value: option.Option(dynamic.Dynamic),\n  unserializable_value: option.Option(UnserializableValue),\n  object_id: option.Option(RemoteObjectId),\n)\n\nvalue\n&lt;p&gt;Primitive value or serializable javascript object.&lt;/p&gt;\n\nunserializable_value\n&lt;p&gt;Primitive value which can not be JSON-stringified.&lt;/p&gt;\n\nobject_id\n&lt;p&gt;Remote object handle.&lt;/p&gt;\n\nSynonyms:\nprotocol/runtime.CallArgument\nprotocol/runtime CallArgument","url":"protocol/runtime.html#CallArgument"},{"doc":"protocol/runtime","title":"CallFrame","content":"pub type CallFrame {\n  CallFrame(\n    function_name: String,\n    script_id: ScriptId,\n    url: String,\n    line_number: Int,\n    column_number: Int,\n  )\n}\n Stack entry for runtime errors and assertions.\nCallFrame(\n  function_name: String,\n  script_id: ScriptId,\n  url: String,\n  line_number: Int,\n  column_number: Int,\n)\n\nfunction_name\n&lt;p&gt;JavaScript function name.&lt;/p&gt;\n\nscript_id\n&lt;p&gt;JavaScript script id.&lt;/p&gt;\n\nurl\n&lt;p&gt;JavaScript script name or url.&lt;/p&gt;\n\nline_number\n&lt;p&gt;JavaScript script line number (0-based).&lt;/p&gt;\n\ncolumn_number\n&lt;p&gt;JavaScript script column number (0-based).&lt;/p&gt;\n\nSynonyms:\nprotocol/runtime.CallFrame\nprotocol/runtime CallFrame","url":"protocol/runtime.html#CallFrame"},{"doc":"protocol/runtime","title":"CallFunctionOnResponse","content":"pub type CallFunctionOnResponse {\n  CallFunctionOnResponse(\n    result: RemoteObject,\n    exception_details: option.Option(ExceptionDetails),\n  )\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `call_function_on`\nCallFunctionOnResponse(\n  result: RemoteObject,\n  exception_details: option.Option(ExceptionDetails),\n)\n\nresult\n&lt;p&gt;Call result.&lt;/p&gt;\n\nexception_details\n&lt;p&gt;Exception details.&lt;/p&gt;\n\nSynonyms:\nprotocol/runtime.CallFunctionOnResponse\nprotocol/runtime CallFunctionOnResponse","url":"protocol/runtime.html#CallFunctionOnResponse"},{"doc":"protocol/runtime","title":"CompileScriptResponse","content":"pub type CompileScriptResponse {\n  CompileScriptResponse(\n    script_id: option.Option(ScriptId),\n    exception_details: option.Option(ExceptionDetails),\n  )\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `compile_script`\nCompileScriptResponse(\n  script_id: option.Option(ScriptId),\n  exception_details: option.Option(ExceptionDetails),\n)\n\nscript_id\n&lt;p&gt;Id of the script.&lt;/p&gt;\n\nexception_details\n&lt;p&gt;Exception details.&lt;/p&gt;\n\nSynonyms:\nprotocol/runtime.CompileScriptResponse\nprotocol/runtime CompileScriptResponse","url":"protocol/runtime.html#CompileScriptResponse"},{"doc":"protocol/runtime","title":"DeepSerializedValue","content":"pub type DeepSerializedValue {\n  DeepSerializedValue(\n    type_: DeepSerializedValueType,\n    value: option.Option(dynamic.Dynamic),\n    object_id: option.Option(String),\n    weak_local_object_reference: option.Option(Int),\n  )\n}\n Represents deep serialized value.\nDeepSerializedValue(\n  type_: DeepSerializedValueType,\n  value: option.Option(dynamic.Dynamic),\n  object_id: option.Option(String),\n  weak_local_object_reference: option.Option(Int),\n)\n\nweak_local_object_reference\n&lt;p&gt;Set if value reference met more then once during serialization. In such\ncase, value is provided only to one of the serialized values. Unique\nper value in the scope of one CDP call.&lt;/p&gt;\n\nSynonyms:\nprotocol/runtime.DeepSerializedValue\nprotocol/runtime DeepSerializedValue","url":"protocol/runtime.html#DeepSerializedValue"},{"doc":"protocol/runtime","title":"DeepSerializedValueType","content":"pub type DeepSerializedValueType {\n  DeepSerializedValueTypeUndefined\n  DeepSerializedValueTypeNull\n  DeepSerializedValueTypeString\n  DeepSerializedValueTypeNumber\n  DeepSerializedValueTypeBoolean\n  DeepSerializedValueTypeBigint\n  DeepSerializedValueTypeRegexp\n  DeepSerializedValueTypeDate\n  DeepSerializedValueTypeSymbol\n  DeepSerializedValueTypeArray\n  DeepSerializedValueTypeObject\n  DeepSerializedValueTypeFunction\n  DeepSerializedValueTypeMap\n  DeepSerializedValueTypeSet\n  DeepSerializedValueTypeWeakmap\n  DeepSerializedValueTypeWeakset\n  DeepSerializedValueTypeError\n  DeepSerializedValueTypeProxy\n  DeepSerializedValueTypePromise\n  DeepSerializedValueTypeTypedarray\n  DeepSerializedValueTypeArraybuffer\n  DeepSerializedValueTypeNode\n  DeepSerializedValueTypeWindow\n  DeepSerializedValueTypeGenerator\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `type` of `DeepSerializedValue`\nDeepSerializedValueTypeUndefined\n\n\nDeepSerializedValueTypeNull\n\n\nDeepSerializedValueTypeString\n\n\nDeepSerializedValueTypeNumber\n\n\nDeepSerializedValueTypeBoolean\n\n\nDeepSerializedValueTypeBigint\n\n\nDeepSerializedValueTypeRegexp\n\n\nDeepSerializedValueTypeDate\n\n\nDeepSerializedValueTypeSymbol\n\n\nDeepSerializedValueTypeArray\n\n\nDeepSerializedValueTypeObject\n\n\nDeepSerializedValueTypeFunction\n\n\nDeepSerializedValueTypeMap\n\n\nDeepSerializedValueTypeSet\n\n\nDeepSerializedValueTypeWeakmap\n\n\nDeepSerializedValueTypeWeakset\n\n\nDeepSerializedValueTypeError\n\n\nDeepSerializedValueTypeProxy\n\n\nDeepSerializedValueTypePromise\n\n\nDeepSerializedValueTypeTypedarray\n\n\nDeepSerializedValueTypeArraybuffer\n\n\nDeepSerializedValueTypeNode\n\n\nDeepSerializedValueTypeWindow\n\n\nDeepSerializedValueTypeGenerator\n\n\nSynonyms:\nprotocol/runtime.DeepSerializedValueType\nprotocol/runtime DeepSerializedValueType","url":"protocol/runtime.html#DeepSerializedValueType"},{"doc":"protocol/runtime","title":"EvaluateResponse","content":"pub type EvaluateResponse {\n  EvaluateResponse(\n    result: RemoteObject,\n    exception_details: option.Option(ExceptionDetails),\n  )\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `evaluate`\nEvaluateResponse(\n  result: RemoteObject,\n  exception_details: option.Option(ExceptionDetails),\n)\n\nresult\n&lt;p&gt;Evaluation result.&lt;/p&gt;\n\nexception_details\n&lt;p&gt;Exception details.&lt;/p&gt;\n\nSynonyms:\nprotocol/runtime.EvaluateResponse\nprotocol/runtime EvaluateResponse","url":"protocol/runtime.html#EvaluateResponse"},{"doc":"protocol/runtime","title":"ExceptionDetails","content":"pub type ExceptionDetails {\n  ExceptionDetails(\n    exception_id: Int,\n    text: String,\n    line_number: Int,\n    column_number: Int,\n    script_id: option.Option(ScriptId),\n    url: option.Option(String),\n    stack_trace: option.Option(StackTrace),\n    exception: option.Option(RemoteObject),\n    execution_context_id: option.Option(ExecutionContextId),\n  )\n}\n Detailed information about exception (or error) that was thrown during script compilation or\n execution.\nExceptionDetails(\n  exception_id: Int,\n  text: String,\n  line_number: Int,\n  column_number: Int,\n  script_id: option.Option(ScriptId),\n  url: option.Option(String),\n  stack_trace: option.Option(StackTrace),\n  exception: option.Option(RemoteObject),\n  execution_context_id: option.Option(ExecutionContextId),\n)\n\nexception_id\n&lt;p&gt;Exception id.&lt;/p&gt;\n\ntext\n&lt;p&gt;Exception text, which should be used together with exception object when available.&lt;/p&gt;\n\nline_number\n&lt;p&gt;Line number of the exception location (0-based).&lt;/p&gt;\n\ncolumn_number\n&lt;p&gt;Column number of the exception location (0-based).&lt;/p&gt;\n\nscript_id\n&lt;p&gt;Script ID of the exception location.&lt;/p&gt;\n\nurl\n&lt;p&gt;URL of the exception location, to be used when the script was not reported.&lt;/p&gt;\n\nstack_trace\n&lt;p&gt;JavaScript stack trace if available.&lt;/p&gt;\n\nexception\n&lt;p&gt;Exception object if available.&lt;/p&gt;\n\nexecution_context_id\n&lt;p&gt;Identifier of the context where exception happened.&lt;/p&gt;\n\nSynonyms:\nprotocol/runtime.ExceptionDetails\nprotocol/runtime ExceptionDetails","url":"protocol/runtime.html#ExceptionDetails"},{"doc":"protocol/runtime","title":"ExecutionContextDescription","content":"pub type ExecutionContextDescription {\n  ExecutionContextDescription(\n    id: ExecutionContextId,\n    origin: String,\n    name: String,\n    aux_data: option.Option(dict.Dict(String, String)),\n  )\n}\n Description of an isolated world.\nExecutionContextDescription(\n  id: ExecutionContextId,\n  origin: String,\n  name: String,\n  aux_data: option.Option(dict.Dict(String, String)),\n)\n\nid\n&lt;p&gt;Unique id of the execution context. It can be used to specify in which execution context\nscript evaluation should be performed.&lt;/p&gt;\n\norigin\n&lt;p&gt;Execution context origin.&lt;/p&gt;\n\nname\n&lt;p&gt;Human readable name describing given context.&lt;/p&gt;\n\naux_data\n&lt;p&gt;Embedder-specific auxiliary data likely matching {isDefault: boolean, type: ‘default’|‘isolated’|‘worker’, frameId: string}&lt;/p&gt;\n\nSynonyms:\nprotocol/runtime.ExecutionContextDescription\nprotocol/runtime ExecutionContextDescription","url":"protocol/runtime.html#ExecutionContextDescription"},{"doc":"protocol/runtime","title":"ExecutionContextId","content":"pub type ExecutionContextId {\n  ExecutionContextId(Int)\n}\n Id of an execution context.\nExecutionContextId(Int)\n\n\nSynonyms:\nprotocol/runtime.ExecutionContextId\nprotocol/runtime ExecutionContextId","url":"protocol/runtime.html#ExecutionContextId"},{"doc":"protocol/runtime","title":"GetPropertiesResponse","content":"pub type GetPropertiesResponse {\n  GetPropertiesResponse(\n    result: List(PropertyDescriptor),\n    internal_properties: option.Option(\n      List(InternalPropertyDescriptor),\n    ),\n    exception_details: option.Option(ExceptionDetails),\n  )\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `get_properties`\nGetPropertiesResponse(\n  result: List(PropertyDescriptor),\n  internal_properties: option.Option(\n    List(InternalPropertyDescriptor),\n  ),\n  exception_details: option.Option(ExceptionDetails),\n)\n\nresult\n&lt;p&gt;Object properties.&lt;/p&gt;\n\ninternal_properties\n&lt;p&gt;Internal object properties (only of the element itself).&lt;/p&gt;\n\nexception_details\n&lt;p&gt;Exception details.&lt;/p&gt;\n\nSynonyms:\nprotocol/runtime.GetPropertiesResponse\nprotocol/runtime GetPropertiesResponse","url":"protocol/runtime.html#GetPropertiesResponse"},{"doc":"protocol/runtime","title":"GlobalLexicalScopeNamesResponse","content":"pub type GlobalLexicalScopeNamesResponse {\n  GlobalLexicalScopeNamesResponse(names: List(String))\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `global_lexical_scope_names`\nGlobalLexicalScopeNamesResponse(names: List(String))\n\n\nSynonyms:\nprotocol/runtime.GlobalLexicalScopeNamesResponse\nprotocol/runtime GlobalLexicalScopeNamesResponse","url":"protocol/runtime.html#GlobalLexicalScopeNamesResponse"},{"doc":"protocol/runtime","title":"InternalPropertyDescriptor","content":"pub type InternalPropertyDescriptor {\n  InternalPropertyDescriptor(\n    name: String,\n    value: option.Option(RemoteObject),\n  )\n}\n Object internal property descriptor. This property isn&#39;t normally visible in JavaScript code.\nInternalPropertyDescriptor(\n  name: String,\n  value: option.Option(RemoteObject),\n)\n\nname\n&lt;p&gt;Conventional property name.&lt;/p&gt;\n\nvalue\n&lt;p&gt;The value associated with the property.&lt;/p&gt;\n\nSynonyms:\nprotocol/runtime.InternalPropertyDescriptor\nprotocol/runtime InternalPropertyDescriptor","url":"protocol/runtime.html#InternalPropertyDescriptor"},{"doc":"protocol/runtime","title":"PropertyDescriptor","content":"pub type PropertyDescriptor {\n  PropertyDescriptor(\n    name: String,\n    value: option.Option(RemoteObject),\n    writable: option.Option(Bool),\n    get: option.Option(RemoteObject),\n    set: option.Option(RemoteObject),\n    configurable: Bool,\n    enumerable: Bool,\n    was_thrown: option.Option(Bool),\n    is_own: option.Option(Bool),\n    symbol: option.Option(RemoteObject),\n  )\n}\n Object property descriptor.\nPropertyDescriptor(\n  name: String,\n  value: option.Option(RemoteObject),\n  writable: option.Option(Bool),\n  get: option.Option(RemoteObject),\n  set: option.Option(RemoteObject),\n  configurable: Bool,\n  enumerable: Bool,\n  was_thrown: option.Option(Bool),\n  is_own: option.Option(Bool),\n  symbol: option.Option(RemoteObject),\n)\n\nname\n&lt;p&gt;Property name or symbol description.&lt;/p&gt;\n\nvalue\n&lt;p&gt;The value associated with the property.&lt;/p&gt;\n\nwritable\n&lt;p&gt;True if the value associated with the property may be changed (data descriptors only).&lt;/p&gt;\n\nget\n&lt;p&gt;A function which serves as a getter for the property, or &lt;code&gt;undefined&lt;/code&gt; if there is no getter\n(accessor descriptors only).&lt;/p&gt;\n\nset\n&lt;p&gt;A function which serves as a setter for the property, or &lt;code&gt;undefined&lt;/code&gt; if there is no setter\n(accessor descriptors only).&lt;/p&gt;\n\nconfigurable\n&lt;p&gt;True if the type of this property descriptor may be changed and if the property may be\ndeleted from the corresponding object.&lt;/p&gt;\n\nenumerable\n&lt;p&gt;True if this property shows up during enumeration of the properties on the corresponding\nobject.&lt;/p&gt;\n\nwas_thrown\n&lt;p&gt;True if the result was thrown during the evaluation.&lt;/p&gt;\n\nis_own\n&lt;p&gt;True if the property is owned for the object.&lt;/p&gt;\n\nsymbol\n&lt;p&gt;Property symbol object, if the property is of the &lt;code&gt;symbol&lt;/code&gt; type.&lt;/p&gt;\n\nSynonyms:\nprotocol/runtime.PropertyDescriptor\nprotocol/runtime PropertyDescriptor","url":"protocol/runtime.html#PropertyDescriptor"},{"doc":"protocol/runtime","title":"QueryObjectsResponse","content":"pub type QueryObjectsResponse {\n  QueryObjectsResponse(objects: RemoteObject)\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `query_objects`\nQueryObjectsResponse(objects: RemoteObject)\n\nobjects\n&lt;p&gt;Array with objects.&lt;/p&gt;\n\nSynonyms:\nprotocol/runtime.QueryObjectsResponse\nprotocol/runtime QueryObjectsResponse","url":"protocol/runtime.html#QueryObjectsResponse"},{"doc":"protocol/runtime","title":"RemoteObject","content":"pub type RemoteObject {\n  RemoteObject(\n    type_: RemoteObjectType,\n    subtype: option.Option(RemoteObjectSubtype),\n    class_name: option.Option(String),\n    value: option.Option(dynamic.Dynamic),\n    unserializable_value: option.Option(UnserializableValue),\n    description: option.Option(String),\n    object_id: option.Option(RemoteObjectId),\n  )\n}\n Mirror object referencing original JavaScript object.\nRemoteObject(\n  type_: RemoteObjectType,\n  subtype: option.Option(RemoteObjectSubtype),\n  class_name: option.Option(String),\n  value: option.Option(dynamic.Dynamic),\n  unserializable_value: option.Option(UnserializableValue),\n  description: option.Option(String),\n  object_id: option.Option(RemoteObjectId),\n)\n\ntype_\n&lt;p&gt;Object type.&lt;/p&gt;\n\nsubtype\n&lt;p&gt;Object subtype hint. Specified for &lt;code&gt;object&lt;/code&gt; type values only.\nNOTE: If you change anything here, make sure to also update\n&lt;code&gt;subtype&lt;/code&gt; in &lt;code&gt;ObjectPreview&lt;/code&gt; and &lt;code&gt;PropertyPreview&lt;/code&gt; below.&lt;/p&gt;\n\nclass_name\n&lt;p&gt;Object class (constructor) name. Specified for &lt;code&gt;object&lt;/code&gt; type values only.&lt;/p&gt;\n\nvalue\n&lt;p&gt;Remote object value in case of primitive values or JSON values (if it was requested).&lt;/p&gt;\n\nunserializable_value\n&lt;p&gt;Primitive value which can not be JSON-stringified does not have &lt;code&gt;value&lt;/code&gt;, but gets this\nproperty.&lt;/p&gt;\n\ndescription\n&lt;p&gt;String representation of the object.&lt;/p&gt;\n\nobject_id\n&lt;p&gt;Unique object identifier (for non-primitive values).&lt;/p&gt;\n\nSynonyms:\nprotocol/runtime.RemoteObject\nprotocol/runtime RemoteObject","url":"protocol/runtime.html#RemoteObject"},{"doc":"protocol/runtime","title":"RemoteObjectId","content":"pub type RemoteObjectId {\n  RemoteObjectId(String)\n}\n Unique object identifier.\nRemoteObjectId(String)\n\n\nSynonyms:\nprotocol/runtime.RemoteObjectId\nprotocol/runtime RemoteObjectId","url":"protocol/runtime.html#RemoteObjectId"},{"doc":"protocol/runtime","title":"RemoteObjectSubtype","content":"pub type RemoteObjectSubtype {\n  RemoteObjectSubtypeArray\n  RemoteObjectSubtypeNull\n  RemoteObjectSubtypeNode\n  RemoteObjectSubtypeRegexp\n  RemoteObjectSubtypeDate\n  RemoteObjectSubtypeMap\n  RemoteObjectSubtypeSet\n  RemoteObjectSubtypeWeakmap\n  RemoteObjectSubtypeWeakset\n  RemoteObjectSubtypeIterator\n  RemoteObjectSubtypeGenerator\n  RemoteObjectSubtypeError\n  RemoteObjectSubtypeProxy\n  RemoteObjectSubtypePromise\n  RemoteObjectSubtypeTypedarray\n  RemoteObjectSubtypeArraybuffer\n  RemoteObjectSubtypeDataview\n  RemoteObjectSubtypeWebassemblymemory\n  RemoteObjectSubtypeWasmvalue\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `subtype` of `RemoteObject`\nRemoteObjectSubtypeArray\n\n\nRemoteObjectSubtypeNull\n\n\nRemoteObjectSubtypeNode\n\n\nRemoteObjectSubtypeRegexp\n\n\nRemoteObjectSubtypeDate\n\n\nRemoteObjectSubtypeMap\n\n\nRemoteObjectSubtypeSet\n\n\nRemoteObjectSubtypeWeakmap\n\n\nRemoteObjectSubtypeWeakset\n\n\nRemoteObjectSubtypeIterator\n\n\nRemoteObjectSubtypeGenerator\n\n\nRemoteObjectSubtypeError\n\n\nRemoteObjectSubtypeProxy\n\n\nRemoteObjectSubtypePromise\n\n\nRemoteObjectSubtypeTypedarray\n\n\nRemoteObjectSubtypeArraybuffer\n\n\nRemoteObjectSubtypeDataview\n\n\nRemoteObjectSubtypeWebassemblymemory\n\n\nRemoteObjectSubtypeWasmvalue\n\n\nSynonyms:\nprotocol/runtime.RemoteObjectSubtype\nprotocol/runtime RemoteObjectSubtype","url":"protocol/runtime.html#RemoteObjectSubtype"},{"doc":"protocol/runtime","title":"RemoteObjectType","content":"pub type RemoteObjectType {\n  RemoteObjectTypeObject\n  RemoteObjectTypeFunction\n  RemoteObjectTypeUndefined\n  RemoteObjectTypeString\n  RemoteObjectTypeNumber\n  RemoteObjectTypeBoolean\n  RemoteObjectTypeSymbol\n  RemoteObjectTypeBigint\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `type` of `RemoteObject`\nRemoteObjectTypeObject\n\n\nRemoteObjectTypeFunction\n\n\nRemoteObjectTypeUndefined\n\n\nRemoteObjectTypeString\n\n\nRemoteObjectTypeNumber\n\n\nRemoteObjectTypeBoolean\n\n\nRemoteObjectTypeSymbol\n\n\nRemoteObjectTypeBigint\n\n\nSynonyms:\nprotocol/runtime.RemoteObjectType\nprotocol/runtime RemoteObjectType","url":"protocol/runtime.html#RemoteObjectType"},{"doc":"protocol/runtime","title":"RunScriptResponse","content":"pub type RunScriptResponse {\n  RunScriptResponse(\n    result: RemoteObject,\n    exception_details: option.Option(ExceptionDetails),\n  )\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `run_script`\nRunScriptResponse(\n  result: RemoteObject,\n  exception_details: option.Option(ExceptionDetails),\n)\n\nresult\n&lt;p&gt;Run result.&lt;/p&gt;\n\nexception_details\n&lt;p&gt;Exception details.&lt;/p&gt;\n\nSynonyms:\nprotocol/runtime.RunScriptResponse\nprotocol/runtime RunScriptResponse","url":"protocol/runtime.html#RunScriptResponse"},{"doc":"protocol/runtime","title":"ScriptId","content":"pub type ScriptId {\n  ScriptId(String)\n}\n Unique script identifier.\nScriptId(String)\n\n\nSynonyms:\nprotocol/runtime.ScriptId\nprotocol/runtime ScriptId","url":"protocol/runtime.html#ScriptId"},{"doc":"protocol/runtime","title":"SerializationOptions","content":"pub type SerializationOptions {\n  SerializationOptions(\n    serialization: SerializationOptionsSerialization,\n    max_depth: option.Option(Int),\n    additional_parameters: option.Option(\n      dict.Dict(String, String),\n    ),\n  )\n}\n Represents options for serialization. Overrides `generatePreview` and `returnByValue`.\nSerializationOptions(\n  serialization: SerializationOptionsSerialization,\n  max_depth: option.Option(Int),\n  additional_parameters: option.Option(dict.Dict(String, String)),\n)\n\nmax_depth\n&lt;p&gt;Deep serialization depth. Default is full depth. Respected only in &lt;code&gt;deep&lt;/code&gt; serialization mode.&lt;/p&gt;\n\nadditional_parameters\n&lt;p&gt;Embedder-specific parameters. For example if connected to V8 in Chrome these control DOM\nserialization via &lt;code&gt;maxNodeDepth: integer&lt;/code&gt; and &lt;code&gt;includeShadowTree: &quot;none&quot; | &quot;open&quot; | &quot;all&quot;&lt;/code&gt;.\nValues can be only of type string or integer.&lt;/p&gt;\n\nSynonyms:\nprotocol/runtime.SerializationOptions\nprotocol/runtime SerializationOptions","url":"protocol/runtime.html#SerializationOptions"},{"doc":"protocol/runtime","title":"SerializationOptionsSerialization","content":"pub type SerializationOptionsSerialization {\n  SerializationOptionsSerializationDeep\n  SerializationOptionsSerializationJson\n  SerializationOptionsSerializationIdOnly\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `serialization` of `SerializationOptions`\nSerializationOptionsSerializationDeep\n\n\nSerializationOptionsSerializationJson\n\n\nSerializationOptionsSerializationIdOnly\n\n\nSynonyms:\nprotocol/runtime.SerializationOptionsSerialization\nprotocol/runtime SerializationOptionsSerialization","url":"protocol/runtime.html#SerializationOptionsSerialization"},{"doc":"protocol/runtime","title":"StackTrace","content":"pub type StackTrace {\n  StackTrace(\n    description: option.Option(String),\n    call_frames: List(CallFrame),\n    parent: option.Option(StackTrace),\n  )\n}\n Call frames for assertions or error messages.\nStackTrace(\n  description: option.Option(String),\n  call_frames: List(CallFrame),\n  parent: option.Option(StackTrace),\n)\n\ndescription\n&lt;p&gt;String label of this stack trace. For async traces this may be a name of the function that\ninitiated the async call.&lt;/p&gt;\n\ncall_frames\n&lt;p&gt;JavaScript function name.&lt;/p&gt;\n\nparent\n&lt;p&gt;Asynchronous JavaScript stack trace that preceded this stack, if available.&lt;/p&gt;\n\nSynonyms:\nprotocol/runtime.StackTrace\nprotocol/runtime StackTrace","url":"protocol/runtime.html#StackTrace"},{"doc":"protocol/runtime","title":"TimeDelta","content":"pub type TimeDelta {\n  TimeDelta(Float)\n}\n Number of milliseconds.\nTimeDelta(Float)\n\n\nSynonyms:\nprotocol/runtime.TimeDelta\nprotocol/runtime TimeDelta","url":"protocol/runtime.html#TimeDelta"},{"doc":"protocol/runtime","title":"Timestamp","content":"pub type Timestamp {\n  Timestamp(Float)\n}\n Number of milliseconds since epoch.\nTimestamp(Float)\n\n\nSynonyms:\nprotocol/runtime.Timestamp\nprotocol/runtime Timestamp","url":"protocol/runtime.html#Timestamp"},{"doc":"protocol/runtime","title":"UnserializableValue","content":"pub type UnserializableValue {\n  UnserializableValue(String)\n}\n Primitive value which cannot be JSON-stringified. Includes values `-0`, `NaN`, `Infinity`,\n `-Infinity`, and bigint literals.\nUnserializableValue(String)\n\n\nSynonyms:\nprotocol/runtime.UnserializableValue\nprotocol/runtime UnserializableValue","url":"protocol/runtime.html#UnserializableValue"},{"doc":"protocol/runtime","title":"add_binding","content":"pub fn add_binding(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  name name: String,\n  execution_context_name execution_context_name: Option(String),\n) -&gt; a\n If executionContextId is empty, adds binding with the given name on the\n global objects of all inspected contexts, including those created later,\n bindings survive reloads.\n Binding function takes exactly one argument, this argument should be string,\n in case of any other input, function throws an exception.\n Each binding function call produces Runtime.bindingCalled notification.\n \n Parameters:  \n  - `name`\n  - `execution_context_name` : If specified, the binding is exposed to the executionContext with\n matching name, even for contexts created after the binding is added.\n See also `ExecutionContext.name` and `worldName` parameter to\n `Page.addScriptToEvaluateOnNewDocument`.\n This parameter is mutually exclusive with `executionContextId`.\n \n Returns:  \n \nSynonyms:\nprotocol/runtime.add_binding\nprotocol/runtime add_binding","url":"protocol/runtime.html#add_binding"},{"doc":"protocol/runtime","title":"await_promise","content":"pub fn await_promise(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  promise_object_id promise_object_id: RemoteObjectId,\n  return_by_value return_by_value: Option(Bool),\n  generate_preview generate_preview: Option(Bool),\n) -&gt; Result(AwaitPromiseResponse, RequestError)\n Add handler to promise with given promise object id.\n \n Parameters:  \n  - `promise_object_id` : Identifier of the promise.\n  - `return_by_value` : Whether the result is expected to be a JSON object that should be sent by value.\n  - `generate_preview` : Whether preview should be generated for the result.\n \n Returns:  \n  - `result` : Promise result. Will contain rejected value if promise was rejected.\n  - `exception_details` : Exception details if stack strace is available.\n \nSynonyms:\nprotocol/runtime.await_promise\nprotocol/runtime await_promise","url":"protocol/runtime.html#await_promise"},{"doc":"protocol/runtime","title":"call_function_on","content":"pub fn call_function_on(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  function_declaration function_declaration: String,\n  object_id object_id: Option(RemoteObjectId),\n  arguments arguments: Option(List(CallArgument)),\n  silent silent: Option(Bool),\n  return_by_value return_by_value: Option(Bool),\n  user_gesture user_gesture: Option(Bool),\n  await_promise await_promise: Option(Bool),\n  execution_context_id execution_context_id: Option(\n    ExecutionContextId,\n  ),\n  object_group object_group: Option(String),\n) -&gt; Result(CallFunctionOnResponse, RequestError)\n Calls function with given declaration on the given object. Object group of the result is\n inherited from the target object.\n \n Parameters:  \n  - `function_declaration` : Declaration of the function to call.\n  - `object_id` : Identifier of the object to call function on. Either objectId or executionContextId should\n be specified.\n  - `arguments` : Call arguments. All call arguments must belong to the same JavaScript world as the target\n object.\n  - `silent` : In silent mode exceptions thrown during evaluation are not reported and do not pause\n execution. Overrides `setPauseOnException` state.\n  - `return_by_value` : Whether the result is expected to be a JSON object which should be sent by value.\n Can be overriden by `serializationOptions`.\n  - `user_gesture` : Whether execution should be treated as initiated by user in the UI.\n  - `await_promise` : Whether execution should `await` for resulting value and return once awaited promise is\n resolved.\n  - `execution_context_id` : Specifies execution context which global object will be used to call function on. Either\n executionContextId or objectId should be specified.\n  - `object_group` : Symbolic group name that can be used to release multiple objects. If objectGroup is not\n specified and objectId is, objectGroup will be inherited from object.\n \n Returns:  \n  - `result` : Call result.\n  - `exception_details` : Exception details.\n \nSynonyms:\nprotocol/runtime.call_function_on\nprotocol/runtime call_function_on","url":"protocol/runtime.html#call_function_on"},{"doc":"protocol/runtime","title":"compile_script","content":"pub fn compile_script(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  expression expression: String,\n  source_url source_url: String,\n  persist_script persist_script: Bool,\n  execution_context_id execution_context_id: Option(\n    ExecutionContextId,\n  ),\n) -&gt; Result(CompileScriptResponse, RequestError)\n Compiles expression.\n \n Parameters:  \n  - `expression` : Expression to compile.\n  - `source_url` : Source url to be set for the script.\n  - `persist_script` : Specifies whether the compiled script should be persisted.\n  - `execution_context_id` : Specifies in which execution context to perform script run. If the parameter is omitted the\n evaluation will be performed in the context of the inspected page.\n \n Returns:  \n  - `script_id` : Id of the script.\n  - `exception_details` : Exception details.\n \nSynonyms:\nprotocol/runtime.compile_script\nprotocol/runtime compile_script","url":"protocol/runtime.html#compile_script"},{"doc":"protocol/runtime","title":"disable","content":"pub fn disable(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n Disables reporting of execution contexts creation.\n \nSynonyms:\nprotocol/runtime.disable\nprotocol/runtime disable","url":"protocol/runtime.html#disable"},{"doc":"protocol/runtime","title":"discard_console_entries","content":"pub fn discard_console_entries(\n  callback__: fn(String, Option(a)) -&gt; b,\n) -&gt; b\n Discards collected exceptions and console API calls.\n \nSynonyms:\nprotocol/runtime.discard_console_entries\nprotocol/runtime discard_console_entries","url":"protocol/runtime.html#discard_console_entries"},{"doc":"protocol/runtime","title":"enable","content":"pub fn enable(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n Enables reporting of execution contexts creation by means of `executionContextCreated` event.\n When the reporting gets enabled the event will be sent immediately for each existing execution\n context.\n \nSynonyms:\nprotocol/runtime.enable\nprotocol/runtime enable","url":"protocol/runtime.html#enable"},{"doc":"protocol/runtime","title":"evaluate","content":"pub fn evaluate(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  expression expression: String,\n  object_group object_group: Option(String),\n  include_command_line_api include_command_line_api: Option(Bool),\n  silent silent: Option(Bool),\n  context_id context_id: Option(ExecutionContextId),\n  return_by_value return_by_value: Option(Bool),\n  user_gesture user_gesture: Option(Bool),\n  await_promise await_promise: Option(Bool),\n) -&gt; Result(EvaluateResponse, RequestError)\n Evaluates expression on global object.\n \n Parameters:  \n  - `expression` : Expression to evaluate.\n  - `object_group` : Symbolic group name that can be used to release multiple objects.\n  - `include_command_line_api` : Determines whether Command Line API should be available during the evaluation.\n  - `silent` : In silent mode exceptions thrown during evaluation are not reported and do not pause\n execution. Overrides `setPauseOnException` state.\n  - `context_id` : Specifies in which execution context to perform evaluation. If the parameter is omitted the\n evaluation will be performed in the context of the inspected page.\n This is mutually exclusive with `uniqueContextId`, which offers an\n alternative way to identify the execution context that is more reliable\n in a multi-process environment.\n  - `return_by_value` : Whether the result is expected to be a JSON object that should be sent by value.\n  - `user_gesture` : Whether execution should be treated as initiated by user in the UI.\n  - `await_promise` : Whether execution should `await` for resulting value and return once awaited promise is\n resolved.\n \n Returns:  \n  - `result` : Evaluation result.\n  - `exception_details` : Exception details.\n \nSynonyms:\nprotocol/runtime.evaluate\nprotocol/runtime evaluate","url":"protocol/runtime.html#evaluate"},{"doc":"protocol/runtime","title":"get_properties","content":"pub fn get_properties(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  object_id object_id: RemoteObjectId,\n  own_properties own_properties: Option(Bool),\n) -&gt; Result(GetPropertiesResponse, RequestError)\n Returns properties of a given object. Object group of the result is inherited from the target\n object.\n \n Parameters:  \n  - `object_id` : Identifier of the object to return properties for.\n  - `own_properties` : If true, returns properties belonging only to the element itself, not to its prototype\n chain.\n \n Returns:  \n  - `result` : Object properties.\n  - `internal_properties` : Internal object properties (only of the element itself).\n  - `exception_details` : Exception details.\n \nSynonyms:\nprotocol/runtime.get_properties\nprotocol/runtime get_properties","url":"protocol/runtime.html#get_properties"},{"doc":"protocol/runtime","title":"global_lexical_scope_names","content":"pub fn global_lexical_scope_names(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  execution_context_id execution_context_id: Option(\n    ExecutionContextId,\n  ),\n) -&gt; Result(GlobalLexicalScopeNamesResponse, RequestError)\n Returns all let, const and class variables from global scope.\n \n Parameters:  \n  - `execution_context_id` : Specifies in which execution context to lookup global scope variables.\n \n Returns:  \n  - `names`\n \nSynonyms:\nprotocol/runtime.global_lexical_scope_names\nprotocol/runtime global_lexical_scope_names","url":"protocol/runtime.html#global_lexical_scope_names"},{"doc":"protocol/runtime","title":"query_objects","content":"pub fn query_objects(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  prototype_object_id prototype_object_id: RemoteObjectId,\n  object_group object_group: Option(String),\n) -&gt; Result(QueryObjectsResponse, RequestError)\n This generated protocol command has no description\n \n Parameters:  \n  - `prototype_object_id` : Identifier of the prototype to return objects for.\n  - `object_group` : Symbolic group name that can be used to release the results.\n \n Returns:  \n  - `objects` : Array with objects.\n \nSynonyms:\nprotocol/runtime.query_objects\nprotocol/runtime query_objects","url":"protocol/runtime.html#query_objects"},{"doc":"protocol/runtime","title":"release_object","content":"pub fn release_object(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  object_id object_id: RemoteObjectId,\n) -&gt; a\n Releases remote object with given id.\n \n Parameters:  \n  - `object_id` : Identifier of the object to release.\n \n Returns:  \n \nSynonyms:\nprotocol/runtime.release_object\nprotocol/runtime release_object","url":"protocol/runtime.html#release_object"},{"doc":"protocol/runtime","title":"release_object_group","content":"pub fn release_object_group(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  object_group object_group: String,\n) -&gt; a\n Releases all remote objects that belong to a given group.\n \n Parameters:  \n  - `object_group` : Symbolic object group name.\n \n Returns:  \n \nSynonyms:\nprotocol/runtime.release_object_group\nprotocol/runtime release_object_group","url":"protocol/runtime.html#release_object_group"},{"doc":"protocol/runtime","title":"remove_binding","content":"pub fn remove_binding(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  name name: String,\n) -&gt; a\n This method does not remove binding function from global object but\n unsubscribes current runtime agent from Runtime.bindingCalled notifications.\n \n Parameters:  \n  - `name`\n \n Returns:  \n \nSynonyms:\nprotocol/runtime.remove_binding\nprotocol/runtime remove_binding","url":"protocol/runtime.html#remove_binding"},{"doc":"protocol/runtime","title":"run_if_waiting_for_debugger","content":"pub fn run_if_waiting_for_debugger(\n  callback__: fn(String, Option(a)) -&gt; b,\n) -&gt; b\n Tells inspected instance to run if it was waiting for debugger to attach.\n \nSynonyms:\nprotocol/runtime.run_if_waiting_for_debugger\nprotocol/runtime run_if_waiting_for_debugger","url":"protocol/runtime.html#run_if_waiting_for_debugger"},{"doc":"protocol/runtime","title":"run_script","content":"pub fn run_script(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  script_id script_id: ScriptId,\n  execution_context_id execution_context_id: Option(\n    ExecutionContextId,\n  ),\n  object_group object_group: Option(String),\n  silent silent: Option(Bool),\n  include_command_line_api include_command_line_api: Option(Bool),\n  return_by_value return_by_value: Option(Bool),\n  generate_preview generate_preview: Option(Bool),\n  await_promise await_promise: Option(Bool),\n) -&gt; Result(RunScriptResponse, RequestError)\n Runs script with given id in a given context.\n \n Parameters:  \n  - `script_id` : Id of the script to run.\n  - `execution_context_id` : Specifies in which execution context to perform script run. If the parameter is omitted the\n evaluation will be performed in the context of the inspected page.\n  - `object_group` : Symbolic group name that can be used to release multiple objects.\n  - `silent` : In silent mode exceptions thrown during evaluation are not reported and do not pause\n execution. Overrides `setPauseOnException` state.\n  - `include_command_line_api` : Determines whether Command Line API should be available during the evaluation.\n  - `return_by_value` : Whether the result is expected to be a JSON object which should be sent by value.\n  - `generate_preview` : Whether preview should be generated for the result.\n  - `await_promise` : Whether execution should `await` for resulting value and return once awaited promise is\n resolved.\n \n Returns:  \n  - `result` : Run result.\n  - `exception_details` : Exception details.\n \nSynonyms:\nprotocol/runtime.run_script\nprotocol/runtime run_script","url":"protocol/runtime.html#run_script"},{"doc":"protocol/runtime","title":"set_async_call_stack_depth","content":"pub fn set_async_call_stack_depth(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  max_depth max_depth: Int,\n) -&gt; a\n Enables or disables async call stacks tracking.\n \n Parameters:  \n  - `max_depth` : Maximum depth of async call stacks. Setting to `0` will effectively disable collecting async\n call stacks (default).\n \n Returns:  \n \nSynonyms:\nprotocol/runtime.set_async_call_stack_depth\nprotocol/runtime set_async_call_stack_depth","url":"protocol/runtime.html#set_async_call_stack_depth"},{"doc":"protocol/runtime","title":"protocol/runtime","content":" &gt; ⚙️  This module was generated from the Chrome DevTools Protocol version **1.3**\n ## Runtime Domain  \n\n Runtime domain exposes JavaScript runtime by means of remote evaluation and mirror objects.\n Evaluation results are returned as mirror object that expose object type, string representation\n and unique identifier that can be used for further object reference. Original objects are\n maintained in memory unless they are either explicitly released or are released along with the\n other objects in their object group.  \n\n [📖   View this domain on the DevTools Protocol API Docs](https://chromedevtools.github.io/devtools-protocol/1-3/Runtime/)","url":"protocol/runtime.html"},{"doc":"protocol/dom","title":"BackendNode","content":"pub type BackendNode {\n  BackendNode(\n    node_type: Int,\n    node_name: String,\n    backend_node_id: BackendNodeId,\n  )\n}\n Backend node with a friendly name.\nBackendNode(\n  node_type: Int,\n  node_name: String,\n  backend_node_id: BackendNodeId,\n)\n\nnode_type\n&lt;p&gt;&lt;code&gt;Node&lt;/code&gt;’s nodeType.&lt;/p&gt;\n\nnode_name\n&lt;p&gt;&lt;code&gt;Node&lt;/code&gt;’s nodeName.&lt;/p&gt;\n\nSynonyms:\nprotocol/dom.BackendNode\nprotocol/dom BackendNode","url":"protocol/dom.html#BackendNode"},{"doc":"protocol/dom","title":"BackendNodeId","content":"pub type BackendNodeId {\n  BackendNodeId(Int)\n}\n Unique DOM node identifier used to reference a node that may not have been pushed to the\n front-end.\nBackendNodeId(Int)\n\n\nSynonyms:\nprotocol/dom.BackendNodeId\nprotocol/dom BackendNodeId","url":"protocol/dom.html#BackendNodeId"},{"doc":"protocol/dom","title":"BoxModel","content":"pub type BoxModel {\n  BoxModel(\n    content: Quad,\n    padding: Quad,\n    border: Quad,\n    margin: Quad,\n    width: Int,\n    height: Int,\n    shape_outside: option.Option(ShapeOutsideInfo),\n  )\n}\n Box model.\nBoxModel(\n  content: Quad,\n  padding: Quad,\n  border: Quad,\n  margin: Quad,\n  width: Int,\n  height: Int,\n  shape_outside: option.Option(ShapeOutsideInfo),\n)\n\ncontent\n&lt;p&gt;Content box&lt;/p&gt;\n\npadding\n&lt;p&gt;Padding box&lt;/p&gt;\n\nborder\n&lt;p&gt;Border box&lt;/p&gt;\n\nmargin\n&lt;p&gt;Margin box&lt;/p&gt;\n\nwidth\n&lt;p&gt;Node width&lt;/p&gt;\n\nheight\n&lt;p&gt;Node height&lt;/p&gt;\n\nshape_outside\n&lt;p&gt;Shape outside coordinates&lt;/p&gt;\n\nSynonyms:\nprotocol/dom.BoxModel\nprotocol/dom BoxModel","url":"protocol/dom.html#BoxModel"},{"doc":"protocol/dom","title":"CSSComputedStyleProperty","content":"pub type CSSComputedStyleProperty {\n  CSSComputedStyleProperty(name: String, value: String)\n}\n\nCSSComputedStyleProperty(name: String, value: String)\n\nname\n&lt;p&gt;Computed style property name.&lt;/p&gt;\n\nvalue\n&lt;p&gt;Computed style property value.&lt;/p&gt;\n\nSynonyms:\nprotocol/dom.CSSComputedStyleProperty\nprotocol/dom CSSComputedStyleProperty","url":"protocol/dom.html#CSSComputedStyleProperty"},{"doc":"protocol/dom","title":"CompatibilityMode","content":"pub type CompatibilityMode {\n  CompatibilityModeQuirksMode\n  CompatibilityModeLimitedQuirksMode\n  CompatibilityModeNoQuirksMode\n}\n Document compatibility mode.\nCompatibilityModeQuirksMode\n\n\nCompatibilityModeLimitedQuirksMode\n\n\nCompatibilityModeNoQuirksMode\n\n\nSynonyms:\nprotocol/dom.CompatibilityMode\nprotocol/dom CompatibilityMode","url":"protocol/dom.html#CompatibilityMode"},{"doc":"protocol/dom","title":"DescribeNodeResponse","content":"pub type DescribeNodeResponse {\n  DescribeNodeResponse(node: Node)\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `describe_node`\nDescribeNodeResponse(node: Node)\n\nnode\n&lt;p&gt;Node description.&lt;/p&gt;\n\nSynonyms:\nprotocol/dom.DescribeNodeResponse\nprotocol/dom DescribeNodeResponse","url":"protocol/dom.html#DescribeNodeResponse"},{"doc":"protocol/dom","title":"GetAttributesResponse","content":"pub type GetAttributesResponse {\n  GetAttributesResponse(attributes: List(String))\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `get_attributes`\nGetAttributesResponse(attributes: List(String))\n\nattributes\n&lt;p&gt;An interleaved array of node attribute names and values.&lt;/p&gt;\n\nSynonyms:\nprotocol/dom.GetAttributesResponse\nprotocol/dom GetAttributesResponse","url":"protocol/dom.html#GetAttributesResponse"},{"doc":"protocol/dom","title":"GetBoxModelResponse","content":"pub type GetBoxModelResponse {\n  GetBoxModelResponse(model: BoxModel)\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `get_box_model`\nGetBoxModelResponse(model: BoxModel)\n\nmodel\n&lt;p&gt;Box model for the node.&lt;/p&gt;\n\nSynonyms:\nprotocol/dom.GetBoxModelResponse\nprotocol/dom GetBoxModelResponse","url":"protocol/dom.html#GetBoxModelResponse"},{"doc":"protocol/dom","title":"GetDocumentResponse","content":"pub type GetDocumentResponse {\n  GetDocumentResponse(root: Node)\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `get_document`\nGetDocumentResponse(root: Node)\n\nroot\n&lt;p&gt;Resulting node.&lt;/p&gt;\n\nSynonyms:\nprotocol/dom.GetDocumentResponse\nprotocol/dom GetDocumentResponse","url":"protocol/dom.html#GetDocumentResponse"},{"doc":"protocol/dom","title":"GetNodeForLocationResponse","content":"pub type GetNodeForLocationResponse {\n  GetNodeForLocationResponse(\n    backend_node_id: BackendNodeId,\n    frame_id: String,\n    node_id: option.Option(NodeId),\n  )\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `get_node_for_location`\nGetNodeForLocationResponse(\n  backend_node_id: BackendNodeId,\n  frame_id: String,\n  node_id: option.Option(NodeId),\n)\n\nbackend_node_id\n&lt;p&gt;Resulting node.&lt;/p&gt;\n\nframe_id\n&lt;p&gt;Frame this node belongs to.&lt;/p&gt;\n\nnode_id\n&lt;p&gt;Id of the node at given coordinates, only when enabled and requested document.&lt;/p&gt;\n\nSynonyms:\nprotocol/dom.GetNodeForLocationResponse\nprotocol/dom GetNodeForLocationResponse","url":"protocol/dom.html#GetNodeForLocationResponse"},{"doc":"protocol/dom","title":"GetOuterHtmlResponse","content":"pub type GetOuterHtmlResponse {\n  GetOuterHtmlResponse(outer_html: String)\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `get_outer_html`\nGetOuterHtmlResponse(outer_html: String)\n\nouter_html\n&lt;p&gt;Outer HTML markup.&lt;/p&gt;\n\nSynonyms:\nprotocol/dom.GetOuterHtmlResponse\nprotocol/dom GetOuterHtmlResponse","url":"protocol/dom.html#GetOuterHtmlResponse"},{"doc":"protocol/dom","title":"LogicalAxes","content":"pub type LogicalAxes {\n  LogicalAxesInline\n  LogicalAxesBlock\n  LogicalAxesBoth\n}\n ContainerSelector logical axes\nLogicalAxesInline\n\n\nLogicalAxesBlock\n\n\nLogicalAxesBoth\n\n\nSynonyms:\nprotocol/dom.LogicalAxes\nprotocol/dom LogicalAxes","url":"protocol/dom.html#LogicalAxes"},{"doc":"protocol/dom","title":"MoveToResponse","content":"pub type MoveToResponse {\n  MoveToResponse(node_id: NodeId)\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `move_to`\nMoveToResponse(node_id: NodeId)\n\nnode_id\n&lt;p&gt;New id of the moved node.&lt;/p&gt;\n\nSynonyms:\nprotocol/dom.MoveToResponse\nprotocol/dom MoveToResponse","url":"protocol/dom.html#MoveToResponse"},{"doc":"protocol/dom","title":"Node","content":"pub type Node {\n  Node(\n    node_id: NodeId,\n    parent_id: option.Option(NodeId),\n    backend_node_id: BackendNodeId,\n    node_type: Int,\n    node_name: String,\n    local_name: String,\n    node_value: String,\n    child_node_count: option.Option(Int),\n    children: option.Option(List(Node)),\n    attributes: option.Option(List(String)),\n    document_url: option.Option(String),\n    base_url: option.Option(String),\n    public_id: option.Option(String),\n    system_id: option.Option(String),\n    internal_subset: option.Option(String),\n    xml_version: option.Option(String),\n    name: option.Option(String),\n    value: option.Option(String),\n    pseudo_type: option.Option(PseudoType),\n    pseudo_identifier: option.Option(String),\n    shadow_root_type: option.Option(ShadowRootType),\n    frame_id: option.Option(String),\n    content_document: option.Option(Node),\n    shadow_roots: option.Option(List(Node)),\n    template_content: option.Option(Node),\n    pseudo_elements: option.Option(List(Node)),\n    distributed_nodes: option.Option(List(BackendNode)),\n    is_svg: option.Option(Bool),\n    compatibility_mode: option.Option(CompatibilityMode),\n    assigned_slot: option.Option(BackendNode),\n  )\n}\n DOM interaction is implemented in terms of mirror objects that represent the actual DOM nodes.\n DOMNode is a base node mirror type.\nNode(\n  node_id: NodeId,\n  parent_id: option.Option(NodeId),\n  backend_node_id: BackendNodeId,\n  node_type: Int,\n  node_name: String,\n  local_name: String,\n  node_value: String,\n  child_node_count: option.Option(Int),\n  children: option.Option(List(Node)),\n  attributes: option.Option(List(String)),\n  document_url: option.Option(String),\n  base_url: option.Option(String),\n  public_id: option.Option(String),\n  system_id: option.Option(String),\n  internal_subset: option.Option(String),\n  xml_version: option.Option(String),\n  name: option.Option(String),\n  value: option.Option(String),\n  pseudo_type: option.Option(PseudoType),\n  pseudo_identifier: option.Option(String),\n  shadow_root_type: option.Option(ShadowRootType),\n  frame_id: option.Option(String),\n  content_document: option.Option(Node),\n  shadow_roots: option.Option(List(Node)),\n  template_content: option.Option(Node),\n  pseudo_elements: option.Option(List(Node)),\n  distributed_nodes: option.Option(List(BackendNode)),\n  is_svg: option.Option(Bool),\n  compatibility_mode: option.Option(CompatibilityMode),\n  assigned_slot: option.Option(BackendNode),\n)\n\nnode_id\n&lt;p&gt;Node identifier that is passed into the rest of the DOM messages as the &lt;code&gt;nodeId&lt;/code&gt;. Backend\nwill only push node with given &lt;code&gt;id&lt;/code&gt; once. It is aware of all requested nodes and will only\nfire DOM events for nodes known to the client.&lt;/p&gt;\n\nparent_id\n&lt;p&gt;The id of the parent node if any.&lt;/p&gt;\n\nbackend_node_id\n&lt;p&gt;The BackendNodeId for this node.&lt;/p&gt;\n\nnode_type\n&lt;p&gt;&lt;code&gt;Node&lt;/code&gt;’s nodeType.&lt;/p&gt;\n\nnode_name\n&lt;p&gt;&lt;code&gt;Node&lt;/code&gt;’s nodeName.&lt;/p&gt;\n\nlocal_name\n&lt;p&gt;&lt;code&gt;Node&lt;/code&gt;’s localName.&lt;/p&gt;\n\nnode_value\n&lt;p&gt;&lt;code&gt;Node&lt;/code&gt;’s nodeValue.&lt;/p&gt;\n\nchild_node_count\n&lt;p&gt;Child count for &lt;code&gt;Container&lt;/code&gt; nodes.&lt;/p&gt;\n\nchildren\n&lt;p&gt;Child nodes of this node when requested with children.&lt;/p&gt;\n\nattributes\n&lt;p&gt;Attributes of the &lt;code&gt;Element&lt;/code&gt; node in the form of flat array &lt;code&gt;[name1, value1, name2, value2]&lt;/code&gt;.&lt;/p&gt;\n\ndocument_url\n&lt;p&gt;Document URL that &lt;code&gt;Document&lt;/code&gt; or &lt;code&gt;FrameOwner&lt;/code&gt; node points to.&lt;/p&gt;\n\nbase_url\n&lt;p&gt;Base URL that &lt;code&gt;Document&lt;/code&gt; or &lt;code&gt;FrameOwner&lt;/code&gt; node uses for URL completion.&lt;/p&gt;\n\npublic_id\n&lt;p&gt;&lt;code&gt;DocumentType&lt;/code&gt;’s publicId.&lt;/p&gt;\n\nsystem_id\n&lt;p&gt;&lt;code&gt;DocumentType&lt;/code&gt;’s systemId.&lt;/p&gt;\n\ninternal_subset\n&lt;p&gt;&lt;code&gt;DocumentType&lt;/code&gt;’s internalSubset.&lt;/p&gt;\n\nxml_version\n&lt;p&gt;&lt;code&gt;Document&lt;/code&gt;’s XML version in case of XML documents.&lt;/p&gt;\n\nname\n&lt;p&gt;&lt;code&gt;Attr&lt;/code&gt;’s name.&lt;/p&gt;\n\nvalue\n&lt;p&gt;&lt;code&gt;Attr&lt;/code&gt;’s value.&lt;/p&gt;\n\npseudo_type\n&lt;p&gt;Pseudo element type for this node.&lt;/p&gt;\n\npseudo_identifier\n&lt;p&gt;Pseudo element identifier for this node. Only present if there is a\nvalid pseudoType.&lt;/p&gt;\n\nshadow_root_type\n&lt;p&gt;Shadow root type.&lt;/p&gt;\n\nframe_id\n&lt;p&gt;Frame ID for frame owner elements.&lt;/p&gt;\n\ncontent_document\n&lt;p&gt;Content document for frame owner elements.&lt;/p&gt;\n\nshadow_roots\n&lt;p&gt;Shadow root list for given element host.&lt;/p&gt;\n\ntemplate_content\n&lt;p&gt;Content document fragment for template elements.&lt;/p&gt;\n\npseudo_elements\n&lt;p&gt;Pseudo elements associated with this node.&lt;/p&gt;\n\ndistributed_nodes\n&lt;p&gt;Distributed nodes for given insertion point.&lt;/p&gt;\n\nis_svg\n&lt;p&gt;Whether the node is SVG.&lt;/p&gt;\n\nSynonyms:\nprotocol/dom.Node\nprotocol/dom Node","url":"protocol/dom.html#Node"},{"doc":"protocol/dom","title":"NodeId","content":"pub type NodeId {\n  NodeId(Int)\n}\n Unique DOM node identifier.\nNodeId(Int)\n\n\nSynonyms:\nprotocol/dom.NodeId\nprotocol/dom NodeId","url":"protocol/dom.html#NodeId"},{"doc":"protocol/dom","title":"PhysicalAxes","content":"pub type PhysicalAxes {\n  PhysicalAxesHorizontal\n  PhysicalAxesVertical\n  PhysicalAxesBoth\n}\n ContainerSelector physical axes\nPhysicalAxesHorizontal\n\n\nPhysicalAxesVertical\n\n\nPhysicalAxesBoth\n\n\nSynonyms:\nprotocol/dom.PhysicalAxes\nprotocol/dom PhysicalAxes","url":"protocol/dom.html#PhysicalAxes"},{"doc":"protocol/dom","title":"PseudoType","content":"pub type PseudoType {\n  PseudoTypeFirstLine\n  PseudoTypeFirstLetter\n  PseudoTypeBefore\n  PseudoTypeAfter\n  PseudoTypeMarker\n  PseudoTypeBackdrop\n  PseudoTypeSelection\n  PseudoTypeTargetText\n  PseudoTypeSpellingError\n  PseudoTypeGrammarError\n  PseudoTypeHighlight\n  PseudoTypeFirstLineInherited\n  PseudoTypeScrollMarker\n  PseudoTypeScrollMarkers\n  PseudoTypeScrollbar\n  PseudoTypeScrollbarThumb\n  PseudoTypeScrollbarButton\n  PseudoTypeScrollbarTrack\n  PseudoTypeScrollbarTrackPiece\n  PseudoTypeScrollbarCorner\n  PseudoTypeResizer\n  PseudoTypeInputListButton\n  PseudoTypeViewTransition\n  PseudoTypeViewTransitionGroup\n  PseudoTypeViewTransitionImagePair\n  PseudoTypeViewTransitionOld\n  PseudoTypeViewTransitionNew\n}\n Pseudo element type.\nPseudoTypeFirstLine\n\n\nPseudoTypeFirstLetter\n\n\nPseudoTypeBefore\n\n\nPseudoTypeAfter\n\n\nPseudoTypeMarker\n\n\nPseudoTypeBackdrop\n\n\nPseudoTypeSelection\n\n\nPseudoTypeTargetText\n\n\nPseudoTypeSpellingError\n\n\nPseudoTypeGrammarError\n\n\nPseudoTypeHighlight\n\n\nPseudoTypeFirstLineInherited\n\n\nPseudoTypeScrollMarker\n\n\nPseudoTypeScrollMarkers\n\n\nPseudoTypeScrollbar\n\n\nPseudoTypeScrollbarThumb\n\n\nPseudoTypeScrollbarButton\n\n\nPseudoTypeScrollbarTrack\n\n\nPseudoTypeScrollbarTrackPiece\n\n\nPseudoTypeScrollbarCorner\n\n\nPseudoTypeResizer\n\n\nPseudoTypeInputListButton\n\n\nPseudoTypeViewTransition\n\n\nPseudoTypeViewTransitionGroup\n\n\nPseudoTypeViewTransitionImagePair\n\n\nPseudoTypeViewTransitionOld\n\n\nPseudoTypeViewTransitionNew\n\n\nSynonyms:\nprotocol/dom.PseudoType\nprotocol/dom PseudoType","url":"protocol/dom.html#PseudoType"},{"doc":"protocol/dom","title":"Quad","content":"pub type Quad {\n  Quad(List(Float))\n}\n An array of quad vertices, x immediately followed by y for each point, points clock-wise.\nQuad(List(Float))\n\n\nSynonyms:\nprotocol/dom.Quad\nprotocol/dom Quad","url":"protocol/dom.html#Quad"},{"doc":"protocol/dom","title":"QuerySelectorAllResponse","content":"pub type QuerySelectorAllResponse {\n  QuerySelectorAllResponse(node_ids: List(NodeId))\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `query_selector_all`\nQuerySelectorAllResponse(node_ids: List(NodeId))\n\nnode_ids\n&lt;p&gt;Query selector result.&lt;/p&gt;\n\nSynonyms:\nprotocol/dom.QuerySelectorAllResponse\nprotocol/dom QuerySelectorAllResponse","url":"protocol/dom.html#QuerySelectorAllResponse"},{"doc":"protocol/dom","title":"QuerySelectorResponse","content":"pub type QuerySelectorResponse {\n  QuerySelectorResponse(node_id: NodeId)\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `query_selector`\nQuerySelectorResponse(node_id: NodeId)\n\nnode_id\n&lt;p&gt;Query selector result.&lt;/p&gt;\n\nSynonyms:\nprotocol/dom.QuerySelectorResponse\nprotocol/dom QuerySelectorResponse","url":"protocol/dom.html#QuerySelectorResponse"},{"doc":"protocol/dom","title":"RGBA","content":"pub type RGBA {\n  RGBA(r: Int, g: Int, b: Int, a: option.Option(Float))\n}\n A structure holding an RGBA color.\nRGBA(r: Int, g: Int, b: Int, a: option.Option(Float))\n\nr\n&lt;p&gt;The red component, in the [0-255] range.&lt;/p&gt;\n\ng\n&lt;p&gt;The green component, in the [0-255] range.&lt;/p&gt;\n\nb\n&lt;p&gt;The blue component, in the [0-255] range.&lt;/p&gt;\n\na\n&lt;p&gt;The alpha component, in the [0-1] range (default: 1).&lt;/p&gt;\n\nSynonyms:\nprotocol/dom.RGBA\nprotocol/dom RGBA","url":"protocol/dom.html#RGBA"},{"doc":"protocol/dom","title":"Rect","content":"pub type Rect {\n  Rect(x: Float, y: Float, width: Float, height: Float)\n}\n Rectangle.\nRect(x: Float, y: Float, width: Float, height: Float)\n\nx\n&lt;p&gt;X coordinate&lt;/p&gt;\n\ny\n&lt;p&gt;Y coordinate&lt;/p&gt;\n\nwidth\n&lt;p&gt;Rectangle width&lt;/p&gt;\n\nheight\n&lt;p&gt;Rectangle height&lt;/p&gt;\n\nSynonyms:\nprotocol/dom.Rect\nprotocol/dom Rect","url":"protocol/dom.html#Rect"},{"doc":"protocol/dom","title":"RequestNodeResponse","content":"pub type RequestNodeResponse {\n  RequestNodeResponse(node_id: NodeId)\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `request_node`\nRequestNodeResponse(node_id: NodeId)\n\nnode_id\n&lt;p&gt;Node id for given object.&lt;/p&gt;\n\nSynonyms:\nprotocol/dom.RequestNodeResponse\nprotocol/dom RequestNodeResponse","url":"protocol/dom.html#RequestNodeResponse"},{"doc":"protocol/dom","title":"ResolveNodeResponse","content":"pub type ResolveNodeResponse {\n  ResolveNodeResponse(object: runtime.RemoteObject)\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `resolve_node`\nResolveNodeResponse(object: runtime.RemoteObject)\n\nobject\n&lt;p&gt;JavaScript object wrapper for given node.&lt;/p&gt;\n\nSynonyms:\nprotocol/dom.ResolveNodeResponse\nprotocol/dom ResolveNodeResponse","url":"protocol/dom.html#ResolveNodeResponse"},{"doc":"protocol/dom","title":"ScrollOrientation","content":"pub type ScrollOrientation {\n  ScrollOrientationHorizontal\n  ScrollOrientationVertical\n}\n Physical scroll orientation\nScrollOrientationHorizontal\n\n\nScrollOrientationVertical\n\n\nSynonyms:\nprotocol/dom.ScrollOrientation\nprotocol/dom ScrollOrientation","url":"protocol/dom.html#ScrollOrientation"},{"doc":"protocol/dom","title":"SetNodeNameResponse","content":"pub type SetNodeNameResponse {\n  SetNodeNameResponse(node_id: NodeId)\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `set_node_name`\nSetNodeNameResponse(node_id: NodeId)\n\nnode_id\n&lt;p&gt;New node’s id.&lt;/p&gt;\n\nSynonyms:\nprotocol/dom.SetNodeNameResponse\nprotocol/dom SetNodeNameResponse","url":"protocol/dom.html#SetNodeNameResponse"},{"doc":"protocol/dom","title":"ShadowRootType","content":"pub type ShadowRootType {\n  ShadowRootTypeUserAgent\n  ShadowRootTypeOpen\n  ShadowRootTypeClosed\n}\n Shadow root type.\nShadowRootTypeUserAgent\n\n\nShadowRootTypeOpen\n\n\nShadowRootTypeClosed\n\n\nSynonyms:\nprotocol/dom.ShadowRootType\nprotocol/dom ShadowRootType","url":"protocol/dom.html#ShadowRootType"},{"doc":"protocol/dom","title":"ShapeOutsideInfo","content":"pub type ShapeOutsideInfo {\n  ShapeOutsideInfo(\n    bounds: Quad,\n    shape: List(dynamic.Dynamic),\n    margin_shape: List(dynamic.Dynamic),\n  )\n}\n CSS Shape Outside details.\nShapeOutsideInfo(\n  bounds: Quad,\n  shape: List(dynamic.Dynamic),\n  margin_shape: List(dynamic.Dynamic),\n)\n\nbounds\n&lt;p&gt;Shape bounds&lt;/p&gt;\n\nshape\n&lt;p&gt;Shape coordinate details&lt;/p&gt;\n\nmargin_shape\n&lt;p&gt;Margin shape bounds&lt;/p&gt;\n\nSynonyms:\nprotocol/dom.ShapeOutsideInfo\nprotocol/dom ShapeOutsideInfo","url":"protocol/dom.html#ShapeOutsideInfo"},{"doc":"protocol/dom","title":"describe_node","content":"pub fn describe_node(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  node_id node_id: Option(NodeId),\n  backend_node_id backend_node_id: Option(BackendNodeId),\n  object_id object_id: Option(RemoteObjectId),\n  depth depth: Option(Int),\n  pierce pierce: Option(Bool),\n) -&gt; Result(DescribeNodeResponse, RequestError)\n Describes node given its id, does not require domain to be enabled. Does not start tracking any\n objects, can be used for automation.\n \n Parameters:  \n  - `node_id` : Identifier of the node.\n  - `backend_node_id` : Identifier of the backend node.\n  - `object_id` : JavaScript object id of the node wrapper.\n  - `depth` : The maximum depth at which children should be retrieved, defaults to 1. Use -1 for the\n entire subtree or provide an integer larger than 0.\n  - `pierce` : Whether or not iframes and shadow roots should be traversed when returning the subtree\n (default is false).\n \n Returns:  \n  - `node` : Node description.\n \nSynonyms:\nprotocol/dom.describe_node\nprotocol/dom describe_node","url":"protocol/dom.html#describe_node"},{"doc":"protocol/dom","title":"disable","content":"pub fn disable(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n Disables DOM agent for the given page.\n \nSynonyms:\nprotocol/dom.disable\nprotocol/dom disable","url":"protocol/dom.html#disable"},{"doc":"protocol/dom","title":"enable","content":"pub fn enable(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n Enables DOM agent for the given page.\n \n Parameters:  \n \n Returns:  \n \nSynonyms:\nprotocol/dom.enable\nprotocol/dom enable","url":"protocol/dom.html#enable"},{"doc":"protocol/dom","title":"focus","content":"pub fn focus(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  node_id node_id: Option(NodeId),\n  backend_node_id backend_node_id: Option(BackendNodeId),\n  object_id object_id: Option(RemoteObjectId),\n) -&gt; a\n Focuses the given element.\n \n Parameters:  \n  - `node_id` : Identifier of the node.\n  - `backend_node_id` : Identifier of the backend node.\n  - `object_id` : JavaScript object id of the node wrapper.\n \n Returns:  \n \nSynonyms:\nprotocol/dom.focus\nprotocol/dom focus","url":"protocol/dom.html#focus"},{"doc":"protocol/dom","title":"get_attributes","content":"pub fn get_attributes(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  node_id node_id: NodeId,\n) -&gt; Result(GetAttributesResponse, RequestError)\n Returns attributes for the specified node.\n \n Parameters:  \n  - `node_id` : Id of the node to retrieve attributes for.\n \n Returns:  \n  - `attributes` : An interleaved array of node attribute names and values.\n \nSynonyms:\nprotocol/dom.get_attributes\nprotocol/dom get_attributes","url":"protocol/dom.html#get_attributes"},{"doc":"protocol/dom","title":"get_box_model","content":"pub fn get_box_model(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  node_id node_id: Option(NodeId),\n  backend_node_id backend_node_id: Option(BackendNodeId),\n  object_id object_id: Option(RemoteObjectId),\n) -&gt; Result(GetBoxModelResponse, RequestError)\n Returns boxes for the given node.\n \n Parameters:  \n  - `node_id` : Identifier of the node.\n  - `backend_node_id` : Identifier of the backend node.\n  - `object_id` : JavaScript object id of the node wrapper.\n \n Returns:  \n  - `model` : Box model for the node.\n \nSynonyms:\nprotocol/dom.get_box_model\nprotocol/dom get_box_model","url":"protocol/dom.html#get_box_model"},{"doc":"protocol/dom","title":"get_document","content":"pub fn get_document(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  depth depth: Option(Int),\n  pierce pierce: Option(Bool),\n) -&gt; Result(GetDocumentResponse, RequestError)\n Returns the root DOM node (and optionally the subtree) to the caller.\n Implicitly enables the DOM domain events for the current target.\n \n Parameters:  \n  - `depth` : The maximum depth at which children should be retrieved, defaults to 1. Use -1 for the\n entire subtree or provide an integer larger than 0.\n  - `pierce` : Whether or not iframes and shadow roots should be traversed when returning the subtree\n (default is false).\n \n Returns:  \n  - `root` : Resulting node.\n \nSynonyms:\nprotocol/dom.get_document\nprotocol/dom get_document","url":"protocol/dom.html#get_document"},{"doc":"protocol/dom","title":"get_node_for_location","content":"pub fn get_node_for_location(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  x x: Int,\n  y y: Int,\n  include_user_agent_shadow_dom include_user_agent_shadow_dom: Option(\n    Bool,\n  ),\n  ignore_pointer_events_none ignore_pointer_events_none: Option(\n    Bool,\n  ),\n) -&gt; Result(GetNodeForLocationResponse, RequestError)\n Returns node id at given location. Depending on whether DOM domain is enabled, nodeId is\n either returned or not.\n \n Parameters:  \n  - `x` : X coordinate.\n  - `y` : Y coordinate.\n  - `include_user_agent_shadow_dom` : False to skip to the nearest non-UA shadow root ancestor (default: false).\n  - `ignore_pointer_events_none` : Whether to ignore pointer-events: none on elements and hit test them.\n \n Returns:  \n  - `backend_node_id` : Resulting node.\n  - `frame_id` : Frame this node belongs to.\n  - `node_id` : Id of the node at given coordinates, only when enabled and requested document.\n \nSynonyms:\nprotocol/dom.get_node_for_location\nprotocol/dom get_node_for_location","url":"protocol/dom.html#get_node_for_location"},{"doc":"protocol/dom","title":"get_outer_html","content":"pub fn get_outer_html(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  node_id node_id: Option(NodeId),\n  backend_node_id backend_node_id: Option(BackendNodeId),\n  object_id object_id: Option(RemoteObjectId),\n) -&gt; Result(GetOuterHtmlResponse, RequestError)\n Returns node&#39;s HTML markup.\n \n Parameters:  \n  - `node_id` : Identifier of the node.\n  - `backend_node_id` : Identifier of the backend node.\n  - `object_id` : JavaScript object id of the node wrapper.\n \n Returns:  \n  - `outer_html` : Outer HTML markup.\n \nSynonyms:\nprotocol/dom.get_outer_html\nprotocol/dom get_outer_html","url":"protocol/dom.html#get_outer_html"},{"doc":"protocol/dom","title":"hide_highlight","content":"pub fn hide_highlight(\n  callback__: fn(String, Option(a)) -&gt; b,\n) -&gt; b\n Hides any highlight.\n \nSynonyms:\nprotocol/dom.hide_highlight\nprotocol/dom hide_highlight","url":"protocol/dom.html#hide_highlight"},{"doc":"protocol/dom","title":"highlight_node","content":"pub fn highlight_node(\n  callback__: fn(String, Option(a)) -&gt; b,\n) -&gt; b\n Highlights DOM node.\n \nSynonyms:\nprotocol/dom.highlight_node\nprotocol/dom highlight_node","url":"protocol/dom.html#highlight_node"},{"doc":"protocol/dom","title":"highlight_rect","content":"pub fn highlight_rect(\n  callback__: fn(String, Option(a)) -&gt; b,\n) -&gt; b\n Highlights given rectangle.\n \nSynonyms:\nprotocol/dom.highlight_rect\nprotocol/dom highlight_rect","url":"protocol/dom.html#highlight_rect"},{"doc":"protocol/dom","title":"move_to","content":"pub fn move_to(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  node_id node_id: NodeId,\n  target_node_id target_node_id: NodeId,\n  insert_before_node_id insert_before_node_id: Option(NodeId),\n) -&gt; Result(MoveToResponse, RequestError)\n Moves node into the new container, places it before the given anchor.\n \n Parameters:  \n  - `node_id` : Id of the node to move.\n  - `target_node_id` : Id of the element to drop the moved node into.\n  - `insert_before_node_id` : Drop node before this one (if absent, the moved node becomes the last child of\n `targetNodeId`).\n \n Returns:  \n  - `node_id` : New id of the moved node.\n \nSynonyms:\nprotocol/dom.move_to\nprotocol/dom move_to","url":"protocol/dom.html#move_to"},{"doc":"protocol/dom","title":"query_selector","content":"pub fn query_selector(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  node_id node_id: NodeId,\n  selector selector: String,\n) -&gt; Result(QuerySelectorResponse, RequestError)\n Executes `querySelector` on a given node.\n \n Parameters:  \n  - `node_id` : Id of the node to query upon.\n  - `selector` : Selector string.\n \n Returns:  \n  - `node_id` : Query selector result.\n \nSynonyms:\nprotocol/dom.query_selector\nprotocol/dom query_selector","url":"protocol/dom.html#query_selector"},{"doc":"protocol/dom","title":"query_selector_all","content":"pub fn query_selector_all(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  node_id node_id: NodeId,\n  selector selector: String,\n) -&gt; Result(QuerySelectorAllResponse, RequestError)\n Executes `querySelectorAll` on a given node.\n \n Parameters:  \n  - `node_id` : Id of the node to query upon.\n  - `selector` : Selector string.\n \n Returns:  \n  - `node_ids` : Query selector result.\n \nSynonyms:\nprotocol/dom.query_selector_all\nprotocol/dom query_selector_all","url":"protocol/dom.html#query_selector_all"},{"doc":"protocol/dom","title":"remove_attribute","content":"pub fn remove_attribute(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  node_id node_id: NodeId,\n  name name: String,\n) -&gt; a\n Removes attribute with given name from an element with given id.\n \n Parameters:  \n  - `node_id` : Id of the element to remove attribute from.\n  - `name` : Name of the attribute to remove.\n \n Returns:  \n \nSynonyms:\nprotocol/dom.remove_attribute\nprotocol/dom remove_attribute","url":"protocol/dom.html#remove_attribute"},{"doc":"protocol/dom","title":"remove_node","content":"pub fn remove_node(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  node_id node_id: NodeId,\n) -&gt; a\n Removes node with given id.\n \n Parameters:  \n  - `node_id` : Id of the node to remove.\n \n Returns:  \n \nSynonyms:\nprotocol/dom.remove_node\nprotocol/dom remove_node","url":"protocol/dom.html#remove_node"},{"doc":"protocol/dom","title":"request_child_nodes","content":"pub fn request_child_nodes(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  node_id node_id: NodeId,\n  depth depth: Option(Int),\n  pierce pierce: Option(Bool),\n) -&gt; a\n Requests that children of the node with given id are returned to the caller in form of\n `setChildNodes` events where not only immediate children are retrieved, but all children down to\n the specified depth.\n \n Parameters:  \n  - `node_id` : Id of the node to get children for.\n  - `depth` : The maximum depth at which children should be retrieved, defaults to 1. Use -1 for the\n entire subtree or provide an integer larger than 0.\n  - `pierce` : Whether or not iframes and shadow roots should be traversed when returning the sub-tree\n (default is false).\n \n Returns:  \n \nSynonyms:\nprotocol/dom.request_child_nodes\nprotocol/dom request_child_nodes","url":"protocol/dom.html#request_child_nodes"},{"doc":"protocol/dom","title":"request_node","content":"pub fn request_node(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  object_id object_id: RemoteObjectId,\n) -&gt; Result(RequestNodeResponse, RequestError)\n Requests that the node is sent to the caller given the JavaScript node object reference. All\n nodes that form the path from the node to the root are also sent to the client as a series of\n `setChildNodes` notifications.\n \n Parameters:  \n  - `object_id` : JavaScript object id to convert into node.\n \n Returns:  \n  - `node_id` : Node id for given object.\n \nSynonyms:\nprotocol/dom.request_node\nprotocol/dom request_node","url":"protocol/dom.html#request_node"},{"doc":"protocol/dom","title":"resolve_node","content":"pub fn resolve_node(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  node_id node_id: Option(NodeId),\n  backend_node_id backend_node_id: Option(BackendNodeId),\n  object_group object_group: Option(String),\n  execution_context_id execution_context_id: Option(\n    ExecutionContextId,\n  ),\n) -&gt; Result(ResolveNodeResponse, RequestError)\n Resolves the JavaScript node object for a given NodeId or BackendNodeId.\n \n Parameters:  \n  - `node_id` : Id of the node to resolve.\n  - `backend_node_id` : Backend identifier of the node to resolve.\n  - `object_group` : Symbolic group name that can be used to release multiple objects.\n  - `execution_context_id` : Execution context in which to resolve the node.\n \n Returns:  \n  - `object` : JavaScript object wrapper for given node.\n \nSynonyms:\nprotocol/dom.resolve_node\nprotocol/dom resolve_node","url":"protocol/dom.html#resolve_node"},{"doc":"protocol/dom","title":"scroll_into_view_if_needed","content":"pub fn scroll_into_view_if_needed(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  node_id node_id: Option(NodeId),\n  backend_node_id backend_node_id: Option(BackendNodeId),\n  object_id object_id: Option(RemoteObjectId),\n  rect rect: Option(Rect),\n) -&gt; a\n Scrolls the specified rect of the given node into view if not already visible.\n Note: exactly one between nodeId, backendNodeId and objectId should be passed\n to identify the node.\n \n Parameters:  \n  - `node_id` : Identifier of the node.\n  - `backend_node_id` : Identifier of the backend node.\n  - `object_id` : JavaScript object id of the node wrapper.\n  - `rect` : The rect to be scrolled into view, relative to the node&#39;s border box, in CSS pixels.\n When omitted, center of the node will be used, similar to Element.scrollIntoView.\n \n Returns:  \n \nSynonyms:\nprotocol/dom.scroll_into_view_if_needed\nprotocol/dom scroll_into_view_if_needed","url":"protocol/dom.html#scroll_into_view_if_needed"},{"doc":"protocol/dom","title":"set_attribute_value","content":"pub fn set_attribute_value(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  node_id node_id: NodeId,\n  name name: String,\n  value value: String,\n) -&gt; a\n Sets attribute for an element with given id.\n \n Parameters:  \n  - `node_id` : Id of the element to set attribute for.\n  - `name` : Attribute name.\n  - `value` : Attribute value.\n \n Returns:  \n \nSynonyms:\nprotocol/dom.set_attribute_value\nprotocol/dom set_attribute_value","url":"protocol/dom.html#set_attribute_value"},{"doc":"protocol/dom","title":"set_attributes_as_text","content":"pub fn set_attributes_as_text(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  node_id node_id: NodeId,\n  text text: String,\n  name name: Option(String),\n) -&gt; a\n Sets attributes on element with given id. This method is useful when user edits some existing\n attribute value and types in several attribute name/value pairs.\n \n Parameters:  \n  - `node_id` : Id of the element to set attributes for.\n  - `text` : Text with a number of attributes. Will parse this text using HTML parser.\n  - `name` : Attribute name to replace with new attributes derived from text in case text parsed\n successfully.\n \n Returns:  \n \nSynonyms:\nprotocol/dom.set_attributes_as_text\nprotocol/dom set_attributes_as_text","url":"protocol/dom.html#set_attributes_as_text"},{"doc":"protocol/dom","title":"set_file_input_files","content":"pub fn set_file_input_files(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  files files: List(String),\n  node_id node_id: Option(NodeId),\n  backend_node_id backend_node_id: Option(BackendNodeId),\n  object_id object_id: Option(RemoteObjectId),\n) -&gt; a\n Sets files for the given file input element.\n \n Parameters:  \n  - `files` : Array of file paths to set.\n  - `node_id` : Identifier of the node.\n  - `backend_node_id` : Identifier of the backend node.\n  - `object_id` : JavaScript object id of the node wrapper.\n \n Returns:  \n \nSynonyms:\nprotocol/dom.set_file_input_files\nprotocol/dom set_file_input_files","url":"protocol/dom.html#set_file_input_files"},{"doc":"protocol/dom","title":"set_node_name","content":"pub fn set_node_name(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  node_id node_id: NodeId,\n  name name: String,\n) -&gt; Result(SetNodeNameResponse, RequestError)\n Sets node name for a node with given id.\n \n Parameters:  \n  - `node_id` : Id of the node to set name for.\n  - `name` : New node&#39;s name.\n \n Returns:  \n  - `node_id` : New node&#39;s id.\n \nSynonyms:\nprotocol/dom.set_node_name\nprotocol/dom set_node_name","url":"protocol/dom.html#set_node_name"},{"doc":"protocol/dom","title":"set_node_value","content":"pub fn set_node_value(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  node_id node_id: NodeId,\n  value value: String,\n) -&gt; a\n Sets node value for a node with given id.\n \n Parameters:  \n  - `node_id` : Id of the node to set value for.\n  - `value` : New node&#39;s value.\n \n Returns:  \n \nSynonyms:\nprotocol/dom.set_node_value\nprotocol/dom set_node_value","url":"protocol/dom.html#set_node_value"},{"doc":"protocol/dom","title":"set_outer_html","content":"pub fn set_outer_html(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  node_id node_id: NodeId,\n  outer_html outer_html: String,\n) -&gt; a\n Sets node HTML markup, returns new node id.\n \n Parameters:  \n  - `node_id` : Id of the node to set markup for.\n  - `outer_html` : Outer HTML markup to set.\n \n Returns:  \n \nSynonyms:\nprotocol/dom.set_outer_html\nprotocol/dom set_outer_html","url":"protocol/dom.html#set_outer_html"},{"doc":"protocol/dom","title":"protocol/dom","content":" &gt; ⚙️  This module was generated from the Chrome DevTools Protocol version **1.3**\n ## DOM Domain  \n\n This domain exposes DOM read/write operations. Each DOM Node is represented with its mirror object\n that has an `id`. This `id` can be used to get additional information on the Node, resolve it into\n the JavaScript object wrapper, etc. It is important that client receives DOM events only for the\n nodes that are known to the client. Backend keeps track of the nodes that were sent to the client\n and never sends the same node twice. It is client&#39;s responsibility to collect information about\n the nodes that were sent to the client. Note that `iframe` owner elements will return\n corresponding document elements as their child nodes.  \n\n [📖   View this domain on the DevTools Protocol API Docs](https://chromedevtools.github.io/devtools-protocol/1-3/DOM/)","url":"protocol/dom.html"},{"doc":"protocol/security","title":"CertificateErrorAction","content":"pub type CertificateErrorAction {\n  CertificateErrorActionContinue\n  CertificateErrorActionCancel\n}\n The action to take when a certificate error occurs. continue will continue processing the\n request and cancel will cancel the request.\nCertificateErrorActionContinue\n\n\nCertificateErrorActionCancel\n\n\nSynonyms:\nprotocol/security.CertificateErrorAction\nprotocol/security CertificateErrorAction","url":"protocol/security.html#CertificateErrorAction"},{"doc":"protocol/security","title":"CertificateId","content":"pub type CertificateId {\n  CertificateId(Int)\n}\n An internal certificate ID value.\nCertificateId(Int)\n\n\nSynonyms:\nprotocol/security.CertificateId\nprotocol/security CertificateId","url":"protocol/security.html#CertificateId"},{"doc":"protocol/security","title":"MixedContentType","content":"pub type MixedContentType {\n  MixedContentTypeBlockable\n  MixedContentTypeOptionallyBlockable\n  MixedContentTypeNone\n}\n A description of mixed content (HTTP resources on HTTPS pages), as defined by\n https://www.w3.org/TR/mixed-content/#categories\nMixedContentTypeBlockable\n\n\nMixedContentTypeOptionallyBlockable\n\n\nMixedContentTypeNone\n\n\nSynonyms:\nprotocol/security.MixedContentType\nprotocol/security MixedContentType","url":"protocol/security.html#MixedContentType"},{"doc":"protocol/security","title":"SecurityState","content":"pub type SecurityState {\n  SecurityStateUnknown\n  SecurityStateNeutral\n  SecurityStateInsecure\n  SecurityStateSecure\n  SecurityStateInfo\n  SecurityStateInsecureBroken\n}\n The security level of a page or resource.\nSecurityStateUnknown\n\n\nSecurityStateNeutral\n\n\nSecurityStateInsecure\n\n\nSecurityStateSecure\n\n\nSecurityStateInfo\n\n\nSecurityStateInsecureBroken\n\n\nSynonyms:\nprotocol/security.SecurityState\nprotocol/security SecurityState","url":"protocol/security.html#SecurityState"},{"doc":"protocol/security","title":"SecurityStateExplanation","content":"pub type SecurityStateExplanation {\n  SecurityStateExplanation(\n    security_state: SecurityState,\n    title: String,\n    summary: String,\n    description: String,\n    mixed_content_type: MixedContentType,\n    certificate: List(String),\n    recommendations: option.Option(List(String)),\n  )\n}\n An explanation of an factor contributing to the security state.\nSecurityStateExplanation(\n  security_state: SecurityState,\n  title: String,\n  summary: String,\n  description: String,\n  mixed_content_type: MixedContentType,\n  certificate: List(String),\n  recommendations: option.Option(List(String)),\n)\n\nsecurity_state\n&lt;p&gt;Security state representing the severity of the factor being explained.&lt;/p&gt;\n\ntitle\n&lt;p&gt;Title describing the type of factor.&lt;/p&gt;\n\nsummary\n&lt;p&gt;Short phrase describing the type of factor.&lt;/p&gt;\n\ndescription\n&lt;p&gt;Full text explanation of the factor.&lt;/p&gt;\n\nmixed_content_type\n&lt;p&gt;The type of mixed content described by the explanation.&lt;/p&gt;\n\ncertificate\n&lt;p&gt;Page certificate.&lt;/p&gt;\n\nrecommendations\n&lt;p&gt;Recommendations to fix any issues.&lt;/p&gt;\n\nSynonyms:\nprotocol/security.SecurityStateExplanation\nprotocol/security SecurityStateExplanation","url":"protocol/security.html#SecurityStateExplanation"},{"doc":"protocol/security","title":"disable","content":"pub fn disable(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n Disables tracking security state changes.\n \nSynonyms:\nprotocol/security.disable\nprotocol/security disable","url":"protocol/security.html#disable"},{"doc":"protocol/security","title":"enable","content":"pub fn enable(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n Enables tracking security state changes.\n \nSynonyms:\nprotocol/security.enable\nprotocol/security enable","url":"protocol/security.html#enable"},{"doc":"protocol/security","title":"set_ignore_certificate_errors","content":"pub fn set_ignore_certificate_errors(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  ignore ignore: Bool,\n) -&gt; a\n Enable/disable whether all certificate errors should be ignored.\n \n Parameters:  \n  - `ignore` : If true, all certificate errors will be ignored.\n \n Returns:  \n \nSynonyms:\nprotocol/security.set_ignore_certificate_errors\nprotocol/security set_ignore_certificate_errors","url":"protocol/security.html#set_ignore_certificate_errors"},{"doc":"protocol/security","title":"protocol/security","content":" &gt; ⚙️  This module was generated from the Chrome DevTools Protocol version **1.3**\n ## Security Domain  \n\n Security  \n\n [📖   View this domain on the DevTools Protocol API Docs](https://chromedevtools.github.io/devtools-protocol/1-3/Security/)","url":"protocol/security.html"},{"doc":"protocol/network","title":"BlockedReason","content":"pub type BlockedReason {\n  BlockedReasonOther\n  BlockedReasonCsp\n  BlockedReasonMixedContent\n  BlockedReasonOrigin\n  BlockedReasonInspector\n  BlockedReasonSubresourceFilter\n  BlockedReasonContentType\n  BlockedReasonCoepFrameResourceNeedsCoepHeader\n  BlockedReasonCoopSandboxedIframeCannotNavigateToCoopPage\n  BlockedReasonCorpNotSameOrigin\n  BlockedReasonCorpNotSameOriginAfterDefaultedToSameOriginByCoep\n  BlockedReasonCorpNotSameSite\n}\n The reason why request was blocked.\nBlockedReasonOther\n\n\nBlockedReasonCsp\n\n\nBlockedReasonMixedContent\n\n\nBlockedReasonOrigin\n\n\nBlockedReasonInspector\n\n\nBlockedReasonSubresourceFilter\n\n\nBlockedReasonContentType\n\n\nBlockedReasonCoepFrameResourceNeedsCoepHeader\n\n\nBlockedReasonCoopSandboxedIframeCannotNavigateToCoopPage\n\n\nBlockedReasonCorpNotSameOrigin\n\n\nBlockedReasonCorpNotSameOriginAfterDefaultedToSameOriginByCoep\n\n\nBlockedReasonCorpNotSameSite\n\n\nSynonyms:\nprotocol/network.BlockedReason\nprotocol/network BlockedReason","url":"protocol/network.html#BlockedReason"},{"doc":"protocol/network","title":"CachedResource","content":"pub type CachedResource {\n  CachedResource(\n    url: String,\n    type_: ResourceType,\n    response: option.Option(Response),\n    body_size: Float,\n  )\n}\n Information about the cached resource.\nCachedResource(\n  url: String,\n  type_: ResourceType,\n  response: option.Option(Response),\n  body_size: Float,\n)\n\nurl\n&lt;p&gt;Resource URL. This is the url of the original network request.&lt;/p&gt;\n\ntype_\n&lt;p&gt;Type of this resource.&lt;/p&gt;\n\nresponse\n&lt;p&gt;Cached response data.&lt;/p&gt;\n\nbody_size\n&lt;p&gt;Cached response body size.&lt;/p&gt;\n\nSynonyms:\nprotocol/network.CachedResource\nprotocol/network CachedResource","url":"protocol/network.html#CachedResource"},{"doc":"protocol/network","title":"CertificateTransparencyCompliance","content":"pub type CertificateTransparencyCompliance {\n  CertificateTransparencyComplianceUnknown\n  CertificateTransparencyComplianceNotCompliant\n  CertificateTransparencyComplianceCompliant\n}\n Whether the request complied with Certificate Transparency policy.\nCertificateTransparencyComplianceUnknown\n\n\nCertificateTransparencyComplianceNotCompliant\n\n\nCertificateTransparencyComplianceCompliant\n\n\nSynonyms:\nprotocol/network.CertificateTransparencyCompliance\nprotocol/network CertificateTransparencyCompliance","url":"protocol/network.html#CertificateTransparencyCompliance"},{"doc":"protocol/network","title":"ConnectionType","content":"pub type ConnectionType {\n  ConnectionTypeNone\n  ConnectionTypeCellular2g\n  ConnectionTypeCellular3g\n  ConnectionTypeCellular4g\n  ConnectionTypeBluetooth\n  ConnectionTypeEthernet\n  ConnectionTypeWifi\n  ConnectionTypeWimax\n  ConnectionTypeOther\n}\n The underlying connection technology that the browser is supposedly using.\nConnectionTypeNone\n\n\nConnectionTypeCellular2g\n\n\nConnectionTypeCellular3g\n\n\nConnectionTypeCellular4g\n\n\nConnectionTypeBluetooth\n\n\nConnectionTypeEthernet\n\n\nConnectionTypeWifi\n\n\nConnectionTypeWimax\n\n\nConnectionTypeOther\n\n\nSynonyms:\nprotocol/network.ConnectionType\nprotocol/network ConnectionType","url":"protocol/network.html#ConnectionType"},{"doc":"protocol/network","title":"Cookie","content":"pub type Cookie {\n  Cookie(\n    name: String,\n    value: String,\n    domain: String,\n    path: String,\n    expires: Float,\n    size: Int,\n    http_only: Bool,\n    secure: Bool,\n    session: Bool,\n    same_site: option.Option(CookieSameSite),\n  )\n}\n Cookie object\nCookie(\n  name: String,\n  value: String,\n  domain: String,\n  path: String,\n  expires: Float,\n  size: Int,\n  http_only: Bool,\n  secure: Bool,\n  session: Bool,\n  same_site: option.Option(CookieSameSite),\n)\n\nname\n&lt;p&gt;Cookie name.&lt;/p&gt;\n\nvalue\n&lt;p&gt;Cookie value.&lt;/p&gt;\n\ndomain\n&lt;p&gt;Cookie domain.&lt;/p&gt;\n\npath\n&lt;p&gt;Cookie path.&lt;/p&gt;\n\nexpires\n&lt;p&gt;Cookie expiration date as the number of seconds since the UNIX epoch.&lt;/p&gt;\n\nsize\n&lt;p&gt;Cookie size.&lt;/p&gt;\n\nhttp_only\n&lt;p&gt;True if cookie is http-only.&lt;/p&gt;\n\nsecure\n&lt;p&gt;True if cookie is secure.&lt;/p&gt;\n\nsession\n&lt;p&gt;True in case of session cookie.&lt;/p&gt;\n\nsame_site\n&lt;p&gt;Cookie SameSite type.&lt;/p&gt;\n\nSynonyms:\nprotocol/network.Cookie\nprotocol/network Cookie","url":"protocol/network.html#Cookie"},{"doc":"protocol/network","title":"CookieParam","content":"pub type CookieParam {\n  CookieParam(\n    name: String,\n    value: String,\n    url: option.Option(String),\n    domain: option.Option(String),\n    path: option.Option(String),\n    secure: option.Option(Bool),\n    http_only: option.Option(Bool),\n    same_site: option.Option(CookieSameSite),\n    expires: option.Option(TimeSinceEpoch),\n  )\n}\n Cookie parameter object\nCookieParam(\n  name: String,\n  value: String,\n  url: option.Option(String),\n  domain: option.Option(String),\n  path: option.Option(String),\n  secure: option.Option(Bool),\n  http_only: option.Option(Bool),\n  same_site: option.Option(CookieSameSite),\n  expires: option.Option(TimeSinceEpoch),\n)\n\nname\n&lt;p&gt;Cookie name.&lt;/p&gt;\n\nvalue\n&lt;p&gt;Cookie value.&lt;/p&gt;\n\nurl\n&lt;p&gt;The request-URI to associate with the setting of the cookie. This value can affect the\ndefault domain, path, source port, and source scheme values of the created cookie.&lt;/p&gt;\n\ndomain\n&lt;p&gt;Cookie domain.&lt;/p&gt;\n\npath\n&lt;p&gt;Cookie path.&lt;/p&gt;\n\nsecure\n&lt;p&gt;True if cookie is secure.&lt;/p&gt;\n\nhttp_only\n&lt;p&gt;True if cookie is http-only.&lt;/p&gt;\n\nsame_site\n&lt;p&gt;Cookie SameSite type.&lt;/p&gt;\n\nexpires\n&lt;p&gt;Cookie expiration date, session cookie if not set&lt;/p&gt;\n\nSynonyms:\nprotocol/network.CookieParam\nprotocol/network CookieParam","url":"protocol/network.html#CookieParam"},{"doc":"protocol/network","title":"CookieSameSite","content":"pub type CookieSameSite {\n  CookieSameSiteStrict\n  CookieSameSiteLax\n  CookieSameSiteNone\n}\n Represents the cookie&#39;s &#39;SameSite&#39; status:\n https://tools.ietf.org/html/draft-west-first-party-cookies\nCookieSameSiteStrict\n\n\nCookieSameSiteLax\n\n\nCookieSameSiteNone\n\n\nSynonyms:\nprotocol/network.CookieSameSite\nprotocol/network CookieSameSite","url":"protocol/network.html#CookieSameSite"},{"doc":"protocol/network","title":"CorsError","content":"pub type CorsError {\n  CorsErrorDisallowedByMode\n  CorsErrorInvalidResponse\n  CorsErrorWildcardOriginNotAllowed\n  CorsErrorMissingAllowOriginHeader\n  CorsErrorMultipleAllowOriginValues\n  CorsErrorInvalidAllowOriginValue\n  CorsErrorAllowOriginMismatch\n  CorsErrorInvalidAllowCredentials\n  CorsErrorCorsDisabledScheme\n  CorsErrorPreflightInvalidStatus\n  CorsErrorPreflightDisallowedRedirect\n  CorsErrorPreflightWildcardOriginNotAllowed\n  CorsErrorPreflightMissingAllowOriginHeader\n  CorsErrorPreflightMultipleAllowOriginValues\n  CorsErrorPreflightInvalidAllowOriginValue\n  CorsErrorPreflightAllowOriginMismatch\n  CorsErrorPreflightInvalidAllowCredentials\n  CorsErrorPreflightMissingAllowExternal\n  CorsErrorPreflightInvalidAllowExternal\n  CorsErrorPreflightMissingAllowPrivateNetwork\n  CorsErrorPreflightInvalidAllowPrivateNetwork\n  CorsErrorInvalidAllowMethodsPreflightResponse\n  CorsErrorInvalidAllowHeadersPreflightResponse\n  CorsErrorMethodDisallowedByPreflightResponse\n  CorsErrorHeaderDisallowedByPreflightResponse\n  CorsErrorRedirectContainsCredentials\n  CorsErrorInsecurePrivateNetwork\n  CorsErrorInvalidPrivateNetworkAccess\n  CorsErrorUnexpectedPrivateNetworkAccess\n  CorsErrorNoCorsRedirectModeNotFollow\n  CorsErrorPreflightMissingPrivateNetworkAccessId\n  CorsErrorPreflightMissingPrivateNetworkAccessName\n  CorsErrorPrivateNetworkAccessPermissionUnavailable\n  CorsErrorPrivateNetworkAccessPermissionDenied\n}\n The reason why request was blocked.\nCorsErrorDisallowedByMode\n\n\nCorsErrorInvalidResponse\n\n\nCorsErrorWildcardOriginNotAllowed\n\n\nCorsErrorMissingAllowOriginHeader\n\n\nCorsErrorMultipleAllowOriginValues\n\n\nCorsErrorInvalidAllowOriginValue\n\n\nCorsErrorAllowOriginMismatch\n\n\nCorsErrorInvalidAllowCredentials\n\n\nCorsErrorCorsDisabledScheme\n\n\nCorsErrorPreflightInvalidStatus\n\n\nCorsErrorPreflightDisallowedRedirect\n\n\nCorsErrorPreflightWildcardOriginNotAllowed\n\n\nCorsErrorPreflightMissingAllowOriginHeader\n\n\nCorsErrorPreflightMultipleAllowOriginValues\n\n\nCorsErrorPreflightInvalidAllowOriginValue\n\n\nCorsErrorPreflightAllowOriginMismatch\n\n\nCorsErrorPreflightInvalidAllowCredentials\n\n\nCorsErrorPreflightMissingAllowExternal\n\n\nCorsErrorPreflightInvalidAllowExternal\n\n\nCorsErrorPreflightMissingAllowPrivateNetwork\n\n\nCorsErrorPreflightInvalidAllowPrivateNetwork\n\n\nCorsErrorInvalidAllowMethodsPreflightResponse\n\n\nCorsErrorInvalidAllowHeadersPreflightResponse\n\n\nCorsErrorMethodDisallowedByPreflightResponse\n\n\nCorsErrorHeaderDisallowedByPreflightResponse\n\n\nCorsErrorRedirectContainsCredentials\n\n\nCorsErrorInsecurePrivateNetwork\n\n\nCorsErrorInvalidPrivateNetworkAccess\n\n\nCorsErrorUnexpectedPrivateNetworkAccess\n\n\nCorsErrorNoCorsRedirectModeNotFollow\n\n\nCorsErrorPreflightMissingPrivateNetworkAccessId\n\n\nCorsErrorPreflightMissingPrivateNetworkAccessName\n\n\nCorsErrorPrivateNetworkAccessPermissionUnavailable\n\n\nCorsErrorPrivateNetworkAccessPermissionDenied\n\n\nSynonyms:\nprotocol/network.CorsError\nprotocol/network CorsError","url":"protocol/network.html#CorsError"},{"doc":"protocol/network","title":"CorsErrorStatus","content":"pub type CorsErrorStatus {\n  CorsErrorStatus(\n    cors_error: CorsError,\n    failed_parameter: String,\n  )\n}\n\nCorsErrorStatus(cors_error: CorsError, failed_parameter: String)\n\n\nSynonyms:\nprotocol/network.CorsErrorStatus\nprotocol/network CorsErrorStatus","url":"protocol/network.html#CorsErrorStatus"},{"doc":"protocol/network","title":"ErrorReason","content":"pub type ErrorReason {\n  ErrorReasonFailed\n  ErrorReasonAborted\n  ErrorReasonTimedOut\n  ErrorReasonAccessDenied\n  ErrorReasonConnectionClosed\n  ErrorReasonConnectionReset\n  ErrorReasonConnectionRefused\n  ErrorReasonConnectionAborted\n  ErrorReasonConnectionFailed\n  ErrorReasonNameNotResolved\n  ErrorReasonInternetDisconnected\n  ErrorReasonAddressUnreachable\n  ErrorReasonBlockedByClient\n  ErrorReasonBlockedByResponse\n}\n Network level fetch failure reason.\nErrorReasonFailed\n\n\nErrorReasonAborted\n\n\nErrorReasonTimedOut\n\n\nErrorReasonAccessDenied\n\n\nErrorReasonConnectionClosed\n\n\nErrorReasonConnectionReset\n\n\nErrorReasonConnectionRefused\n\n\nErrorReasonConnectionAborted\n\n\nErrorReasonConnectionFailed\n\n\nErrorReasonNameNotResolved\n\n\nErrorReasonInternetDisconnected\n\n\nErrorReasonAddressUnreachable\n\n\nErrorReasonBlockedByClient\n\n\nErrorReasonBlockedByResponse\n\n\nSynonyms:\nprotocol/network.ErrorReason\nprotocol/network ErrorReason","url":"protocol/network.html#ErrorReason"},{"doc":"protocol/network","title":"GetCookiesResponse","content":"pub type GetCookiesResponse {\n  GetCookiesResponse(cookies: List(Cookie))\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `get_cookies`\nGetCookiesResponse(cookies: List(Cookie))\n\ncookies\n&lt;p&gt;Array of cookie objects.&lt;/p&gt;\n\nSynonyms:\nprotocol/network.GetCookiesResponse\nprotocol/network GetCookiesResponse","url":"protocol/network.html#GetCookiesResponse"},{"doc":"protocol/network","title":"GetRequestPostDataResponse","content":"pub type GetRequestPostDataResponse {\n  GetRequestPostDataResponse(post_data: String)\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `get_request_post_data`\nGetRequestPostDataResponse(post_data: String)\n\npost_data\n&lt;p&gt;Request body string, omitting files from multipart requests&lt;/p&gt;\n\nSynonyms:\nprotocol/network.GetRequestPostDataResponse\nprotocol/network GetRequestPostDataResponse","url":"protocol/network.html#GetRequestPostDataResponse"},{"doc":"protocol/network","title":"GetResponseBodyResponse","content":"pub type GetResponseBodyResponse {\n  GetResponseBodyResponse(body: String, base64_encoded: Bool)\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `get_response_body`\nGetResponseBodyResponse(body: String, base64_encoded: Bool)\n\nbody\n&lt;p&gt;Response body.&lt;/p&gt;\n\nbase64_encoded\n&lt;p&gt;True, if content was sent as base64.&lt;/p&gt;\n\nSynonyms:\nprotocol/network.GetResponseBodyResponse\nprotocol/network GetResponseBodyResponse","url":"protocol/network.html#GetResponseBodyResponse"},{"doc":"protocol/network","title":"Headers","content":"pub type Headers {\n  Headers(dict.Dict(String, String))\n}\n Request / response headers as keys / values of JSON object.\nHeaders(dict.Dict(String, String))\n\n\nSynonyms:\nprotocol/network.Headers\nprotocol/network Headers","url":"protocol/network.html#Headers"},{"doc":"protocol/network","title":"Initiator","content":"pub type Initiator {\n  Initiator(\n    type_: InitiatorType,\n    stack: option.Option(runtime.StackTrace),\n    url: option.Option(String),\n    line_number: option.Option(Float),\n    column_number: option.Option(Float),\n    request_id: option.Option(RequestId),\n  )\n}\n Information about the request initiator.\nInitiator(\n  type_: InitiatorType,\n  stack: option.Option(runtime.StackTrace),\n  url: option.Option(String),\n  line_number: option.Option(Float),\n  column_number: option.Option(Float),\n  request_id: option.Option(RequestId),\n)\n\ntype_\n&lt;p&gt;Type of this initiator.&lt;/p&gt;\n\nstack\n&lt;p&gt;Initiator JavaScript stack trace, set for Script only.&lt;/p&gt;\n\nurl\n&lt;p&gt;Initiator URL, set for Parser type or for Script type (when script is importing module) or for SignedExchange type.&lt;/p&gt;\n\nline_number\n&lt;p&gt;Initiator line number, set for Parser type or for Script type (when script is importing\nmodule) (0-based).&lt;/p&gt;\n\ncolumn_number\n&lt;p&gt;Initiator column number, set for Parser type or for Script type (when script is importing\nmodule) (0-based).&lt;/p&gt;\n\nrequest_id\n&lt;p&gt;Set if another request triggered this request (e.g. preflight).&lt;/p&gt;\n\nSynonyms:\nprotocol/network.Initiator\nprotocol/network Initiator","url":"protocol/network.html#Initiator"},{"doc":"protocol/network","title":"InitiatorType","content":"pub type InitiatorType {\n  InitiatorTypeParser\n  InitiatorTypeScript\n  InitiatorTypePreload\n  InitiatorTypeSignedExchange\n  InitiatorTypePreflight\n  InitiatorTypeOther\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `type` of `Initiator`\nInitiatorTypeParser\n\n\nInitiatorTypeScript\n\n\nInitiatorTypePreload\n\n\nInitiatorTypeSignedExchange\n\n\nInitiatorTypePreflight\n\n\nInitiatorTypeOther\n\n\nSynonyms:\nprotocol/network.InitiatorType\nprotocol/network InitiatorType","url":"protocol/network.html#InitiatorType"},{"doc":"protocol/network","title":"InterceptionId","content":"pub type InterceptionId {\n  InterceptionId(String)\n}\n Unique intercepted request identifier.\nInterceptionId(String)\n\n\nSynonyms:\nprotocol/network.InterceptionId\nprotocol/network InterceptionId","url":"protocol/network.html#InterceptionId"},{"doc":"protocol/network","title":"LoaderId","content":"pub type LoaderId {\n  LoaderId(String)\n}\n Unique loader identifier.\nLoaderId(String)\n\n\nSynonyms:\nprotocol/network.LoaderId\nprotocol/network LoaderId","url":"protocol/network.html#LoaderId"},{"doc":"protocol/network","title":"MonotonicTime","content":"pub type MonotonicTime {\n  MonotonicTime(Float)\n}\n Monotonically increasing time in seconds since an arbitrary point in the past.\nMonotonicTime(Float)\n\n\nSynonyms:\nprotocol/network.MonotonicTime\nprotocol/network MonotonicTime","url":"protocol/network.html#MonotonicTime"},{"doc":"protocol/network","title":"PostDataEntry","content":"pub type PostDataEntry {\n  PostDataEntry(bytes: option.Option(String))\n}\n Post data entry for HTTP request\nPostDataEntry(bytes: option.Option(String))\n\n\nSynonyms:\nprotocol/network.PostDataEntry\nprotocol/network PostDataEntry","url":"protocol/network.html#PostDataEntry"},{"doc":"protocol/network","title":"Request","content":"pub type Request {\n  Request(\n    url: String,\n    url_fragment: option.Option(String),\n    method: String,\n    headers: Headers,\n    has_post_data: option.Option(Bool),\n    mixed_content_type: option.Option(security.MixedContentType),\n    initial_priority: ResourcePriority,\n    referrer_policy: RequestReferrerPolicy,\n    is_link_preload: option.Option(Bool),\n  )\n}\n HTTP request data.\nRequest(\n  url: String,\n  url_fragment: option.Option(String),\n  method: String,\n  headers: Headers,\n  has_post_data: option.Option(Bool),\n  mixed_content_type: option.Option(security.MixedContentType),\n  initial_priority: ResourcePriority,\n  referrer_policy: RequestReferrerPolicy,\n  is_link_preload: option.Option(Bool),\n)\n\nurl\n&lt;p&gt;Request URL (without fragment).&lt;/p&gt;\n\nurl_fragment\n&lt;p&gt;Fragment of the requested URL starting with hash, if present.&lt;/p&gt;\n\nmethod\n&lt;p&gt;HTTP request method.&lt;/p&gt;\n\nheaders\n&lt;p&gt;HTTP request headers.&lt;/p&gt;\n\nhas_post_data\n&lt;p&gt;True when the request has POST data. Note that postData might still be omitted when this flag is true when the data is too long.&lt;/p&gt;\n\nmixed_content_type\n&lt;p&gt;The mixed content type of the request.&lt;/p&gt;\n\ninitial_priority\n&lt;p&gt;Priority of the resource request at the time request is sent.&lt;/p&gt;\n\nreferrer_policy\n&lt;p&gt;The referrer policy of the request, as defined in https://www.w3.org/TR/referrer-policy/&lt;/p&gt;\n\nis_link_preload\n&lt;p&gt;Whether is loaded via link preload.&lt;/p&gt;\n\nSynonyms:\nprotocol/network.Request\nprotocol/network Request","url":"protocol/network.html#Request"},{"doc":"protocol/network","title":"RequestId","content":"pub type RequestId {\n  RequestId(String)\n}\n Unique request identifier.\nRequestId(String)\n\n\nSynonyms:\nprotocol/network.RequestId\nprotocol/network RequestId","url":"protocol/network.html#RequestId"},{"doc":"protocol/network","title":"RequestReferrerPolicy","content":"pub type RequestReferrerPolicy {\n  RequestReferrerPolicyUnsafeUrl\n  RequestReferrerPolicyNoReferrerWhenDowngrade\n  RequestReferrerPolicyNoReferrer\n  RequestReferrerPolicyOrigin\n  RequestReferrerPolicyOriginWhenCrossOrigin\n  RequestReferrerPolicySameOrigin\n  RequestReferrerPolicyStrictOrigin\n  RequestReferrerPolicyStrictOriginWhenCrossOrigin\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `referrerPolicy` of `Request`\nRequestReferrerPolicyUnsafeUrl\n\n\nRequestReferrerPolicyNoReferrerWhenDowngrade\n\n\nRequestReferrerPolicyNoReferrer\n\n\nRequestReferrerPolicyOrigin\n\n\nRequestReferrerPolicyOriginWhenCrossOrigin\n\n\nRequestReferrerPolicySameOrigin\n\n\nRequestReferrerPolicyStrictOrigin\n\n\nRequestReferrerPolicyStrictOriginWhenCrossOrigin\n\n\nSynonyms:\nprotocol/network.RequestReferrerPolicy\nprotocol/network RequestReferrerPolicy","url":"protocol/network.html#RequestReferrerPolicy"},{"doc":"protocol/network","title":"ResourcePriority","content":"pub type ResourcePriority {\n  ResourcePriorityVeryLow\n  ResourcePriorityLow\n  ResourcePriorityMedium\n  ResourcePriorityHigh\n  ResourcePriorityVeryHigh\n}\n Loading priority of a resource request.\nResourcePriorityVeryLow\n\n\nResourcePriorityLow\n\n\nResourcePriorityMedium\n\n\nResourcePriorityHigh\n\n\nResourcePriorityVeryHigh\n\n\nSynonyms:\nprotocol/network.ResourcePriority\nprotocol/network ResourcePriority","url":"protocol/network.html#ResourcePriority"},{"doc":"protocol/network","title":"ResourceTiming","content":"pub type ResourceTiming {\n  ResourceTiming(\n    request_time: Float,\n    proxy_start: Float,\n    proxy_end: Float,\n    dns_start: Float,\n    dns_end: Float,\n    connect_start: Float,\n    connect_end: Float,\n    ssl_start: Float,\n    ssl_end: Float,\n    send_start: Float,\n    send_end: Float,\n    receive_headers_end: Float,\n  )\n}\n Timing information for the request.\nResourceTiming(\n  request_time: Float,\n  proxy_start: Float,\n  proxy_end: Float,\n  dns_start: Float,\n  dns_end: Float,\n  connect_start: Float,\n  connect_end: Float,\n  ssl_start: Float,\n  ssl_end: Float,\n  send_start: Float,\n  send_end: Float,\n  receive_headers_end: Float,\n)\n\nrequest_time\n&lt;p&gt;Timing’s requestTime is a baseline in seconds, while the other numbers are ticks in\nmilliseconds relatively to this requestTime.&lt;/p&gt;\n\nproxy_start\n&lt;p&gt;Started resolving proxy.&lt;/p&gt;\n\nproxy_end\n&lt;p&gt;Finished resolving proxy.&lt;/p&gt;\n\ndns_start\n&lt;p&gt;Started DNS address resolve.&lt;/p&gt;\n\ndns_end\n&lt;p&gt;Finished DNS address resolve.&lt;/p&gt;\n\nconnect_start\n&lt;p&gt;Started connecting to the remote host.&lt;/p&gt;\n\nconnect_end\n&lt;p&gt;Connected to the remote host.&lt;/p&gt;\n\nssl_start\n&lt;p&gt;Started SSL handshake.&lt;/p&gt;\n\nssl_end\n&lt;p&gt;Finished SSL handshake.&lt;/p&gt;\n\nsend_start\n&lt;p&gt;Started sending request.&lt;/p&gt;\n\nsend_end\n&lt;p&gt;Finished sending request.&lt;/p&gt;\n\nreceive_headers_end\n&lt;p&gt;Finished receiving response headers.&lt;/p&gt;\n\nSynonyms:\nprotocol/network.ResourceTiming\nprotocol/network ResourceTiming","url":"protocol/network.html#ResourceTiming"},{"doc":"protocol/network","title":"ResourceType","content":"pub type ResourceType {\n  ResourceTypeDocument\n  ResourceTypeStylesheet\n  ResourceTypeImage\n  ResourceTypeMedia\n  ResourceTypeFont\n  ResourceTypeScript\n  ResourceTypeTextTrack\n  ResourceTypeXhr\n  ResourceTypeFetch\n  ResourceTypePrefetch\n  ResourceTypeEventSource\n  ResourceTypeWebSocket\n  ResourceTypeManifest\n  ResourceTypeSignedExchange\n  ResourceTypePing\n  ResourceTypeCspViolationReport\n  ResourceTypePreflight\n  ResourceTypeOther\n}\n Resource type as it was perceived by the rendering engine.\nResourceTypeDocument\n\n\nResourceTypeStylesheet\n\n\nResourceTypeImage\n\n\nResourceTypeMedia\n\n\nResourceTypeFont\n\n\nResourceTypeScript\n\n\nResourceTypeTextTrack\n\n\nResourceTypeXhr\n\n\nResourceTypeFetch\n\n\nResourceTypePrefetch\n\n\nResourceTypeEventSource\n\n\nResourceTypeWebSocket\n\n\nResourceTypeManifest\n\n\nResourceTypeSignedExchange\n\n\nResourceTypePing\n\n\nResourceTypeCspViolationReport\n\n\nResourceTypePreflight\n\n\nResourceTypeOther\n\n\nSynonyms:\nprotocol/network.ResourceType\nprotocol/network ResourceType","url":"protocol/network.html#ResourceType"},{"doc":"protocol/network","title":"Response","content":"pub type Response {\n  Response(\n    url: String,\n    status: Int,\n    status_text: String,\n    headers: Headers,\n    mime_type: String,\n    charset: String,\n    request_headers: option.Option(Headers),\n    connection_reused: Bool,\n    connection_id: Float,\n    remote_ip_address: option.Option(String),\n    remote_port: option.Option(Int),\n    from_disk_cache: option.Option(Bool),\n    from_service_worker: option.Option(Bool),\n    from_prefetch_cache: option.Option(Bool),\n    from_early_hints: option.Option(Bool),\n    encoded_data_length: Float,\n    timing: option.Option(ResourceTiming),\n    service_worker_response_source: option.Option(\n      ServiceWorkerResponseSource,\n    ),\n    response_time: option.Option(TimeSinceEpoch),\n    cache_storage_cache_name: option.Option(String),\n    protocol: option.Option(String),\n    security_state: security.SecurityState,\n    security_details: option.Option(SecurityDetails),\n  )\n}\n HTTP response data.\nResponse(\n  url: String,\n  status: Int,\n  status_text: String,\n  headers: Headers,\n  mime_type: String,\n  charset: String,\n  request_headers: option.Option(Headers),\n  connection_reused: Bool,\n  connection_id: Float,\n  remote_ip_address: option.Option(String),\n  remote_port: option.Option(Int),\n  from_disk_cache: option.Option(Bool),\n  from_service_worker: option.Option(Bool),\n  from_prefetch_cache: option.Option(Bool),\n  from_early_hints: option.Option(Bool),\n  encoded_data_length: Float,\n  timing: option.Option(ResourceTiming),\n  service_worker_response_source: option.Option(\n    ServiceWorkerResponseSource,\n  ),\n  response_time: option.Option(TimeSinceEpoch),\n  cache_storage_cache_name: option.Option(String),\n  protocol: option.Option(String),\n  security_state: security.SecurityState,\n  security_details: option.Option(SecurityDetails),\n)\n\nurl\n&lt;p&gt;Response URL. This URL can be different from CachedResource.url in case of redirect.&lt;/p&gt;\n\nstatus\n&lt;p&gt;HTTP response status code.&lt;/p&gt;\n\nstatus_text\n&lt;p&gt;HTTP response status text.&lt;/p&gt;\n\nheaders\n&lt;p&gt;HTTP response headers.&lt;/p&gt;\n\nmime_type\n&lt;p&gt;Resource mimeType as determined by the browser.&lt;/p&gt;\n\ncharset\n&lt;p&gt;Resource charset as determined by the browser (if applicable).&lt;/p&gt;\n\nrequest_headers\n&lt;p&gt;Refined HTTP request headers that were actually transmitted over the network.&lt;/p&gt;\n\nconnection_reused\n&lt;p&gt;Specifies whether physical connection was actually reused for this request.&lt;/p&gt;\n\nconnection_id\n&lt;p&gt;Physical connection id that was actually used for this request.&lt;/p&gt;\n\nremote_ip_address\n&lt;p&gt;Remote IP address.&lt;/p&gt;\n\nremote_port\n&lt;p&gt;Remote port.&lt;/p&gt;\n\nfrom_disk_cache\n&lt;p&gt;Specifies that the request was served from the disk cache.&lt;/p&gt;\n\nfrom_service_worker\n&lt;p&gt;Specifies that the request was served from the ServiceWorker.&lt;/p&gt;\n\nfrom_prefetch_cache\n&lt;p&gt;Specifies that the request was served from the prefetch cache.&lt;/p&gt;\n\nfrom_early_hints\n&lt;p&gt;Specifies that the request was served from the prefetch cache.&lt;/p&gt;\n\nencoded_data_length\n&lt;p&gt;Total number of bytes received for this request so far.&lt;/p&gt;\n\ntiming\n&lt;p&gt;Timing information for the given request.&lt;/p&gt;\n\nservice_worker_response_source\n&lt;p&gt;Response source of response from ServiceWorker.&lt;/p&gt;\n\nresponse_time\n&lt;p&gt;The time at which the returned response was generated.&lt;/p&gt;\n\ncache_storage_cache_name\n&lt;p&gt;Cache Storage Cache Name.&lt;/p&gt;\n\nprotocol\n&lt;p&gt;Protocol used to fetch this request.&lt;/p&gt;\n\nsecurity_state\n&lt;p&gt;Security state of the request resource.&lt;/p&gt;\n\nsecurity_details\n&lt;p&gt;Security details for the request.&lt;/p&gt;\n\nSynonyms:\nprotocol/network.Response\nprotocol/network Response","url":"protocol/network.html#Response"},{"doc":"protocol/network","title":"SecurityDetails","content":"pub type SecurityDetails {\n  SecurityDetails(\n    protocol: String,\n    key_exchange: String,\n    key_exchange_group: option.Option(String),\n    cipher: String,\n    mac: option.Option(String),\n    certificate_id: security.CertificateId,\n    subject_name: String,\n    san_list: List(String),\n    issuer: String,\n    valid_from: TimeSinceEpoch,\n    valid_to: TimeSinceEpoch,\n    signed_certificate_timestamp_list: List(\n      SignedCertificateTimestamp,\n    ),\n    certificate_transparency_compliance: CertificateTransparencyCompliance,\n    server_signature_algorithm: option.Option(Int),\n    encrypted_client_hello: Bool,\n  )\n}\n Security details about a request.\nSecurityDetails(\n  protocol: String,\n  key_exchange: String,\n  key_exchange_group: option.Option(String),\n  cipher: String,\n  mac: option.Option(String),\n  certificate_id: security.CertificateId,\n  subject_name: String,\n  san_list: List(String),\n  issuer: String,\n  valid_from: TimeSinceEpoch,\n  valid_to: TimeSinceEpoch,\n  signed_certificate_timestamp_list: List(\n    SignedCertificateTimestamp,\n  ),\n  certificate_transparency_compliance: CertificateTransparencyCompliance,\n  server_signature_algorithm: option.Option(Int),\n  encrypted_client_hello: Bool,\n)\n\nprotocol\n&lt;p&gt;Protocol name (e.g. “TLS 1.2” or “QUIC”).&lt;/p&gt;\n\nkey_exchange\n&lt;p&gt;Key Exchange used by the connection, or the empty string if not applicable.&lt;/p&gt;\n\nkey_exchange_group\n&lt;p&gt;(EC)DH group used by the connection, if applicable.&lt;/p&gt;\n\ncipher\n&lt;p&gt;Cipher name.&lt;/p&gt;\n\nmac\n&lt;p&gt;TLS MAC. Note that AEAD ciphers do not have separate MACs.&lt;/p&gt;\n\ncertificate_id\n&lt;p&gt;Certificate ID value.&lt;/p&gt;\n\nsubject_name\n&lt;p&gt;Certificate subject name.&lt;/p&gt;\n\nsan_list\n&lt;p&gt;Subject Alternative Name (SAN) DNS names and IP addresses.&lt;/p&gt;\n\nissuer\n&lt;p&gt;Name of the issuing CA.&lt;/p&gt;\n\nvalid_from\n&lt;p&gt;Certificate valid from date.&lt;/p&gt;\n\nvalid_to\n&lt;p&gt;Certificate valid to (expiration) date&lt;/p&gt;\n\nsigned_certificate_timestamp_list\n&lt;p&gt;List of signed certificate timestamps (SCTs).&lt;/p&gt;\n\ncertificate_transparency_compliance\n&lt;p&gt;Whether the request complied with Certificate Transparency policy&lt;/p&gt;\n\nserver_signature_algorithm\n&lt;p&gt;The signature algorithm used by the server in the TLS server signature,\nrepresented as a TLS SignatureScheme code point. Omitted if not\napplicable or not known.&lt;/p&gt;\n\nencrypted_client_hello\n&lt;p&gt;Whether the connection used Encrypted ClientHello&lt;/p&gt;\n\nSynonyms:\nprotocol/network.SecurityDetails\nprotocol/network SecurityDetails","url":"protocol/network.html#SecurityDetails"},{"doc":"protocol/network","title":"ServiceWorkerResponseSource","content":"pub type ServiceWorkerResponseSource {\n  ServiceWorkerResponseSourceCacheStorage\n  ServiceWorkerResponseSourceHttpCache\n  ServiceWorkerResponseSourceFallbackCode\n  ServiceWorkerResponseSourceNetwork\n}\n Source of serviceworker response.\nServiceWorkerResponseSourceCacheStorage\n\n\nServiceWorkerResponseSourceHttpCache\n\n\nServiceWorkerResponseSourceFallbackCode\n\n\nServiceWorkerResponseSourceNetwork\n\n\nSynonyms:\nprotocol/network.ServiceWorkerResponseSource\nprotocol/network ServiceWorkerResponseSource","url":"protocol/network.html#ServiceWorkerResponseSource"},{"doc":"protocol/network","title":"ServiceWorkerRouterSource","content":"pub type ServiceWorkerRouterSource {\n  ServiceWorkerRouterSourceNetwork\n  ServiceWorkerRouterSourceCache\n  ServiceWorkerRouterSourceFetchEvent\n  ServiceWorkerRouterSourceRaceNetworkAndFetchHandler\n}\n Source of service worker router.\nServiceWorkerRouterSourceNetwork\n\n\nServiceWorkerRouterSourceCache\n\n\nServiceWorkerRouterSourceFetchEvent\n\n\nServiceWorkerRouterSourceRaceNetworkAndFetchHandler\n\n\nSynonyms:\nprotocol/network.ServiceWorkerRouterSource\nprotocol/network ServiceWorkerRouterSource","url":"protocol/network.html#ServiceWorkerRouterSource"},{"doc":"protocol/network","title":"SignedCertificateTimestamp","content":"pub type SignedCertificateTimestamp {\n  SignedCertificateTimestamp(\n    status: String,\n    origin: String,\n    log_description: String,\n    log_id: String,\n    timestamp: Float,\n    hash_algorithm: String,\n    signature_algorithm: String,\n    signature_data: String,\n  )\n}\n Details of a signed certificate timestamp (SCT).\nSignedCertificateTimestamp(\n  status: String,\n  origin: String,\n  log_description: String,\n  log_id: String,\n  timestamp: Float,\n  hash_algorithm: String,\n  signature_algorithm: String,\n  signature_data: String,\n)\n\nstatus\n&lt;p&gt;Validation status.&lt;/p&gt;\n\norigin\n&lt;p&gt;Origin.&lt;/p&gt;\n\nlog_description\n&lt;p&gt;Log name / description.&lt;/p&gt;\n\nlog_id\n&lt;p&gt;Log ID.&lt;/p&gt;\n\ntimestamp\n&lt;p&gt;Issuance date. Unlike TimeSinceEpoch, this contains the number of\nmilliseconds since January 1, 1970, UTC, not the number of seconds.&lt;/p&gt;\n\nhash_algorithm\n&lt;p&gt;Hash algorithm.&lt;/p&gt;\n\nsignature_algorithm\n&lt;p&gt;Signature algorithm.&lt;/p&gt;\n\nsignature_data\n&lt;p&gt;Signature data.&lt;/p&gt;\n\nSynonyms:\nprotocol/network.SignedCertificateTimestamp\nprotocol/network SignedCertificateTimestamp","url":"protocol/network.html#SignedCertificateTimestamp"},{"doc":"protocol/network","title":"TimeSinceEpoch","content":"pub type TimeSinceEpoch {\n  TimeSinceEpoch(Float)\n}\n UTC time in seconds, counted from January 1, 1970.\nTimeSinceEpoch(Float)\n\n\nSynonyms:\nprotocol/network.TimeSinceEpoch\nprotocol/network TimeSinceEpoch","url":"protocol/network.html#TimeSinceEpoch"},{"doc":"protocol/network","title":"WebSocketFrame","content":"pub type WebSocketFrame {\n  WebSocketFrame(opcode: Float, mask: Bool, payload_data: String)\n}\n WebSocket message data. This represents an entire WebSocket message, not just a fragmented frame as the name suggests.\nWebSocketFrame(opcode: Float, mask: Bool, payload_data: String)\n\nopcode\n&lt;p&gt;WebSocket message opcode.&lt;/p&gt;\n\nmask\n&lt;p&gt;WebSocket message mask.&lt;/p&gt;\n\npayload_data\n&lt;p&gt;WebSocket message payload data.\nIf the opcode is 1, this is a text message and payloadData is a UTF-8 string.\nIf the opcode isn’t 1, then payloadData is a base64 encoded string representing binary data.&lt;/p&gt;\n\nSynonyms:\nprotocol/network.WebSocketFrame\nprotocol/network WebSocketFrame","url":"protocol/network.html#WebSocketFrame"},{"doc":"protocol/network","title":"WebSocketRequest","content":"pub type WebSocketRequest {\n  WebSocketRequest(headers: Headers)\n}\n WebSocket request data.\nWebSocketRequest(headers: Headers)\n\nheaders\n&lt;p&gt;HTTP request headers.&lt;/p&gt;\n\nSynonyms:\nprotocol/network.WebSocketRequest\nprotocol/network WebSocketRequest","url":"protocol/network.html#WebSocketRequest"},{"doc":"protocol/network","title":"WebSocketResponse","content":"pub type WebSocketResponse {\n  WebSocketResponse(\n    status: Int,\n    status_text: String,\n    headers: Headers,\n    headers_text: option.Option(String),\n    request_headers: option.Option(Headers),\n    request_headers_text: option.Option(String),\n  )\n}\n WebSocket response data.\nWebSocketResponse(\n  status: Int,\n  status_text: String,\n  headers: Headers,\n  headers_text: option.Option(String),\n  request_headers: option.Option(Headers),\n  request_headers_text: option.Option(String),\n)\n\nstatus\n&lt;p&gt;HTTP response status code.&lt;/p&gt;\n\nstatus_text\n&lt;p&gt;HTTP response status text.&lt;/p&gt;\n\nheaders\n&lt;p&gt;HTTP response headers.&lt;/p&gt;\n\nheaders_text\n&lt;p&gt;HTTP response headers text.&lt;/p&gt;\n\nrequest_headers\n&lt;p&gt;HTTP request headers.&lt;/p&gt;\n\nrequest_headers_text\n&lt;p&gt;HTTP request headers text.&lt;/p&gt;\n\nSynonyms:\nprotocol/network.WebSocketResponse\nprotocol/network WebSocketResponse","url":"protocol/network.html#WebSocketResponse"},{"doc":"protocol/network","title":"clear_browser_cache","content":"pub fn clear_browser_cache(\n  callback__: fn(String, Option(a)) -&gt; b,\n) -&gt; b\n Clears browser cache.\n \nSynonyms:\nprotocol/network.clear_browser_cache\nprotocol/network clear_browser_cache","url":"protocol/network.html#clear_browser_cache"},{"doc":"protocol/network","title":"clear_browser_cookies","content":"pub fn clear_browser_cookies(\n  callback__: fn(String, Option(a)) -&gt; b,\n) -&gt; b\n Clears browser cookies.\n \nSynonyms:\nprotocol/network.clear_browser_cookies\nprotocol/network clear_browser_cookies","url":"protocol/network.html#clear_browser_cookies"},{"doc":"protocol/network","title":"delete_cookies","content":"pub fn delete_cookies(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  name name: String,\n  url url: Option(String),\n  domain domain: Option(String),\n  path path: Option(String),\n  partition_key partition_key: Option(String),\n) -&gt; a\n Deletes browser cookies with matching name and url or domain/path/partitionKey pair.\n \n Parameters:  \n  - `name` : Name of the cookies to remove.\n  - `url` : If specified, deletes all the cookies with the given name where domain and path match\n provided URL.\n  - `domain` : If specified, deletes only cookies with the exact domain.\n  - `path` : If specified, deletes only cookies with the exact path.\n  - `partition_key` : If specified, deletes only cookies with the the given name and partitionKey where domain\n matches provided URL.\n \n Returns:  \n \nSynonyms:\nprotocol/network.delete_cookies\nprotocol/network delete_cookies","url":"protocol/network.html#delete_cookies"},{"doc":"protocol/network","title":"disable","content":"pub fn disable(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n Disables network tracking, prevents network events from being sent to the client.\n \nSynonyms:\nprotocol/network.disable\nprotocol/network disable","url":"protocol/network.html#disable"},{"doc":"protocol/network","title":"emulate_network_conditions","content":"pub fn emulate_network_conditions(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  offline offline: Bool,\n  latency latency: Float,\n  download_throughput download_throughput: Float,\n  upload_throughput upload_throughput: Float,\n  connection_type connection_type: Option(ConnectionType),\n) -&gt; a\n Activates emulation of network conditions.\n \n Parameters:  \n  - `offline` : True to emulate internet disconnection.\n  - `latency` : Minimum latency from request sent to response headers received (ms).\n  - `download_throughput` : Maximal aggregated download throughput (bytes/sec). -1 disables download throttling.\n  - `upload_throughput` : Maximal aggregated upload throughput (bytes/sec).  -1 disables upload throttling.\n  - `connection_type` : Connection type if known.\n \n Returns:  \n \nSynonyms:\nprotocol/network.emulate_network_conditions\nprotocol/network emulate_network_conditions","url":"protocol/network.html#emulate_network_conditions"},{"doc":"protocol/network","title":"enable","content":"pub fn enable(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  max_post_data_size max_post_data_size: Option(Int),\n) -&gt; a\n Enables network tracking, network events will now be delivered to the client.\n \n Parameters:  \n  - `max_post_data_size` : Longest post body size (in bytes) that would be included in requestWillBeSent notification\n \n Returns:  \n \nSynonyms:\nprotocol/network.enable\nprotocol/network enable","url":"protocol/network.html#enable"},{"doc":"protocol/network","title":"get_cookies","content":"pub fn get_cookies(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  urls urls: Option(List(String)),\n) -&gt; Result(GetCookiesResponse, RequestError)\n Returns all browser cookies for the current URL. Depending on the backend support, will return\n detailed cookie information in the `cookies` field.\n \n Parameters:  \n  - `urls` : The list of URLs for which applicable cookies will be fetched.\n If not specified, it&#39;s assumed to be set to the list containing\n the URLs of the page and all of its subframes.\n \n Returns:  \n  - `cookies` : Array of cookie objects.\n \nSynonyms:\nprotocol/network.get_cookies\nprotocol/network get_cookies","url":"protocol/network.html#get_cookies"},{"doc":"protocol/network","title":"get_request_post_data","content":"pub fn get_request_post_data(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  request_id request_id: RequestId,\n) -&gt; Result(GetRequestPostDataResponse, RequestError)\n Returns post data sent with the request. Returns an error when no data was sent with the request.\n \n Parameters:  \n  - `request_id` : Identifier of the network request to get content for.\n \n Returns:  \n  - `post_data` : Request body string, omitting files from multipart requests\n \nSynonyms:\nprotocol/network.get_request_post_data\nprotocol/network get_request_post_data","url":"protocol/network.html#get_request_post_data"},{"doc":"protocol/network","title":"get_response_body","content":"pub fn get_response_body(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  request_id request_id: RequestId,\n) -&gt; Result(GetResponseBodyResponse, RequestError)\n Returns content served for the given request.\n \n Parameters:  \n  - `request_id` : Identifier of the network request to get content for.\n \n Returns:  \n  - `body` : Response body.\n  - `base64_encoded` : True, if content was sent as base64.\n \nSynonyms:\nprotocol/network.get_response_body\nprotocol/network get_response_body","url":"protocol/network.html#get_response_body"},{"doc":"protocol/network","title":"set_bypass_service_worker","content":"pub fn set_bypass_service_worker(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  bypass bypass: Bool,\n) -&gt; a\n Toggles ignoring of service worker for each request.\n \n Parameters:  \n  - `bypass` : Bypass service worker and load from network.\n \n Returns:  \n \nSynonyms:\nprotocol/network.set_bypass_service_worker\nprotocol/network set_bypass_service_worker","url":"protocol/network.html#set_bypass_service_worker"},{"doc":"protocol/network","title":"set_cache_disabled","content":"pub fn set_cache_disabled(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  cache_disabled cache_disabled: Bool,\n) -&gt; a\n Toggles ignoring cache for each request. If `true`, cache will not be used.\n \n Parameters:  \n  - `cache_disabled` : Cache disabled state.\n \n Returns:  \n \nSynonyms:\nprotocol/network.set_cache_disabled\nprotocol/network set_cache_disabled","url":"protocol/network.html#set_cache_disabled"},{"doc":"protocol/network","title":"set_cookie","content":"pub fn set_cookie(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  name name: String,\n  value value: String,\n  url url: Option(String),\n  domain domain: Option(String),\n  path path: Option(String),\n  secure secure: Option(Bool),\n  http_only http_only: Option(Bool),\n  same_site same_site: Option(CookieSameSite),\n  expires expires: Option(TimeSinceEpoch),\n) -&gt; a\n Sets a cookie with the given cookie data; may overwrite equivalent cookies if they exist.\n \n Parameters:  \n  - `name` : Cookie name.\n  - `value` : Cookie value.\n  - `url` : The request-URI to associate with the setting of the cookie. This value can affect the\n default domain, path, source port, and source scheme values of the created cookie.\n  - `domain` : Cookie domain.\n  - `path` : Cookie path.\n  - `secure` : True if cookie is secure.\n  - `http_only` : True if cookie is http-only.\n  - `same_site` : Cookie SameSite type.\n  - `expires` : Cookie expiration date, session cookie if not set\n \n Returns:  \n \nSynonyms:\nprotocol/network.set_cookie\nprotocol/network set_cookie","url":"protocol/network.html#set_cookie"},{"doc":"protocol/network","title":"set_cookies","content":"pub fn set_cookies(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  cookies cookies: List(CookieParam),\n) -&gt; a\n Sets given cookies.\n \n Parameters:  \n  - `cookies` : Cookies to be set.\n \n Returns:  \n \nSynonyms:\nprotocol/network.set_cookies\nprotocol/network set_cookies","url":"protocol/network.html#set_cookies"},{"doc":"protocol/network","title":"set_extra_http_headers","content":"pub fn set_extra_http_headers(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  headers headers: Headers,\n) -&gt; a\n Specifies whether to always send extra HTTP headers with the requests from this page.\n \n Parameters:  \n  - `headers` : Map with extra HTTP headers.\n \n Returns:  \n \nSynonyms:\nprotocol/network.set_extra_http_headers\nprotocol/network set_extra_http_headers","url":"protocol/network.html#set_extra_http_headers"},{"doc":"protocol/network","title":"set_user_agent_override","content":"pub fn set_user_agent_override(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  user_agent user_agent: String,\n  accept_language accept_language: Option(String),\n  platform platform: Option(String),\n) -&gt; a\n Allows overriding user agent with the given string.\n \n Parameters:  \n  - `user_agent` : User agent to use.\n  - `accept_language` : Browser language to emulate.\n  - `platform` : The platform navigator.platform should return.\n \n Returns:  \n \nSynonyms:\nprotocol/network.set_user_agent_override\nprotocol/network set_user_agent_override","url":"protocol/network.html#set_user_agent_override"},{"doc":"protocol/network","title":"protocol/network","content":" &gt; ⚙️  This module was generated from the Chrome DevTools Protocol version **1.3**\n ## Network Domain  \n\n Network domain allows tracking network activities of the page. It exposes information about http,\n file, data and other requests and responses, their headers, bodies, timing, etc.  \n\n [📖   View this domain on the DevTools Protocol API Docs](https://chromedevtools.github.io/devtools-protocol/1-3/Network/)","url":"protocol/network.html"},{"doc":"protocol/page","title":"AddScriptToEvaluateOnNewDocumentResponse","content":"pub type AddScriptToEvaluateOnNewDocumentResponse {\n  AddScriptToEvaluateOnNewDocumentResponse(\n    identifier: ScriptIdentifier,\n  )\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `add_script_to_evaluate_on_new_document`\nAddScriptToEvaluateOnNewDocumentResponse(\n  identifier: ScriptIdentifier,\n)\n\nidentifier\n&lt;p&gt;Identifier of the added script.&lt;/p&gt;\n\nSynonyms:\nprotocol/page.AddScriptToEvaluateOnNewDocumentResponse\nprotocol/page AddScriptToEvaluateOnNewDocumentResponse","url":"protocol/page.html#AddScriptToEvaluateOnNewDocumentResponse"},{"doc":"protocol/page","title":"AppManifestError","content":"pub type AppManifestError {\n  AppManifestError(\n    message: String,\n    critical: Int,\n    line: Int,\n    column: Int,\n  )\n}\n Error while paring app manifest.\nAppManifestError(\n  message: String,\n  critical: Int,\n  line: Int,\n  column: Int,\n)\n\nmessage\n&lt;p&gt;Error message.&lt;/p&gt;\n\ncritical\n&lt;p&gt;If critical, this is a non-recoverable parse error.&lt;/p&gt;\n\nline\n&lt;p&gt;Error line.&lt;/p&gt;\n\ncolumn\n&lt;p&gt;Error column.&lt;/p&gt;\n\nSynonyms:\nprotocol/page.AppManifestError\nprotocol/page AppManifestError","url":"protocol/page.html#AppManifestError"},{"doc":"protocol/page","title":"CaptureScreenshotFormat","content":"pub type CaptureScreenshotFormat {\n  CaptureScreenshotFormatJpeg\n  CaptureScreenshotFormatPng\n  CaptureScreenshotFormatWebp\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `format` of `captureScreenshot`\nCaptureScreenshotFormatJpeg\n\n\nCaptureScreenshotFormatPng\n\n\nCaptureScreenshotFormatWebp\n\n\nSynonyms:\nprotocol/page.CaptureScreenshotFormat\nprotocol/page CaptureScreenshotFormat","url":"protocol/page.html#CaptureScreenshotFormat"},{"doc":"protocol/page","title":"CaptureScreenshotResponse","content":"pub type CaptureScreenshotResponse {\n  CaptureScreenshotResponse(data: String)\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `capture_screenshot`\nCaptureScreenshotResponse(data: String)\n\ndata\n&lt;p&gt;Base64-encoded image data. (Encoded as a base64 string when passed over JSON)&lt;/p&gt;\n\nSynonyms:\nprotocol/page.CaptureScreenshotResponse\nprotocol/page CaptureScreenshotResponse","url":"protocol/page.html#CaptureScreenshotResponse"},{"doc":"protocol/page","title":"CreateIsolatedWorldResponse","content":"pub type CreateIsolatedWorldResponse {\n  CreateIsolatedWorldResponse(\n    execution_context_id: runtime.ExecutionContextId,\n  )\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `create_isolated_world`\nCreateIsolatedWorldResponse(\n  execution_context_id: runtime.ExecutionContextId,\n)\n\nexecution_context_id\n&lt;p&gt;Execution context of the isolated world.&lt;/p&gt;\n\nSynonyms:\nprotocol/page.CreateIsolatedWorldResponse\nprotocol/page CreateIsolatedWorldResponse","url":"protocol/page.html#CreateIsolatedWorldResponse"},{"doc":"protocol/page","title":"DialogType","content":"pub type DialogType {\n  DialogTypeAlert\n  DialogTypeConfirm\n  DialogTypePrompt\n  DialogTypeBeforeunload\n}\n Javascript dialog type.\nDialogTypeAlert\n\n\nDialogTypeConfirm\n\n\nDialogTypePrompt\n\n\nDialogTypeBeforeunload\n\n\nSynonyms:\nprotocol/page.DialogType\nprotocol/page DialogType","url":"protocol/page.html#DialogType"},{"doc":"protocol/page","title":"Frame","content":"pub type Frame {\n  Frame(\n    id: FrameId,\n    parent_id: option.Option(FrameId),\n    loader_id: network.LoaderId,\n    name: option.Option(String),\n    url: String,\n    security_origin: String,\n    mime_type: String,\n  )\n}\n Information about the Frame on the page.\nFrame(\n  id: FrameId,\n  parent_id: option.Option(FrameId),\n  loader_id: network.LoaderId,\n  name: option.Option(String),\n  url: String,\n  security_origin: String,\n  mime_type: String,\n)\n\nid\n&lt;p&gt;Frame unique identifier.&lt;/p&gt;\n\nparent_id\n&lt;p&gt;Parent frame identifier.&lt;/p&gt;\n\nloader_id\n&lt;p&gt;Identifier of the loader associated with this frame.&lt;/p&gt;\n\nname\n&lt;p&gt;Frame’s name as specified in the tag.&lt;/p&gt;\n\nurl\n&lt;p&gt;Frame document’s URL without fragment.&lt;/p&gt;\n\nsecurity_origin\n&lt;p&gt;Frame document’s security origin.&lt;/p&gt;\n\nmime_type\n&lt;p&gt;Frame document’s mimeType as determined by the browser.&lt;/p&gt;\n\nSynonyms:\nprotocol/page.Frame\nprotocol/page Frame","url":"protocol/page.html#Frame"},{"doc":"protocol/page","title":"FrameId","content":"pub type FrameId {\n  FrameId(String)\n}\n Unique frame identifier.\nFrameId(String)\n\n\nSynonyms:\nprotocol/page.FrameId\nprotocol/page FrameId","url":"protocol/page.html#FrameId"},{"doc":"protocol/page","title":"FrameTree","content":"pub type FrameTree {\n  FrameTree(\n    frame: Frame,\n    child_frames: option.Option(List(FrameTree)),\n  )\n}\n Information about the Frame hierarchy.\nFrameTree(\n  frame: Frame,\n  child_frames: option.Option(List(FrameTree)),\n)\n\nframe\n&lt;p&gt;Frame information for this tree item.&lt;/p&gt;\n\nchild_frames\n&lt;p&gt;Child frames.&lt;/p&gt;\n\nSynonyms:\nprotocol/page.FrameTree\nprotocol/page FrameTree","url":"protocol/page.html#FrameTree"},{"doc":"protocol/page","title":"GetAppManifestResponse","content":"pub type GetAppManifestResponse {\n  GetAppManifestResponse(\n    url: String,\n    errors: List(AppManifestError),\n    data: option.Option(String),\n  )\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `get_app_manifest`\nGetAppManifestResponse(\n  url: String,\n  errors: List(AppManifestError),\n  data: option.Option(String),\n)\n\nurl\n&lt;p&gt;Manifest location.&lt;/p&gt;\n\ndata\n&lt;p&gt;Manifest content.&lt;/p&gt;\n\nSynonyms:\nprotocol/page.GetAppManifestResponse\nprotocol/page GetAppManifestResponse","url":"protocol/page.html#GetAppManifestResponse"},{"doc":"protocol/page","title":"GetFrameTreeResponse","content":"pub type GetFrameTreeResponse {\n  GetFrameTreeResponse(frame_tree: FrameTree)\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `get_frame_tree`\nGetFrameTreeResponse(frame_tree: FrameTree)\n\nframe_tree\n&lt;p&gt;Present frame tree structure.&lt;/p&gt;\n\nSynonyms:\nprotocol/page.GetFrameTreeResponse\nprotocol/page GetFrameTreeResponse","url":"protocol/page.html#GetFrameTreeResponse"},{"doc":"protocol/page","title":"GetLayoutMetricsResponse","content":"pub type GetLayoutMetricsResponse {\n  GetLayoutMetricsResponse(\n    css_layout_viewport: LayoutViewport,\n    css_visual_viewport: VisualViewport,\n    css_content_size: dom.Rect,\n  )\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `get_layout_metrics`\nGetLayoutMetricsResponse(\n  css_layout_viewport: LayoutViewport,\n  css_visual_viewport: VisualViewport,\n  css_content_size: dom.Rect,\n)\n\ncss_layout_viewport\n&lt;p&gt;Metrics relating to the layout viewport in CSS pixels.&lt;/p&gt;\n\ncss_visual_viewport\n&lt;p&gt;Metrics relating to the visual viewport in CSS pixels.&lt;/p&gt;\n\ncss_content_size\n&lt;p&gt;Size of scrollable area in CSS pixels.&lt;/p&gt;\n\nSynonyms:\nprotocol/page.GetLayoutMetricsResponse\nprotocol/page GetLayoutMetricsResponse","url":"protocol/page.html#GetLayoutMetricsResponse"},{"doc":"protocol/page","title":"GetNavigationHistoryResponse","content":"pub type GetNavigationHistoryResponse {\n  GetNavigationHistoryResponse(\n    current_index: Int,\n    entries: List(NavigationEntry),\n  )\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `get_navigation_history`\nGetNavigationHistoryResponse(\n  current_index: Int,\n  entries: List(NavigationEntry),\n)\n\ncurrent_index\n&lt;p&gt;Index of the current navigation history entry.&lt;/p&gt;\n\nentries\n&lt;p&gt;Array of navigation history entries.&lt;/p&gt;\n\nSynonyms:\nprotocol/page.GetNavigationHistoryResponse\nprotocol/page GetNavigationHistoryResponse","url":"protocol/page.html#GetNavigationHistoryResponse"},{"doc":"protocol/page","title":"LayoutViewport","content":"pub type LayoutViewport {\n  LayoutViewport(\n    page_x: Int,\n    page_y: Int,\n    client_width: Int,\n    client_height: Int,\n  )\n}\n Layout viewport position and dimensions.\nLayoutViewport(\n  page_x: Int,\n  page_y: Int,\n  client_width: Int,\n  client_height: Int,\n)\n\npage_x\n&lt;p&gt;Horizontal offset relative to the document (CSS pixels).&lt;/p&gt;\n\npage_y\n&lt;p&gt;Vertical offset relative to the document (CSS pixels).&lt;/p&gt;\n\nclient_width\n&lt;p&gt;Width (CSS pixels), excludes scrollbar if present.&lt;/p&gt;\n\nclient_height\n&lt;p&gt;Height (CSS pixels), excludes scrollbar if present.&lt;/p&gt;\n\nSynonyms:\nprotocol/page.LayoutViewport\nprotocol/page LayoutViewport","url":"protocol/page.html#LayoutViewport"},{"doc":"protocol/page","title":"NavigateResponse","content":"pub type NavigateResponse {\n  NavigateResponse(\n    frame_id: FrameId,\n    loader_id: option.Option(network.LoaderId),\n    error_text: option.Option(String),\n  )\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `navigate`\nNavigateResponse(\n  frame_id: FrameId,\n  loader_id: option.Option(network.LoaderId),\n  error_text: option.Option(String),\n)\n\nframe_id\n&lt;p&gt;Frame id that has navigated (or failed to navigate)&lt;/p&gt;\n\nloader_id\n&lt;p&gt;Loader identifier. This is omitted in case of same-document navigation,\nas the previously committed loaderId would not change.&lt;/p&gt;\n\nerror_text\n&lt;p&gt;User friendly error message, present if and only if navigation has failed.&lt;/p&gt;\n\nSynonyms:\nprotocol/page.NavigateResponse\nprotocol/page NavigateResponse","url":"protocol/page.html#NavigateResponse"},{"doc":"protocol/page","title":"NavigationEntry","content":"pub type NavigationEntry {\n  NavigationEntry(\n    id: Int,\n    url: String,\n    user_typed_url: String,\n    title: String,\n    transition_type: TransitionType,\n  )\n}\n Navigation history entry.\nNavigationEntry(\n  id: Int,\n  url: String,\n  user_typed_url: String,\n  title: String,\n  transition_type: TransitionType,\n)\n\nid\n&lt;p&gt;Unique id of the navigation history entry.&lt;/p&gt;\n\nurl\n&lt;p&gt;URL of the navigation history entry.&lt;/p&gt;\n\nuser_typed_url\n&lt;p&gt;URL that the user typed in the url bar.&lt;/p&gt;\n\ntitle\n&lt;p&gt;Title of the navigation history entry.&lt;/p&gt;\n\ntransition_type\n&lt;p&gt;Transition type.&lt;/p&gt;\n\nSynonyms:\nprotocol/page.NavigationEntry\nprotocol/page NavigationEntry","url":"protocol/page.html#NavigationEntry"},{"doc":"protocol/page","title":"PrintToPdfResponse","content":"pub type PrintToPdfResponse {\n  PrintToPdfResponse(data: String)\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `print_to_pdf`\nPrintToPdfResponse(data: String)\n\ndata\n&lt;p&gt;Base64-encoded pdf data. Empty if |returnAsStream| is specified. (Encoded as a base64 string when passed over JSON)&lt;/p&gt;\n\nSynonyms:\nprotocol/page.PrintToPdfResponse\nprotocol/page PrintToPdfResponse","url":"protocol/page.html#PrintToPdfResponse"},{"doc":"protocol/page","title":"ScriptIdentifier","content":"pub type ScriptIdentifier {\n  ScriptIdentifier(String)\n}\n Unique script identifier.\nScriptIdentifier(String)\n\n\nSynonyms:\nprotocol/page.ScriptIdentifier\nprotocol/page ScriptIdentifier","url":"protocol/page.html#ScriptIdentifier"},{"doc":"protocol/page","title":"TransitionType","content":"pub type TransitionType {\n  TransitionTypeLink\n  TransitionTypeTyped\n  TransitionTypeAddressBar\n  TransitionTypeAutoBookmark\n  TransitionTypeAutoSubframe\n  TransitionTypeManualSubframe\n  TransitionTypeGenerated\n  TransitionTypeAutoToplevel\n  TransitionTypeFormSubmit\n  TransitionTypeReload\n  TransitionTypeKeyword\n  TransitionTypeKeywordGenerated\n  TransitionTypeOther\n}\n Transition type.\nTransitionTypeLink\n\n\nTransitionTypeTyped\n\n\nTransitionTypeAddressBar\n\n\nTransitionTypeAutoBookmark\n\n\nTransitionTypeAutoSubframe\n\n\nTransitionTypeManualSubframe\n\n\nTransitionTypeGenerated\n\n\nTransitionTypeAutoToplevel\n\n\nTransitionTypeFormSubmit\n\n\nTransitionTypeReload\n\n\nTransitionTypeKeyword\n\n\nTransitionTypeKeywordGenerated\n\n\nTransitionTypeOther\n\n\nSynonyms:\nprotocol/page.TransitionType\nprotocol/page TransitionType","url":"protocol/page.html#TransitionType"},{"doc":"protocol/page","title":"Viewport","content":"pub type Viewport {\n  Viewport(\n    x: Float,\n    y: Float,\n    width: Float,\n    height: Float,\n    scale: Float,\n  )\n}\n Viewport for capturing screenshot.\nViewport(\n  x: Float,\n  y: Float,\n  width: Float,\n  height: Float,\n  scale: Float,\n)\n\nx\n&lt;p&gt;X offset in device independent pixels (dip).&lt;/p&gt;\n\ny\n&lt;p&gt;Y offset in device independent pixels (dip).&lt;/p&gt;\n\nwidth\n&lt;p&gt;Rectangle width in device independent pixels (dip).&lt;/p&gt;\n\nheight\n&lt;p&gt;Rectangle height in device independent pixels (dip).&lt;/p&gt;\n\nscale\n&lt;p&gt;Page scale factor.&lt;/p&gt;\n\nSynonyms:\nprotocol/page.Viewport\nprotocol/page Viewport","url":"protocol/page.html#Viewport"},{"doc":"protocol/page","title":"VisualViewport","content":"pub type VisualViewport {\n  VisualViewport(\n    offset_x: Float,\n    offset_y: Float,\n    page_x: Float,\n    page_y: Float,\n    client_width: Float,\n    client_height: Float,\n    scale: Float,\n    zoom: option.Option(Float),\n  )\n}\n Visual viewport position, dimensions, and scale.\nVisualViewport(\n  offset_x: Float,\n  offset_y: Float,\n  page_x: Float,\n  page_y: Float,\n  client_width: Float,\n  client_height: Float,\n  scale: Float,\n  zoom: option.Option(Float),\n)\n\noffset_x\n&lt;p&gt;Horizontal offset relative to the layout viewport (CSS pixels).&lt;/p&gt;\n\noffset_y\n&lt;p&gt;Vertical offset relative to the layout viewport (CSS pixels).&lt;/p&gt;\n\npage_x\n&lt;p&gt;Horizontal offset relative to the document (CSS pixels).&lt;/p&gt;\n\npage_y\n&lt;p&gt;Vertical offset relative to the document (CSS pixels).&lt;/p&gt;\n\nclient_width\n&lt;p&gt;Width (CSS pixels), excludes scrollbar if present.&lt;/p&gt;\n\nclient_height\n&lt;p&gt;Height (CSS pixels), excludes scrollbar if present.&lt;/p&gt;\n\nscale\n&lt;p&gt;Scale relative to the ideal viewport (size at width=device-width).&lt;/p&gt;\n\nzoom\n&lt;p&gt;Page zoom factor (CSS to device independent pixels ratio).&lt;/p&gt;\n\nSynonyms:\nprotocol/page.VisualViewport\nprotocol/page VisualViewport","url":"protocol/page.html#VisualViewport"},{"doc":"protocol/page","title":"add_script_to_evaluate_on_new_document","content":"pub fn add_script_to_evaluate_on_new_document(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  source source: String,\n) -&gt; Result(\n  AddScriptToEvaluateOnNewDocumentResponse,\n  RequestError,\n)\n Evaluates given script in every frame upon creation (before loading frame&#39;s scripts).\n \n Parameters:  \n  - `source`\n \n Returns:  \n  - `identifier` : Identifier of the added script.\n \nSynonyms:\nprotocol/page.add_script_to_evaluate_on_new_document\nprotocol/page add_script_to_evaluate_on_new_document","url":"protocol/page.html#add_script_to_evaluate_on_new_document"},{"doc":"protocol/page","title":"bring_to_front","content":"pub fn bring_to_front(\n  callback__: fn(String, Option(a)) -&gt; b,\n) -&gt; b\n Brings page to front (activates tab).\n \nSynonyms:\nprotocol/page.bring_to_front\nprotocol/page bring_to_front","url":"protocol/page.html#bring_to_front"},{"doc":"protocol/page","title":"capture_screenshot","content":"pub fn capture_screenshot(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  format format: Option(CaptureScreenshotFormat),\n  quality quality: Option(Int),\n  clip clip: Option(Viewport),\n) -&gt; Result(CaptureScreenshotResponse, RequestError)\n Capture page screenshot.\n \n Parameters:  \n  - `format` : Image compression format (defaults to png).\n  - `quality` : Compression quality from range [0..100] (jpeg only).\n  - `clip` : Capture the screenshot of a given region only.\n \n Returns:  \n  - `data` : Base64-encoded image data. (Encoded as a base64 string when passed over JSON)\n \nSynonyms:\nprotocol/page.capture_screenshot\nprotocol/page capture_screenshot","url":"protocol/page.html#capture_screenshot"},{"doc":"protocol/page","title":"close","content":"pub fn close(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n Tries to close page, running its beforeunload hooks, if any.\n \nSynonyms:\nprotocol/page.close\nprotocol/page close","url":"protocol/page.html#close"},{"doc":"protocol/page","title":"create_isolated_world","content":"pub fn create_isolated_world(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  frame_id frame_id: FrameId,\n  world_name world_name: Option(String),\n  grant_univeral_access grant_univeral_access: Option(Bool),\n) -&gt; Result(CreateIsolatedWorldResponse, RequestError)\n Creates an isolated world for the given frame.\n \n Parameters:  \n  - `frame_id` : Id of the frame in which the isolated world should be created.\n  - `world_name` : An optional name which is reported in the Execution Context.\n  - `grant_univeral_access` : Whether or not universal access should be granted to the isolated world. This is a powerful\n option, use with caution.\n \n Returns:  \n  - `execution_context_id` : Execution context of the isolated world.\n \nSynonyms:\nprotocol/page.create_isolated_world\nprotocol/page create_isolated_world","url":"protocol/page.html#create_isolated_world"},{"doc":"protocol/page","title":"disable","content":"pub fn disable(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n Disables page domain notifications.\n \nSynonyms:\nprotocol/page.disable\nprotocol/page disable","url":"protocol/page.html#disable"},{"doc":"protocol/page","title":"enable","content":"pub fn enable(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n Enables page domain notifications.\n \nSynonyms:\nprotocol/page.enable\nprotocol/page enable","url":"protocol/page.html#enable"},{"doc":"protocol/page","title":"get_app_manifest","content":"pub fn get_app_manifest(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  manifest_id manifest_id: Option(String),\n) -&gt; Result(GetAppManifestResponse, RequestError)\n Gets the processed manifest for this current document.\n   This API always waits for the manifest to be loaded.\n   If manifestId is provided, and it does not match the manifest of the\n     current document, this API errors out.\n   If there is not a loaded page, this API errors out immediately.\n \n Parameters:  \n  - `manifest_id`\n \n Returns:  \n  - `url` : Manifest location.\n  - `errors`\n  - `data` : Manifest content.\n \nSynonyms:\nprotocol/page.get_app_manifest\nprotocol/page get_app_manifest","url":"protocol/page.html#get_app_manifest"},{"doc":"protocol/page","title":"get_frame_tree","content":"pub fn get_frame_tree(\n  callback__: fn(String, Option(a)) -&gt;\n    Result(Dynamic, RequestError),\n) -&gt; Result(GetFrameTreeResponse, RequestError)\n Returns present frame tree structure.\n  - `frame_tree` : Present frame tree structure.\n \nSynonyms:\nprotocol/page.get_frame_tree\nprotocol/page get_frame_tree","url":"protocol/page.html#get_frame_tree"},{"doc":"protocol/page","title":"get_layout_metrics","content":"pub fn get_layout_metrics(\n  callback__: fn(String, Option(a)) -&gt;\n    Result(Dynamic, RequestError),\n) -&gt; Result(GetLayoutMetricsResponse, RequestError)\n Returns metrics relating to the layouting of the page, such as viewport bounds/scale.\n  - `css_layout_viewport` : Metrics relating to the layout viewport in CSS pixels.\n  - `css_visual_viewport` : Metrics relating to the visual viewport in CSS pixels.\n  - `css_content_size` : Size of scrollable area in CSS pixels.\n \nSynonyms:\nprotocol/page.get_layout_metrics\nprotocol/page get_layout_metrics","url":"protocol/page.html#get_layout_metrics"},{"doc":"protocol/page","title":"get_navigation_history","content":"pub fn get_navigation_history(\n  callback__: fn(String, Option(a)) -&gt;\n    Result(Dynamic, RequestError),\n) -&gt; Result(GetNavigationHistoryResponse, RequestError)\n Returns navigation history for the current page.\n  - `current_index` : Index of the current navigation history entry.\n  - `entries` : Array of navigation history entries.\n \nSynonyms:\nprotocol/page.get_navigation_history\nprotocol/page get_navigation_history","url":"protocol/page.html#get_navigation_history"},{"doc":"protocol/page","title":"handle_java_script_dialog","content":"pub fn handle_java_script_dialog(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  accept accept: Bool,\n  prompt_text prompt_text: Option(String),\n) -&gt; a\n Accepts or dismisses a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload).\n \n Parameters:  \n  - `accept` : Whether to accept or dismiss the dialog.\n  - `prompt_text` : The text to enter into the dialog prompt before accepting. Used only if this is a prompt\n dialog.\n \n Returns:  \n \nSynonyms:\nprotocol/page.handle_java_script_dialog\nprotocol/page handle_java_script_dialog","url":"protocol/page.html#handle_java_script_dialog"},{"doc":"protocol/page","title":"navigate","content":"pub fn navigate(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  url url: String,\n  referrer referrer: Option(String),\n  transition_type transition_type: Option(TransitionType),\n  frame_id frame_id: Option(FrameId),\n) -&gt; Result(NavigateResponse, RequestError)\n Navigates current page to the given URL.\n \n Parameters:  \n  - `url` : URL to navigate the page to.\n  - `referrer` : Referrer URL.\n  - `transition_type` : Intended transition type.\n  - `frame_id` : Frame id to navigate, if not specified navigates the top frame.\n \n Returns:  \n  - `frame_id` : Frame id that has navigated (or failed to navigate)\n  - `loader_id` : Loader identifier. This is omitted in case of same-document navigation,\n as the previously committed loaderId would not change.\n  - `error_text` : User friendly error message, present if and only if navigation has failed.\n \nSynonyms:\nprotocol/page.navigate\nprotocol/page navigate","url":"protocol/page.html#navigate"},{"doc":"protocol/page","title":"navigate_to_history_entry","content":"pub fn navigate_to_history_entry(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  entry_id entry_id: Int,\n) -&gt; a\n Navigates current page to the given history entry.\n \n Parameters:  \n  - `entry_id` : Unique id of the entry to navigate to.\n \n Returns:  \n \nSynonyms:\nprotocol/page.navigate_to_history_entry\nprotocol/page navigate_to_history_entry","url":"protocol/page.html#navigate_to_history_entry"},{"doc":"protocol/page","title":"print_to_pdf","content":"pub fn print_to_pdf(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  landscape landscape: Option(Bool),\n  display_header_footer display_header_footer: Option(Bool),\n  print_background print_background: Option(Bool),\n  scale scale: Option(Float),\n  paper_width paper_width: Option(Float),\n  paper_height paper_height: Option(Float),\n  margin_top margin_top: Option(Float),\n  margin_bottom margin_bottom: Option(Float),\n  margin_left margin_left: Option(Float),\n  margin_right margin_right: Option(Float),\n  page_ranges page_ranges: Option(String),\n  header_template header_template: Option(String),\n  footer_template footer_template: Option(String),\n  prefer_css_page_size prefer_css_page_size: Option(Bool),\n) -&gt; Result(PrintToPdfResponse, RequestError)\n Print page as PDF.\n \n Parameters:  \n  - `landscape` : Paper orientation. Defaults to false.\n  - `display_header_footer` : Display header and footer. Defaults to false.\n  - `print_background` : Print background graphics. Defaults to false.\n  - `scale` : Scale of the webpage rendering. Defaults to 1.\n  - `paper_width` : Paper width in inches. Defaults to 8.5 inches.\n  - `paper_height` : Paper height in inches. Defaults to 11 inches.\n  - `margin_top` : Top margin in inches. Defaults to 1cm (~0.4 inches).\n  - `margin_bottom` : Bottom margin in inches. Defaults to 1cm (~0.4 inches).\n  - `margin_left` : Left margin in inches. Defaults to 1cm (~0.4 inches).\n  - `margin_right` : Right margin in inches. Defaults to 1cm (~0.4 inches).\n  - `page_ranges` : Paper ranges to print, one based, e.g., &#39;1-5, 8, 11-13&#39;. Pages are\n printed in the document order, not in the order specified, and no\n more than once.\n Defaults to empty string, which implies the entire document is printed.\n The page numbers are quietly capped to actual page count of the\n document, and ranges beyond the end of the document are ignored.\n If this results in no pages to print, an error is reported.\n It is an error to specify a range with start greater than end.\n  - `header_template` : HTML template for the print header. Should be valid HTML markup with following\n classes used to inject printing values into them:\n - `date`: formatted print date\n - `title`: document title\n - `url`: document location\n - `pageNumber`: current page number\n - `totalPages`: total pages in the document\n \n For example, `&lt;span class=title&gt;&lt;/span&gt;` would generate span containing the title.\n  - `footer_template` : HTML template for the print footer. Should use the same format as the `headerTemplate`.\n  - `prefer_css_page_size` : Whether or not to prefer page size as defined by css. Defaults to false,\n in which case the content will be scaled to fit the paper size.\n \n Returns:  \n  - `data` : Base64-encoded pdf data. Empty if |returnAsStream| is specified. (Encoded as a base64 string when passed over JSON)\n \nSynonyms:\nprotocol/page.print_to_pdf\nprotocol/page print_to_pdf","url":"protocol/page.html#print_to_pdf"},{"doc":"protocol/page","title":"reload","content":"pub fn reload(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  ignore_cache ignore_cache: Option(Bool),\n  script_to_evaluate_on_load script_to_evaluate_on_load: Option(\n    String,\n  ),\n) -&gt; a\n Reloads given page optionally ignoring the cache.\n \n Parameters:  \n  - `ignore_cache` : If true, browser cache is ignored (as if the user pressed Shift+refresh).\n  - `script_to_evaluate_on_load` : If set, the script will be injected into all frames of the inspected page after reload.\n Argument will be ignored if reloading dataURL origin.\n \n Returns:  \n \nSynonyms:\nprotocol/page.reload\nprotocol/page reload","url":"protocol/page.html#reload"},{"doc":"protocol/page","title":"remove_script_to_evaluate_on_new_document","content":"pub fn remove_script_to_evaluate_on_new_document(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  identifier identifier: ScriptIdentifier,\n) -&gt; a\n Removes given script from the list.\n \n Parameters:  \n  - `identifier`\n \n Returns:  \n \nSynonyms:\nprotocol/page.remove_script_to_evaluate_on_new_document\nprotocol/page remove_script_to_evaluate_on_new_document","url":"protocol/page.html#remove_script_to_evaluate_on_new_document"},{"doc":"protocol/page","title":"reset_navigation_history","content":"pub fn reset_navigation_history(\n  callback__: fn(String, Option(a)) -&gt; b,\n) -&gt; b\n Resets navigation history for the current page.\n \nSynonyms:\nprotocol/page.reset_navigation_history\nprotocol/page reset_navigation_history","url":"protocol/page.html#reset_navigation_history"},{"doc":"protocol/page","title":"set_bypass_csp","content":"pub fn set_bypass_csp(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  enabled enabled: Bool,\n) -&gt; a\n Enable page Content Security Policy by-passing.\n \n Parameters:  \n  - `enabled` : Whether to bypass page CSP.\n \n Returns:  \n \nSynonyms:\nprotocol/page.set_bypass_csp\nprotocol/page set_bypass_csp","url":"protocol/page.html#set_bypass_csp"},{"doc":"protocol/page","title":"set_document_content","content":"pub fn set_document_content(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  frame_id frame_id: FrameId,\n  html html: String,\n) -&gt; a\n Sets given markup as the document&#39;s HTML.\n \n Parameters:  \n  - `frame_id` : Frame id to set HTML for.\n  - `html` : HTML content to set.\n \n Returns:  \n \nSynonyms:\nprotocol/page.set_document_content\nprotocol/page set_document_content","url":"protocol/page.html#set_document_content"},{"doc":"protocol/page","title":"set_intercept_file_chooser_dialog","content":"pub fn set_intercept_file_chooser_dialog(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  enabled enabled: Bool,\n) -&gt; a\n Intercept file chooser requests and transfer control to protocol clients.\n When file chooser interception is enabled, native file chooser dialog is not shown.\n Instead, a protocol event `Page.fileChooserOpened` is emitted.\n \n Parameters:  \n  - `enabled`\n \n Returns:  \n \nSynonyms:\nprotocol/page.set_intercept_file_chooser_dialog\nprotocol/page set_intercept_file_chooser_dialog","url":"protocol/page.html#set_intercept_file_chooser_dialog"},{"doc":"protocol/page","title":"set_lifecycle_events_enabled","content":"pub fn set_lifecycle_events_enabled(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  enabled enabled: Bool,\n) -&gt; a\n Controls whether page will emit lifecycle events.\n \n Parameters:  \n  - `enabled` : If true, starts emitting lifecycle events.\n \n Returns:  \n \nSynonyms:\nprotocol/page.set_lifecycle_events_enabled\nprotocol/page set_lifecycle_events_enabled","url":"protocol/page.html#set_lifecycle_events_enabled"},{"doc":"protocol/page","title":"stop_loading","content":"pub fn stop_loading(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n Force the page stop all navigations and pending resource fetches.\n \nSynonyms:\nprotocol/page.stop_loading\nprotocol/page stop_loading","url":"protocol/page.html#stop_loading"},{"doc":"protocol/page","title":"protocol/page","content":" &gt; ⚙️  This module was generated from the Chrome DevTools Protocol version **1.3**\n ## Page Domain  \n\n Actions and events related to the inspected page belong to the page domain.  \n\n [📖   View this domain on the DevTools Protocol API Docs](https://chromedevtools.github.io/devtools-protocol/1-3/Page/)","url":"protocol/page.html"},{"doc":"protocol/target","title":"AttachToTargetResponse","content":"pub type AttachToTargetResponse {\n  AttachToTargetResponse(session_id: SessionID)\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `attach_to_target`\nAttachToTargetResponse(session_id: SessionID)\n\nsession_id\n&lt;p&gt;Id assigned to the session.&lt;/p&gt;\n\nSynonyms:\nprotocol/target.AttachToTargetResponse\nprotocol/target AttachToTargetResponse","url":"protocol/target.html#AttachToTargetResponse"},{"doc":"protocol/target","title":"CreateBrowserContextResponse","content":"pub type CreateBrowserContextResponse {\n  CreateBrowserContextResponse(browser_context_id: String)\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `create_browser_context`\nCreateBrowserContextResponse(browser_context_id: String)\n\nbrowser_context_id\n&lt;p&gt;The id of the context created.&lt;/p&gt;\n\nSynonyms:\nprotocol/target.CreateBrowserContextResponse\nprotocol/target CreateBrowserContextResponse","url":"protocol/target.html#CreateBrowserContextResponse"},{"doc":"protocol/target","title":"CreateTargetResponse","content":"pub type CreateTargetResponse {\n  CreateTargetResponse(target_id: TargetID)\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `create_target`\nCreateTargetResponse(target_id: TargetID)\n\ntarget_id\n&lt;p&gt;The id of the page opened.&lt;/p&gt;\n\nSynonyms:\nprotocol/target.CreateTargetResponse\nprotocol/target CreateTargetResponse","url":"protocol/target.html#CreateTargetResponse"},{"doc":"protocol/target","title":"GetBrowserContextsResponse","content":"pub type GetBrowserContextsResponse {\n  GetBrowserContextsResponse(browser_context_ids: List(String))\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `get_browser_contexts`\nGetBrowserContextsResponse(browser_context_ids: List(String))\n\nbrowser_context_ids\n&lt;p&gt;An array of browser context ids.&lt;/p&gt;\n\nSynonyms:\nprotocol/target.GetBrowserContextsResponse\nprotocol/target GetBrowserContextsResponse","url":"protocol/target.html#GetBrowserContextsResponse"},{"doc":"protocol/target","title":"GetTargetsResponse","content":"pub type GetTargetsResponse {\n  GetTargetsResponse(target_infos: List(TargetInfo))\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `get_targets`\nGetTargetsResponse(target_infos: List(TargetInfo))\n\ntarget_infos\n&lt;p&gt;The list of targets.&lt;/p&gt;\n\nSynonyms:\nprotocol/target.GetTargetsResponse\nprotocol/target GetTargetsResponse","url":"protocol/target.html#GetTargetsResponse"},{"doc":"protocol/target","title":"SessionID","content":"pub type SessionID {\n  SessionID(String)\n}\n Unique identifier of attached debugging session.\nSessionID(String)\n\n\nSynonyms:\nprotocol/target.SessionID\nprotocol/target SessionID","url":"protocol/target.html#SessionID"},{"doc":"protocol/target","title":"TargetID","content":"pub type TargetID {\n  TargetID(String)\n}\n\nTargetID(String)\n\n\nSynonyms:\nprotocol/target.TargetID\nprotocol/target TargetID","url":"protocol/target.html#TargetID"},{"doc":"protocol/target","title":"TargetInfo","content":"pub type TargetInfo {\n  TargetInfo(\n    target_id: TargetID,\n    type_: String,\n    title: String,\n    url: String,\n    attached: Bool,\n    opener_id: option.Option(TargetID),\n  )\n}\n\nTargetInfo(\n  target_id: TargetID,\n  type_: String,\n  title: String,\n  url: String,\n  attached: Bool,\n  opener_id: option.Option(TargetID),\n)\n\ntype_\n&lt;p&gt;List of types: https://source.chromium.org/chromium/chromium/src/+/main:content/browser/devtools/devtools_agent_host_impl.cc?ss=chromium&amp;amp;q=f:devtools%20-f:out%20%22::kTypeTab%5B%5D%22&lt;/p&gt;\n\nattached\n&lt;p&gt;Whether the target has an attached client.&lt;/p&gt;\n\nopener_id\n&lt;p&gt;Opener target Id&lt;/p&gt;\n\nSynonyms:\nprotocol/target.TargetInfo\nprotocol/target TargetInfo","url":"protocol/target.html#TargetInfo"},{"doc":"protocol/target","title":"activate_target","content":"pub fn activate_target(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  target_id target_id: TargetID,\n) -&gt; a\n Activates (focuses) the target.\n \n Parameters:  \n  - `target_id`\n \n Returns:  \n \nSynonyms:\nprotocol/target.activate_target\nprotocol/target activate_target","url":"protocol/target.html#activate_target"},{"doc":"protocol/target","title":"attach_to_target","content":"pub fn attach_to_target(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  target_id target_id: TargetID,\n  flatten flatten: Option(Bool),\n) -&gt; Result(AttachToTargetResponse, RequestError)\n Attaches to the target with given id.\n \n Parameters:  \n  - `target_id`\n  - `flatten` : Enables &quot;flat&quot; access to the session via specifying sessionId attribute in the commands.\n We plan to make this the default, deprecate non-flattened mode,\n and eventually retire it. See crbug.com/991325.\n \n Returns:  \n  - `session_id` : Id assigned to the session.\n \nSynonyms:\nprotocol/target.attach_to_target\nprotocol/target attach_to_target","url":"protocol/target.html#attach_to_target"},{"doc":"protocol/target","title":"close_target","content":"pub fn close_target(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  target_id target_id: TargetID,\n) -&gt; a\n Closes the target. If the target is a page that gets closed too.\n \n Parameters:  \n  - `target_id`\n \n Returns:  \n \nSynonyms:\nprotocol/target.close_target\nprotocol/target close_target","url":"protocol/target.html#close_target"},{"doc":"protocol/target","title":"create_browser_context","content":"pub fn create_browser_context(\n  callback__: fn(String, Option(a)) -&gt;\n    Result(Dynamic, RequestError),\n) -&gt; Result(CreateBrowserContextResponse, RequestError)\n Creates a new empty BrowserContext. Similar to an incognito profile but you can have more than\n one.\n \n Parameters:  \n \n Returns:  \n  - `browser_context_id` : The id of the context created.\n \nSynonyms:\nprotocol/target.create_browser_context\nprotocol/target create_browser_context","url":"protocol/target.html#create_browser_context"},{"doc":"protocol/target","title":"create_target","content":"pub fn create_target(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  url url: String,\n  width width: Option(Int),\n  height height: Option(Int),\n  new_window new_window: Option(Bool),\n  background background: Option(Bool),\n) -&gt; Result(CreateTargetResponse, RequestError)\n Creates a new page.\n \n Parameters:  \n  - `url` : The initial URL the page will be navigated to. An empty string indicates about:blank.\n  - `width` : Frame width in DIP (headless chrome only).\n  - `height` : Frame height in DIP (headless chrome only).\n  - `new_window` : Whether to create a new Window or Tab (chrome-only, false by default).\n  - `background` : Whether to create the target in background or foreground (chrome-only,\n false by default).\n \n Returns:  \n  - `target_id` : The id of the page opened.\n \nSynonyms:\nprotocol/target.create_target\nprotocol/target create_target","url":"protocol/target.html#create_target"},{"doc":"protocol/target","title":"detach_from_target","content":"pub fn detach_from_target(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  session_id session_id: Option(SessionID),\n) -&gt; a\n Detaches session with given id.\n \n Parameters:  \n  - `session_id` : Session to detach.\n \n Returns:  \n \nSynonyms:\nprotocol/target.detach_from_target\nprotocol/target detach_from_target","url":"protocol/target.html#detach_from_target"},{"doc":"protocol/target","title":"dispose_browser_context","content":"pub fn dispose_browser_context(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  browser_context_id browser_context_id: String,\n) -&gt; a\n Deletes a BrowserContext. All the belonging pages will be closed without calling their\n beforeunload hooks.\n \n Parameters:  \n  - `browser_context_id`\n \n Returns:  \n \nSynonyms:\nprotocol/target.dispose_browser_context\nprotocol/target dispose_browser_context","url":"protocol/target.html#dispose_browser_context"},{"doc":"protocol/target","title":"get_browser_contexts","content":"pub fn get_browser_contexts(\n  callback__: fn(String, Option(a)) -&gt;\n    Result(Dynamic, RequestError),\n) -&gt; Result(GetBrowserContextsResponse, RequestError)\n Returns all browser contexts created with `Target.createBrowserContext` method.\n  - `browser_context_ids` : An array of browser context ids.\n \nSynonyms:\nprotocol/target.get_browser_contexts\nprotocol/target get_browser_contexts","url":"protocol/target.html#get_browser_contexts"},{"doc":"protocol/target","title":"get_targets","content":"pub fn get_targets(\n  callback__: fn(String, Option(a)) -&gt;\n    Result(Dynamic, RequestError),\n) -&gt; Result(GetTargetsResponse, RequestError)\n Retrieves a list of available targets.\n \n Parameters:  \n \n Returns:  \n  - `target_infos` : The list of targets.\n \nSynonyms:\nprotocol/target.get_targets\nprotocol/target get_targets","url":"protocol/target.html#get_targets"},{"doc":"protocol/target","title":"set_auto_attach","content":"pub fn set_auto_attach(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  auto_attach auto_attach: Bool,\n  wait_for_debugger_on_start wait_for_debugger_on_start: Bool,\n) -&gt; a\n Controls whether to automatically attach to new targets which are considered to be related to\n this one. When turned on, attaches to all existing related targets as well. When turned off,\n automatically detaches from all currently attached targets.\n This also clears all targets added by `autoAttachRelated` from the list of targets to watch\n for creation of related targets.\n \n Parameters:  \n  - `auto_attach` : Whether to auto-attach to related targets.\n  - `wait_for_debugger_on_start` : Whether to pause new targets when attaching to them. Use `Runtime.runIfWaitingForDebugger`\n to run paused targets.\n \n Returns:  \n \nSynonyms:\nprotocol/target.set_auto_attach\nprotocol/target set_auto_attach","url":"protocol/target.html#set_auto_attach"},{"doc":"protocol/target","title":"set_discover_targets","content":"pub fn set_discover_targets(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  discover discover: Bool,\n) -&gt; a\n Controls whether to discover available targets and notify via\n `targetCreated/targetInfoChanged/targetDestroyed` events.\n \n Parameters:  \n  - `discover` : Whether to discover available targets.\n \n Returns:  \n \nSynonyms:\nprotocol/target.set_discover_targets\nprotocol/target set_discover_targets","url":"protocol/target.html#set_discover_targets"},{"doc":"protocol/target","title":"protocol/target","content":" &gt; ⚙️  This module was generated from the Chrome DevTools Protocol version **1.3**\n ## Target Domain  \n\n Supports additional targets discovery and allows to attach to them.  \n\n [📖   View this domain on the DevTools Protocol API Docs](https://chromedevtools.github.io/devtools-protocol/1-3/Target/)","url":"protocol/target.html"},{"doc":"chrobot","title":"CallArgument","content":"pub type CallArgument {\n  StringArg(value: String)\n  IntArg(value: Int)\n  FloatArg(value: Float)\n  BoolArg(value: Bool)\n  ArrayArg(value: List(CallArgument))\n}\n Type wrapper to let you pass in custom arguments of different types \n to a JavaScript function as a list of the same type\nStringArg(value: String)\n\n\nIntArg(value: Int)\n\n\nFloatArg(value: Float)\n\n\nBoolArg(value: Bool)\n\n\nArrayArg(value: List(CallArgument))\n\n\nSynonyms:\nchrobot.CallArgument\nchrobot CallArgument","url":"chrobot.html#CallArgument"},{"doc":"chrobot","title":"EncodedFile","content":"pub type EncodedFile {\n  EncodedFile(data: String, extension: String)\n}\n Holds a base64 encoded file and its extension\nEncodedFile(data: String, extension: String)\n\n\nSynonyms:\nchrobot.EncodedFile\nchrobot EncodedFile","url":"chrobot.html#EncodedFile"},{"doc":"chrobot","title":"Page","content":"pub type Page {\n  Page(\n    browser: Subject(chrome.Message),\n    time_out: Int,\n    target_id: target.TargetID,\n    session_id: target.SessionID,\n  )\n}\n Holds information about the current page,\n as well as the desired timeout in milliseconds\n to use when waiting for browser responses.\nPage(\n  browser: Subject(chrome.Message),\n  time_out: Int,\n  target_id: target.TargetID,\n  session_id: target.SessionID,\n)\n\n\nSynonyms:\nchrobot.Page\nchrobot Page","url":"chrobot.html#Page"},{"doc":"chrobot","title":"as_value","content":"pub fn as_value(\n  result: Result(RemoteObject, RequestError),\n  decoder: fn(Dynamic) -&gt; Result(a, b),\n) -&gt; Result(a, RequestError)\n Cast a RemoteObject into a value by passing a dynamic decoder.  \n This is a convenience for when you know a RemoteObject is returned by value and not ID,\n and you want to extract the value from it.  \n Because it accepts a Result, you can chain this to [`eval`](#eval) or [`eval_async`](#eval_async) like so:\n \n eval(page, &quot;window.document.documentElement.outerHTML&quot;)\n   |&gt; as_value(dynamic.string)\n \nSynonyms:\nchrobot.as_value\nchrobot as_value","url":"chrobot.html#as_value"},{"doc":"chrobot","title":"await_load_event","content":"pub fn await_load_event(\n  browser: Subject(Message),\n  page: Page,\n) -&gt; Result(Dynamic, RequestError)\n Block until the page load event has fired.\n Note that with local pages, the load event can often fire \n before the handler is attached.  \n It&#39;s best to use [`await_selector`](#await_selector) instead of this\nSynonyms:\nchrobot.await_load_event\nchrobot await_load_event","url":"chrobot.html#await_load_event"},{"doc":"chrobot","title":"await_selector","content":"pub fn await_selector(\n  on page: Page,\n  select selector: String,\n) -&gt; Result(RemoteObjectId, RequestError)\n Continously attempt to run a selector, until it succeeds.  \n You can use this after opening a page, to wait for the moment it has initialized\n enough sufficiently for you to run your automation on it.  \n The final result will be single [`runtime.RemoteObjectId`](/chrobot/protocol/runtime.html#RemoteObjectId)\nSynonyms:\nchrobot.await_selector\nchrobot await_selector","url":"chrobot.html#await_selector"},{"doc":"chrobot","title":"call_custom_function_on","content":"pub fn call_custom_function_on(\n  callback: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  function_declaration function_declaration: String,\n  object_id object_id: RemoteObjectId,\n  args arguments: List(CallArgument),\n  value_decoder value_decoder: fn(Dynamic) -&gt; Result(a, b),\n) -&gt; Result(a, RequestError)\n This is a version of [`runtime.call_function_on`](/chrobot/protocol/runtime.html#call_function_on) which allows\n passing in arguments, and always returns the result as a value,\n which will be decoded by the decoder you pass in\n  \n You would use it with a JavaScript function declaration like this:  \n js\n function my_function(my_arg) {\n   // You can access the passed RemoteObject with `this`\n   const wibble = this.getAttribute(&#39;href&#39;)\n   // You have access to the arguments you passed in\n   const wobble = &#39;hello &#39; + my_arg\n   // You receive this return value, you should pass in a string decoder\n   // in this case\n   return wibble + wobble;\n }\n \nSynonyms:\nchrobot.call_custom_function_on\nchrobot call_custom_function_on","url":"chrobot.html#call_custom_function_on"},{"doc":"chrobot","title":"call_custom_function_on_raw","content":"pub fn call_custom_function_on_raw(\n  callback: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  function_declaration function_declaration: String,\n  object_id object_id: RemoteObjectId,\n  args arguments: List(CallArgument),\n) -&gt; Result(CallFunctionOnResponse, RequestError)\n This is a version of `call_custom_function_on` which does not attempt\n to decode the result as a value and just returns it directly instead.  \n Useful when the return value should be discarded or handled in a custom way.\nSynonyms:\nchrobot.call_custom_function_on_raw\nchrobot call_custom_function_on_raw","url":"chrobot.html#call_custom_function_on_raw"},{"doc":"chrobot","title":"click","content":"pub fn click(\n  on page: Page,\n  target item: RemoteObjectId,\n) -&gt; Result(Nil, RequestError)\n Simulate a click on an element.  \n Calls [`HTMLElement.click()`](https://developer.mozilla.org/en-US/docs/Web/API/HTMLElement/click) via JavaScript.\nSynonyms:\nchrobot.click\nchrobot click","url":"chrobot.html#click"},{"doc":"chrobot","title":"click_selector","content":"pub fn click_selector(\n  on page: Page,\n  target selector: String,\n) -&gt; Result(Nil, RequestError)\n Convencience function to simulate a click on an element by selector.  \n See [`click`](#click) for more info.\nSynonyms:\nchrobot.click_selector\nchrobot click_selector","url":"chrobot.html#click_selector"},{"doc":"chrobot","title":"close","content":"pub fn close(page: Page) -&gt; Result(Dynamic, RequestError)\n Close the passed page\nSynonyms:\nchrobot.close\nchrobot close","url":"chrobot.html#close"},{"doc":"chrobot","title":"create_page","content":"pub fn create_page(\n  with browser: Subject(Message),\n  from html: String,\n  time_out time_out: Int,\n) -&gt; Result(Page, RequestError)\n Similar to [`open`](#open), but creates a new page from HTML that you pass to it.\n The page will be created under the `about:blank` URL.\nSynonyms:\nchrobot.create_page\nchrobot create_page","url":"chrobot.html#create_page"},{"doc":"chrobot","title":"defer_quit","content":"pub fn defer_quit(\n  browser: Subject(Message),\n  body: fn() -&gt; a,\n) -&gt; Result(Nil, CallError(Nil))\n Convenience function that lets you defer quitting the browser after you are done with it,\n it&#39;s meant for a `use` expression like this:\n \n \n let assert Ok(browser_subject) = browser.launch()\n use &lt;- browser.defer_quit(browser_subject)\n // do stuff with the browser\n \nSynonyms:\nchrobot.defer_quit\nchrobot defer_quit","url":"chrobot.html#defer_quit"},{"doc":"chrobot","title":"down_key","content":"pub fn down_key(\n  on page: Page,\n  key key: String,\n  modifiers modifiers: Int,\n) -&gt; Result(Nil, RequestError)\n Simulate a keydown event for a given key.  \n \n You can pass in latin characters, digits and some DOM key names,\n The keymap is based on the US keyboard layout.  \n \n [⌨️ You can see the supported key values here](https://github.com/JonasGruenwald/chrobot/blob/main/src/chrobot/internal/keymap.gleam)\nSynonyms:\nchrobot.down_key\nchrobot down_key","url":"chrobot.html#down_key"},{"doc":"chrobot","title":"eval","content":"pub fn eval(\n  on page: Page,\n  js expression: String,\n) -&gt; Result(RemoteObject, RequestError)\n Evaluate some JavaScript on the page and return the result,\n which will be a [`runtime.RemoteObject`](/chrobot/protocol/runtime.html#RemoteObject) reference.  \nSynonyms:\nchrobot.eval\nchrobot eval","url":"chrobot.html#eval"},{"doc":"chrobot","title":"eval_async","content":"pub fn eval_async(\n  on page: Page,\n  js expression: String,\n) -&gt; Result(RemoteObject, RequestError)\n Like [`eval`](#eval), but awaits for the result of the evaluation\n and returns once promise has been resolved\nSynonyms:\nchrobot.eval_async\nchrobot eval_async","url":"chrobot.html#eval_async"},{"doc":"chrobot","title":"eval_to_value","content":"pub fn eval_to_value(\n  on page: Page,\n  js expression: String,\n) -&gt; Result(RemoteObject, RequestError)\n\nSynonyms:\nchrobot.eval_to_value\nchrobot eval_to_value","url":"chrobot.html#eval_to_value"},{"doc":"chrobot","title":"focus","content":"pub fn focus(\n  on page: Page,\n  target item: RemoteObjectId,\n) -&gt; Result(Nil, RequestError)\n Focus an element.  \n Calls [`HTMLElement.focus()`](https://developer.mozilla.org/en-US/docs/Web/API/HTMLElement/focus) via JavaScript.\nSynonyms:\nchrobot.focus\nchrobot focus","url":"chrobot.html#focus"},{"doc":"chrobot","title":"focus_selector","content":"pub fn focus_selector(\n  on page: Page,\n  target selector: String,\n) -&gt; Result(Nil, RequestError)\n Convenience function to focus an element by selector.  \n See [`focus`](#focus) for more info.  \nSynonyms:\nchrobot.focus_selector\nchrobot focus_selector","url":"chrobot.html#focus_selector"},{"doc":"chrobot","title":"get_all_html","content":"pub fn get_all_html(\n  on page: Page,\n) -&gt; Result(String, RequestError)\n Return the entire HTML of the page as a string.  \n Returns `document.documentElement.outerHTML` via JavaScript.\nSynonyms:\nchrobot.get_all_html\nchrobot get_all_html","url":"chrobot.html#get_all_html"},{"doc":"chrobot","title":"get_attribute","content":"pub fn get_attribute(\n  on page: Page,\n  from item: RemoteObjectId,\n  name attribute_name: String,\n) -&gt; Result(String, RequestError)\n Assuming the passed [`runtime.RemoteObjectId`](/chrobot/protocol/runtime.html#RemoteObjectId) reference is an Element,\n return an attribute of that element.  \n Attributes are always returned as a string.  \n If the attribute is not found, or the item is not an Element, an error will be returned.  \n \n ## Example\n \n let assert Ok(foo_data) = get_attribute(page, item, &quot;data-foo&quot;)\n \nSynonyms:\nchrobot.get_attribute\nchrobot get_attribute","url":"chrobot.html#get_attribute"},{"doc":"chrobot","title":"get_inner_html","content":"pub fn get_inner_html(\n  on page: Page,\n  from item: RemoteObjectId,\n) -&gt; Result(String, RequestError)\n Get the inner HTML of an element.\n Returns the [`Element.innerHTML`](https://developer.mozilla.org/en-US/docs/Web/API/Element/innerHTML) JavaScript property.\nSynonyms:\nchrobot.get_inner_html\nchrobot get_inner_html","url":"chrobot.html#get_inner_html"},{"doc":"chrobot","title":"get_outer_html","content":"pub fn get_outer_html(\n  on page: Page,\n  from item: RemoteObjectId,\n) -&gt; Result(String, RequestError)\n Get the outer HTML of an element.  \n Returns the [`Element.outerHTML`](https://developer.mozilla.org/en-US/docs/Web/API/Element/outerHTML) JavaScript property.\nSynonyms:\nchrobot.get_outer_html\nchrobot get_outer_html","url":"chrobot.html#get_outer_html"},{"doc":"chrobot","title":"get_property","content":"pub fn get_property(\n  on page: Page,\n  from item: RemoteObjectId,\n  name property_name: String,\n  property_decoder property_decoder: fn(Dynamic) -&gt; Result(a, b),\n) -&gt; Result(a, RequestError)\n Get a property of a [`runtime.RemoteObjectId`](/chrobot/protocol/runtime.html#RemoteObjectId) and decode it with the provided decoder  \n \n ## Example\n \n import gleam/dynamic\n let assert Ok(link_target) = get_property(page, item, &quot;href&quot;, dynamic.string)\n \nSynonyms:\nchrobot.get_property\nchrobot get_property","url":"chrobot.html#get_property"},{"doc":"chrobot","title":"get_text","content":"pub fn get_text(\n  on page: Page,\n  from item: RemoteObjectId,\n) -&gt; Result(String, RequestError)\n Get the text content of an element.  \n Returns the [`HTMLElement.innerText`](https://developer.mozilla.org/en-US/docs/Web/API/HTMLElement/innerText) property via JavaScript, NOT `Node.textContent`.  \n Learn about the differences [here](https://developer.mozilla.org/en-US/docs/Web/API/Node/textContent#differences_from_innertext).\nSynonyms:\nchrobot.get_text\nchrobot get_text","url":"chrobot.html#get_text"},{"doc":"chrobot","title":"insert_char","content":"pub fn insert_char(\n  on page: Page,\n  key key: String,\n) -&gt; Result(Nil, RequestError)\n Insert the given character into a [focus](#focus)ed input field by sending a `char` keyboard event.  \n Note that this does not trigger a keydown or keyup event, see [`press_key`](#press_key) for that.  \n If you want to insert a whole string into an input field, use [`type_text`](#type_text) instead.  \nSynonyms:\nchrobot.insert_char\nchrobot insert_char","url":"chrobot.html#insert_char"},{"doc":"chrobot","title":"launch","content":"pub fn launch() -&gt; Result(Subject(Message), LaunchError)\n ✨Cleverly✨ try to find a chrome installation and launch it with reasonable defaults.\n \n 1. If `CHROBOT_BROWSER_PATH` is set, use that\n 2. If a local chrome installation is found, use that\n 3. If a system chrome installation is found, use that\n 4. If none of the above, return an error\n \n If you want to always use a specific chrome installation, take a look at [`launch_with_config`](#launch_with_config) or \n [`launch_with_env`](#launch_with_env) to set the path explicitly.\n \n This function will validate that the browser launched successfully, and the \n protocol version matches the one supported by this library.\nSynonyms:\nchrobot.launch\nchrobot launch","url":"chrobot.html#launch"},{"doc":"chrobot","title":"launch_window","content":"pub fn launch_window() -&gt; Result(Subject(Message), LaunchError)\n Like [`launch`](#launch), but launches the browser with a visible window, not\n in headless mode, which is useful for debugging and development.  \nSynonyms:\nchrobot.launch_window\nchrobot launch_window","url":"chrobot.html#launch_window"},{"doc":"chrobot","title":"launch_with_config","content":"pub fn launch_with_config(\n  config: BrowserConfig,\n) -&gt; Result(Subject(Message), LaunchError)\n Launch a browser with the given configuration,\n to populate the arguments, use [`chrome.get_default_chrome_args`](/chrobot/chrome.html#get_default_chrome_args).\n This function will validate that the browser launched successfully, and the \n protocol version matches the one supported by this library.\n \n ## Example\n \n let config =\n browser.BrowserConfig(\n   path: &quot;chrome/linux-116.0.5793.0/chrome-linux64/chrome&quot;,\n   args: chrome.get_default_chrome_args(),\n   start_timeout: 5000,\n )\n let assert Ok(browser_subject) = launch_with_config(config)\n \nSynonyms:\nchrobot.launch_with_config\nchrobot launch_with_config","url":"chrobot.html#launch_with_config"},{"doc":"chrobot","title":"launch_with_env","content":"pub fn launch_with_env() -&gt; Result(Subject(Message), LaunchError)\n Launch a browser, and read the configuration from environment variables.\n The browser path variable must be set, all others will fall back to a default.\n \n This function will validate that the browser launched successfully, and the \n protocol version matches the one supported by this library.\n \n Configuration variables:\n - `CHROBOT_BROWSER_PATH` - The path to the browser executable\n - `CHROBOT_BROWSER_ARGS` - The arguments to pass to the browser, separated by spaces\n - `CHROBOT_BROWSER_TIMEOUT` - The timeout in milliseconds to wait for the browser to start, must be an integer\n - `CHROBOT_LOG_LEVEL` - The log level to use, one of `silent`, `warnings`, `info`, `debug`\n \nSynonyms:\nchrobot.launch_with_env\nchrobot launch_with_env","url":"chrobot.html#launch_with_env"},{"doc":"chrobot","title":"open","content":"pub fn open(\n  with browser_subject: Subject(Message),\n  to url: String,\n  time_out time_out: Int,\n) -&gt; Result(Page, RequestError)\n Open a new page in the browser.\n Returns a response when the protocol call succeeds, please use\n [`await_selector`](#await_selector) to determine when the page is ready.  \n The timeout passed to this function will be attached to the returned\n [`Page`](#Page) type to be reused by other functions in this module.  \n You can always adjust it using [`with_timeout`](#with_timeout).\nSynonyms:\nchrobot.open\nchrobot open","url":"chrobot.html#open"},{"doc":"chrobot","title":"page_caller","content":"pub fn page_caller(\n  page: Page,\n) -&gt; fn(String, Option(Json)) -&gt; Result(Dynamic, RequestError)\n Create callback to pass to protocol commands from a `Page`  \n This is useful when you want to make raw protocol calls  \n \n ## Example\n \n import chrobot.{open, page_caller}\n import gleam/option.{None}\n import protocol/page\n pub fn main() {\n   let assert Ok(browser) = chrobot.launch()\n   let assert Ok(page) = open(browser, &quot;https://example.com&quot;, 5000)\n   let callback = page_caller(page)\n   let assert Ok(_) =\n     page.navigate(callback, &quot;https://gleam.run&quot;, None, None, None)\n }\n \nSynonyms:\nchrobot.page_caller\nchrobot page_caller","url":"chrobot.html#page_caller"},{"doc":"chrobot","title":"pdf","content":"pub fn pdf(page: Page) -&gt; Result(EncodedFile, RequestError)\n Export the current page as PDF and return it as a base64 encoded string.  \n Transferring the encoded file from the browser to the chrome agent can take a pretty long time,\n depending on the document size.  \n Consider setting a larger timeout, you can use `with_timeout` on your existing `Page` to do this.\n The Ok(result) of this function can be passed to `to_file`  \n   \n If you want to customize the settings of the output document, use [`page.print_to_pdf`](/chrobot/protocol/page.html#print_to_pdf) directly.\nSynonyms:\nchrobot.pdf\nchrobot pdf","url":"chrobot.html#pdf"},{"doc":"chrobot","title":"poll","content":"pub fn poll(\n  callback: fn() -&gt; Result(a, RequestError),\n  timeout: Int,\n) -&gt; Result(a, RequestError)\n Utility to repeatedly call a browser function until it succeeds or times out.\nSynonyms:\nchrobot.poll\nchrobot poll","url":"chrobot.html#poll"},{"doc":"chrobot","title":"press_key","content":"pub fn press_key(\n  on page: Page,\n  key key: String,\n) -&gt; Result(Nil, RequestError)\n Simulate a keypress for a given key.  \n This will trigger a keydown and keyup event in sequence.  \n \n You can pass in latin characters, digits and some DOM key names,\n The keymap is based on the US keyboard layout.  \n \n [⌨️ You can see the supported key values here](https://github.com/JonasGruenwald/chrobot/blob/main/src/chrobot/internal/keymap.gleam)\n \n If you want to insert a whole string into an input field, use `type_text` instead.\nSynonyms:\nchrobot.press_key\nchrobot press_key","url":"chrobot.html#press_key"},{"doc":"chrobot","title":"quit","content":"pub fn quit(\n  browser: Subject(Message),\n) -&gt; Result(Nil, CallError(Nil))\n Quit the browser (alias for [`chrome.quit`](/chrobot/chrome.html#quit))\nSynonyms:\nchrobot.quit\nchrobot quit","url":"chrobot.html#quit"},{"doc":"chrobot","title":"screenshot","content":"pub fn screenshot(\n  page: Page,\n) -&gt; Result(EncodedFile, RequestError)\n Capture a screenshot of the current page and return it as a base64 encoded string\n The Ok(result) of this function can be passed to [`to_file`](#to_file)  \n   \n If you want to customize the settings of the output image, use [`page.capture_screenshot`](/chrobot/protocol/page.html#capture_screenshot) directly.\nSynonyms:\nchrobot.screenshot\nchrobot screenshot","url":"chrobot.html#screenshot"},{"doc":"chrobot","title":"select","content":"pub fn select(\n  on page: Page,\n  matching selector: String,\n) -&gt; Result(RemoteObjectId, RequestError)\n Run [`document.querySelector`](https://developer.mozilla.org/en-US/docs/Web/API/Document/querySelector) on the page\n and return a single [`runtime.RemoteObjectId`](/chrobot/protocol/runtime.html#RemoteObjectId)\n for the first matching element.\nSynonyms:\nchrobot.select\nchrobot select","url":"chrobot.html#select"},{"doc":"chrobot","title":"select_all","content":"pub fn select_all(\n  on page: Page,\n  matching selector: String,\n) -&gt; Result(List(RemoteObjectId), RequestError)\n Run [`document.querySelectorAll`](https://developer.mozilla.org/en-US/docs/Web/API/Document/querySelectorAll) on the page and return a list of [`runtime.RemoteObjectId`](/chrobot/protocol/runtime.html#RemoteObjectId) items \n for all matching elements.\nSynonyms:\nchrobot.select_all\nchrobot select_all","url":"chrobot.html#select_all"},{"doc":"chrobot","title":"to_file","content":"pub fn to_file(\n  input input: EncodedFile,\n  path path: String,\n) -&gt; Result(Nil, FileError)\n Write a file returned from [`screenshot`](#screenshot) or [`pdf`](#pdf) to a file.  \n File path should not include the file extension, it will be appended automatically!  \n Will return a FileError from the `simplifile` package if not successfull\nSynonyms:\nchrobot.to_file\nchrobot to_file","url":"chrobot.html#to_file"},{"doc":"chrobot","title":"to_value","content":"pub fn to_value(\n  on page: Page,\n  from remote_object_id: RemoteObjectId,\n  to decoder: fn(Dynamic) -&gt; Result(a, b),\n) -&gt; Result(a, RequestError)\n Evalute a [`runtime.RemoteObjectId`](/chrobot/protocol/runtime.html#RemoteObjectId) to a value,\n passing in the appropriate decoder function\nSynonyms:\nchrobot.to_value\nchrobot to_value","url":"chrobot.html#to_value"},{"doc":"chrobot","title":"type_text","content":"pub fn type_text(\n  on page: Page,\n  text input: String,\n) -&gt; Result(Nil, RequestError)\n Type text by simulating keypresses for each character in the input string.  \n Note: If a character is not supported by the virtual keyboard, it will be inserted using a char event,\n which will not produce keydown or keyup events.  \n [⌨️ You can see the key values supported by the virtual keyboard here](https://github.com/JonasGruenwald/chrobot/blob/main/src/chrobot/internal/keymap.gleam)  \n \n If you want to type text into an input field, make sure to [`focus`](#focus) it first!  \nSynonyms:\nchrobot.type_text\nchrobot type_text","url":"chrobot.html#type_text"},{"doc":"chrobot","title":"up_key","content":"pub fn up_key(\n  on page: Page,\n  key key: String,\n  modifiers modifiers: Int,\n) -&gt; Result(Nil, RequestError)\n Simulate a keyup event for a given key.  \n \n You can pass in latin characters, digits and some DOM key names,\n The keymap is based on the US keyboard layout.  \n \n [⌨️ You can see the supported key values here](https://github.com/JonasGruenwald/chrobot/blob/main/src/chrobot/internal/keymap.gleam)\nSynonyms:\nchrobot.up_key\nchrobot up_key","url":"chrobot.html#up_key"},{"doc":"chrobot","title":"with_timeout","content":"pub fn with_timeout(page: Page, time_out: Int) -&gt; Page\n Return an updated `Page` with the desired timeout to apply, in milliseconds\nSynonyms:\nchrobot.with_timeout\nchrobot with_timeout","url":"chrobot.html#with_timeout"},{"doc":"chrobot","title":"chrobot","content":" Welcome to Chrobot! 🤖\n This module exposes high level functions for browser automation.\n \n Some basic concepts:\n \n - You&#39;ll first want to [`launch`](#launch) an instance of the browser and receive a `Subject` which allows\n you to send messages to the browser (actor)\n - You can [`open`](#open) a [`Page`](#Page), which makes the browser browse to a website\n - Use [`await_selector`](#await_selector) to wait for an element to appear on the page before you interact with it!\n - You can interact with the page by calling functions in this module with the [`Page`](#Page) you received from [`open`](#open)\n - For extracting information from the page, select elements with [`select`](#select) or [`select_all`](#select_all), \n   then use [`get_text`](#get_text), [`get_attribute`](#get_attribute), [`get_property`](#get_property) or [`get_inner_html`](#get_inner_html)\n - To simulate user input, use [`press_key`](#press_key), [`type_text`](#type_text), [`click`](#click) and [`focus`](#focus)\n - If you want to make raw protocol calls, you can use [`page_caller`](#page_caller), to create a callback to pass to protocol commands from your [`Page`](#Page)\n - When you are done with the browser, you should call [`quit`](#quit) to shut it down gracefully\n \n The functions in this module just make calls to [`protocol/`](/chrobot/protocol.html)  modules, if you\n would like to customize the behaviour, take a look at them to see how to make\n direct protocol calls and pass different defaults.  \n  \n Something to consider:  \n A lot of the functions in this module are interpolating their parameters into  \n JavaScript expressions that are evaluated in the page context.  \n No attempt is made to escape the passed parameters or prevent script injection through them, \n you should not use the functions in this module with arbitrary strings if you want\n to treat the pages you are operating on as a secure context.\n ","url":"chrobot.html"},{"doc":"protocol/browser","title":"GetVersionResponse","content":"pub type GetVersionResponse {\n  GetVersionResponse(\n    protocol_version: String,\n    product: String,\n    revision: String,\n    user_agent: String,\n    js_version: String,\n  )\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `get_version`\nGetVersionResponse(\n  protocol_version: String,\n  product: String,\n  revision: String,\n  user_agent: String,\n  js_version: String,\n)\n\nprotocol_version\n&lt;p&gt;Protocol version.&lt;/p&gt;\n\nproduct\n&lt;p&gt;Product name.&lt;/p&gt;\n\nrevision\n&lt;p&gt;Product revision.&lt;/p&gt;\n\nuser_agent\n&lt;p&gt;User-Agent.&lt;/p&gt;\n\njs_version\n&lt;p&gt;V8 version.&lt;/p&gt;\n\nSynonyms:\nprotocol/browser.GetVersionResponse\nprotocol/browser GetVersionResponse","url":"protocol/browser.html#GetVersionResponse"},{"doc":"protocol/browser","title":"add_privacy_sandbox_enrollment_override","content":"pub fn add_privacy_sandbox_enrollment_override(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  url url: String,\n) -&gt; a\n Allows a site to use privacy sandbox features that require enrollment\n without the site actually being enrolled. Only supported on page targets.\n \n Parameters:  \n  - `url`\n \n Returns:  \n \nSynonyms:\nprotocol/browser.add_privacy_sandbox_enrollment_override\nprotocol/browser add_privacy_sandbox_enrollment_override","url":"protocol/browser.html#add_privacy_sandbox_enrollment_override"},{"doc":"protocol/browser","title":"close","content":"pub fn close(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n Close browser gracefully.\n \nSynonyms:\nprotocol/browser.close\nprotocol/browser close","url":"protocol/browser.html#close"},{"doc":"protocol/browser","title":"get_version","content":"pub fn get_version(\n  callback__: fn(String, Option(a)) -&gt;\n    Result(Dynamic, RequestError),\n) -&gt; Result(GetVersionResponse, RequestError)\n Returns version information.\n  - `protocol_version` : Protocol version.\n  - `product` : Product name.\n  - `revision` : Product revision.\n  - `user_agent` : User-Agent.\n  - `js_version` : V8 version.\n \nSynonyms:\nprotocol/browser.get_version\nprotocol/browser get_version","url":"protocol/browser.html#get_version"},{"doc":"protocol/browser","title":"reset_permissions","content":"pub fn reset_permissions(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  browser_context_id browser_context_id: Option(String),\n) -&gt; a\n Reset all permission management for all origins.\n \n Parameters:  \n  - `browser_context_id` : BrowserContext to reset permissions. When omitted, default browser context is used.\n \n Returns:  \n \nSynonyms:\nprotocol/browser.reset_permissions\nprotocol/browser reset_permissions","url":"protocol/browser.html#reset_permissions"},{"doc":"protocol/browser","title":"protocol/browser","content":" &gt; ⚙️  This module was generated from the Chrome DevTools Protocol version **1.3**\n ## Browser Domain  \n\n The Browser domain defines methods and events for browser managing.  \n\n [📖   View this domain on the DevTools Protocol API Docs](https://chromedevtools.github.io/devtools-protocol/1-3/Browser/)","url":"protocol/browser.html"},{"doc":"protocol/debugger","title":"BreakLocation","content":"pub type BreakLocation {\n  BreakLocation(\n    script_id: runtime.ScriptId,\n    line_number: Int,\n    column_number: option.Option(Int),\n    type_: option.Option(BreakLocationType),\n  )\n}\n\nBreakLocation(\n  script_id: runtime.ScriptId,\n  line_number: Int,\n  column_number: option.Option(Int),\n  type_: option.Option(BreakLocationType),\n)\n\nscript_id\n&lt;p&gt;Script identifier as reported in the &lt;code&gt;Debugger.scriptParsed&lt;/code&gt;.&lt;/p&gt;\n\nline_number\n&lt;p&gt;Line number in the script (0-based).&lt;/p&gt;\n\ncolumn_number\n&lt;p&gt;Column number in the script (0-based).&lt;/p&gt;\n\nSynonyms:\nprotocol/debugger.BreakLocation\nprotocol/debugger BreakLocation","url":"protocol/debugger.html#BreakLocation"},{"doc":"protocol/debugger","title":"BreakLocationType","content":"pub type BreakLocationType {\n  BreakLocationTypeDebuggerStatement\n  BreakLocationTypeCall\n  BreakLocationTypeReturn\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `type` of `BreakLocation`\nBreakLocationTypeDebuggerStatement\n\n\nBreakLocationTypeCall\n\n\nBreakLocationTypeReturn\n\n\nSynonyms:\nprotocol/debugger.BreakLocationType\nprotocol/debugger BreakLocationType","url":"protocol/debugger.html#BreakLocationType"},{"doc":"protocol/debugger","title":"BreakpointId","content":"pub type BreakpointId {\n  BreakpointId(String)\n}\n Breakpoint identifier.\nBreakpointId(String)\n\n\nSynonyms:\nprotocol/debugger.BreakpointId\nprotocol/debugger BreakpointId","url":"protocol/debugger.html#BreakpointId"},{"doc":"protocol/debugger","title":"CallFrame","content":"pub type CallFrame {\n  CallFrame(\n    call_frame_id: CallFrameId,\n    function_name: String,\n    function_location: option.Option(Location),\n    location: Location,\n    scope_chain: List(Scope),\n    this: runtime.RemoteObject,\n    return_value: option.Option(runtime.RemoteObject),\n  )\n}\n JavaScript call frame. Array of call frames form the call stack.\nCallFrame(\n  call_frame_id: CallFrameId,\n  function_name: String,\n  function_location: option.Option(Location),\n  location: Location,\n  scope_chain: List(Scope),\n  this: runtime.RemoteObject,\n  return_value: option.Option(runtime.RemoteObject),\n)\n\ncall_frame_id\n&lt;p&gt;Call frame identifier. This identifier is only valid while the virtual machine is paused.&lt;/p&gt;\n\nfunction_name\n&lt;p&gt;Name of the JavaScript function called on this call frame.&lt;/p&gt;\n\nfunction_location\n&lt;p&gt;Location in the source code.&lt;/p&gt;\n\nlocation\n&lt;p&gt;Location in the source code.&lt;/p&gt;\n\nscope_chain\n&lt;p&gt;Scope chain for this call frame.&lt;/p&gt;\n\nthis\n&lt;p&gt;&lt;code&gt;this&lt;/code&gt; object for this call frame.&lt;/p&gt;\n\nreturn_value\n&lt;p&gt;The value being returned, if the function is at return point.&lt;/p&gt;\n\nSynonyms:\nprotocol/debugger.CallFrame\nprotocol/debugger CallFrame","url":"protocol/debugger.html#CallFrame"},{"doc":"protocol/debugger","title":"CallFrameId","content":"pub type CallFrameId {\n  CallFrameId(String)\n}\n Call frame identifier.\nCallFrameId(String)\n\n\nSynonyms:\nprotocol/debugger.CallFrameId\nprotocol/debugger CallFrameId","url":"protocol/debugger.html#CallFrameId"},{"doc":"protocol/debugger","title":"ContinueToLocationTargetCallFrames","content":"pub type ContinueToLocationTargetCallFrames {\n  ContinueToLocationTargetCallFramesAny\n  ContinueToLocationTargetCallFramesCurrent\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `targetCallFrames` of `continueToLocation`\nContinueToLocationTargetCallFramesAny\n\n\nContinueToLocationTargetCallFramesCurrent\n\n\nSynonyms:\nprotocol/debugger.ContinueToLocationTargetCallFrames\nprotocol/debugger ContinueToLocationTargetCallFrames","url":"protocol/debugger.html#ContinueToLocationTargetCallFrames"},{"doc":"protocol/debugger","title":"DebugSymbols","content":"pub type DebugSymbols {\n  DebugSymbols(\n    type_: DebugSymbolsType,\n    external_url: option.Option(String),\n  )\n}\n Debug symbols available for a wasm script.\nDebugSymbols(\n  type_: DebugSymbolsType,\n  external_url: option.Option(String),\n)\n\ntype_\n&lt;p&gt;Type of the debug symbols.&lt;/p&gt;\n\nexternal_url\n&lt;p&gt;URL of the external symbol source.&lt;/p&gt;\n\nSynonyms:\nprotocol/debugger.DebugSymbols\nprotocol/debugger DebugSymbols","url":"protocol/debugger.html#DebugSymbols"},{"doc":"protocol/debugger","title":"DebugSymbolsType","content":"pub type DebugSymbolsType {\n  DebugSymbolsTypeNone\n  DebugSymbolsTypeSourceMap\n  DebugSymbolsTypeEmbeddedDwarf\n  DebugSymbolsTypeExternalDwarf\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `type` of `DebugSymbols`\nDebugSymbolsTypeNone\n\n\nDebugSymbolsTypeSourceMap\n\n\nDebugSymbolsTypeEmbeddedDwarf\n\n\nDebugSymbolsTypeExternalDwarf\n\n\nSynonyms:\nprotocol/debugger.DebugSymbolsType\nprotocol/debugger DebugSymbolsType","url":"protocol/debugger.html#DebugSymbolsType"},{"doc":"protocol/debugger","title":"EvaluateOnCallFrameResponse","content":"pub type EvaluateOnCallFrameResponse {\n  EvaluateOnCallFrameResponse(\n    result: runtime.RemoteObject,\n    exception_details: option.Option(runtime.ExceptionDetails),\n  )\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `evaluate_on_call_frame`\nEvaluateOnCallFrameResponse(\n  result: runtime.RemoteObject,\n  exception_details: option.Option(runtime.ExceptionDetails),\n)\n\nresult\n&lt;p&gt;Object wrapper for the evaluation result.&lt;/p&gt;\n\nexception_details\n&lt;p&gt;Exception details.&lt;/p&gt;\n\nSynonyms:\nprotocol/debugger.EvaluateOnCallFrameResponse\nprotocol/debugger EvaluateOnCallFrameResponse","url":"protocol/debugger.html#EvaluateOnCallFrameResponse"},{"doc":"protocol/debugger","title":"GetPossibleBreakpointsResponse","content":"pub type GetPossibleBreakpointsResponse {\n  GetPossibleBreakpointsResponse(locations: List(BreakLocation))\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `get_possible_breakpoints`\nGetPossibleBreakpointsResponse(locations: List(BreakLocation))\n\nlocations\n&lt;p&gt;List of the possible breakpoint locations.&lt;/p&gt;\n\nSynonyms:\nprotocol/debugger.GetPossibleBreakpointsResponse\nprotocol/debugger GetPossibleBreakpointsResponse","url":"protocol/debugger.html#GetPossibleBreakpointsResponse"},{"doc":"protocol/debugger","title":"GetScriptSourceResponse","content":"pub type GetScriptSourceResponse {\n  GetScriptSourceResponse(\n    script_source: String,\n    bytecode: option.Option(String),\n  )\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `get_script_source`\nGetScriptSourceResponse(\n  script_source: String,\n  bytecode: option.Option(String),\n)\n\nscript_source\n&lt;p&gt;Script source (empty in case of Wasm bytecode).&lt;/p&gt;\n\nbytecode\n&lt;p&gt;Wasm bytecode. (Encoded as a base64 string when passed over JSON)&lt;/p&gt;\n\nSynonyms:\nprotocol/debugger.GetScriptSourceResponse\nprotocol/debugger GetScriptSourceResponse","url":"protocol/debugger.html#GetScriptSourceResponse"},{"doc":"protocol/debugger","title":"Location","content":"pub type Location {\n  Location(\n    script_id: runtime.ScriptId,\n    line_number: Int,\n    column_number: option.Option(Int),\n  )\n}\n Location in the source code.\nLocation(\n  script_id: runtime.ScriptId,\n  line_number: Int,\n  column_number: option.Option(Int),\n)\n\nscript_id\n&lt;p&gt;Script identifier as reported in the &lt;code&gt;Debugger.scriptParsed&lt;/code&gt;.&lt;/p&gt;\n\nline_number\n&lt;p&gt;Line number in the script (0-based).&lt;/p&gt;\n\ncolumn_number\n&lt;p&gt;Column number in the script (0-based).&lt;/p&gt;\n\nSynonyms:\nprotocol/debugger.Location\nprotocol/debugger Location","url":"protocol/debugger.html#Location"},{"doc":"protocol/debugger","title":"Scope","content":"pub type Scope {\n  Scope(\n    type_: ScopeType,\n    object: runtime.RemoteObject,\n    name: option.Option(String),\n    start_location: option.Option(Location),\n    end_location: option.Option(Location),\n  )\n}\n Scope description.\nScope(\n  type_: ScopeType,\n  object: runtime.RemoteObject,\n  name: option.Option(String),\n  start_location: option.Option(Location),\n  end_location: option.Option(Location),\n)\n\ntype_\n&lt;p&gt;Scope type.&lt;/p&gt;\n\nobject\n&lt;p&gt;Object representing the scope. For &lt;code&gt;global&lt;/code&gt; and &lt;code&gt;with&lt;/code&gt; scopes it represents the actual\nobject; for the rest of the scopes, it is artificial transient object enumerating scope\nvariables as its properties.&lt;/p&gt;\n\nstart_location\n&lt;p&gt;Location in the source code where scope starts&lt;/p&gt;\n\nend_location\n&lt;p&gt;Location in the source code where scope ends&lt;/p&gt;\n\nSynonyms:\nprotocol/debugger.Scope\nprotocol/debugger Scope","url":"protocol/debugger.html#Scope"},{"doc":"protocol/debugger","title":"ScopeType","content":"pub type ScopeType {\n  ScopeTypeGlobal\n  ScopeTypeLocal\n  ScopeTypeWith\n  ScopeTypeClosure\n  ScopeTypeCatch\n  ScopeTypeBlock\n  ScopeTypeScript\n  ScopeTypeEval\n  ScopeTypeModule\n  ScopeTypeWasmExpressionStack\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `type` of `Scope`\nScopeTypeGlobal\n\n\nScopeTypeLocal\n\n\nScopeTypeWith\n\n\nScopeTypeClosure\n\n\nScopeTypeCatch\n\n\nScopeTypeBlock\n\n\nScopeTypeScript\n\n\nScopeTypeEval\n\n\nScopeTypeModule\n\n\nScopeTypeWasmExpressionStack\n\n\nSynonyms:\nprotocol/debugger.ScopeType\nprotocol/debugger ScopeType","url":"protocol/debugger.html#ScopeType"},{"doc":"protocol/debugger","title":"ScriptLanguage","content":"pub type ScriptLanguage {\n  ScriptLanguageJavaScript\n  ScriptLanguageWebAssembly\n}\n Enum of possible script languages.\nScriptLanguageJavaScript\n\n\nScriptLanguageWebAssembly\n\n\nSynonyms:\nprotocol/debugger.ScriptLanguage\nprotocol/debugger ScriptLanguage","url":"protocol/debugger.html#ScriptLanguage"},{"doc":"protocol/debugger","title":"SearchInContentResponse","content":"pub type SearchInContentResponse {\n  SearchInContentResponse(result: List(SearchMatch))\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `search_in_content`\nSearchInContentResponse(result: List(SearchMatch))\n\nresult\n&lt;p&gt;List of search matches.&lt;/p&gt;\n\nSynonyms:\nprotocol/debugger.SearchInContentResponse\nprotocol/debugger SearchInContentResponse","url":"protocol/debugger.html#SearchInContentResponse"},{"doc":"protocol/debugger","title":"SearchMatch","content":"pub type SearchMatch {\n  SearchMatch(line_number: Float, line_content: String)\n}\n Search match for resource.\nSearchMatch(line_number: Float, line_content: String)\n\nline_number\n&lt;p&gt;Line number in resource content.&lt;/p&gt;\n\nline_content\n&lt;p&gt;Line with match content.&lt;/p&gt;\n\nSynonyms:\nprotocol/debugger.SearchMatch\nprotocol/debugger SearchMatch","url":"protocol/debugger.html#SearchMatch"},{"doc":"protocol/debugger","title":"SetBreakpointByUrlResponse","content":"pub type SetBreakpointByUrlResponse {\n  SetBreakpointByUrlResponse(\n    breakpoint_id: BreakpointId,\n    locations: List(Location),\n  )\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `set_breakpoint_by_url`\nSetBreakpointByUrlResponse(\n  breakpoint_id: BreakpointId,\n  locations: List(Location),\n)\n\nbreakpoint_id\n&lt;p&gt;Id of the created breakpoint for further reference.&lt;/p&gt;\n\nlocations\n&lt;p&gt;List of the locations this breakpoint resolved into upon addition.&lt;/p&gt;\n\nSynonyms:\nprotocol/debugger.SetBreakpointByUrlResponse\nprotocol/debugger SetBreakpointByUrlResponse","url":"protocol/debugger.html#SetBreakpointByUrlResponse"},{"doc":"protocol/debugger","title":"SetBreakpointResponse","content":"pub type SetBreakpointResponse {\n  SetBreakpointResponse(\n    breakpoint_id: BreakpointId,\n    actual_location: Location,\n  )\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `set_breakpoint`\nSetBreakpointResponse(\n  breakpoint_id: BreakpointId,\n  actual_location: Location,\n)\n\nbreakpoint_id\n&lt;p&gt;Id of the created breakpoint for further reference.&lt;/p&gt;\n\nactual_location\n&lt;p&gt;Location this breakpoint resolved into.&lt;/p&gt;\n\nSynonyms:\nprotocol/debugger.SetBreakpointResponse\nprotocol/debugger SetBreakpointResponse","url":"protocol/debugger.html#SetBreakpointResponse"},{"doc":"protocol/debugger","title":"SetInstrumentationBreakpointInstrumentation","content":"pub type SetInstrumentationBreakpointInstrumentation {\n  SetInstrumentationBreakpointInstrumentationBeforeScriptExecution\n  SetInstrumentationBreakpointInstrumentationBeforeScriptWithSourceMapExecution\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `instrumentation` of `setInstrumentationBreakpoint`\nSetInstrumentationBreakpointInstrumentationBeforeScriptExecution\n\n\nSetInstrumentationBreakpointInstrumentationBeforeScriptWithSourceMapExecution\n\n\nSynonyms:\nprotocol/debugger.SetInstrumentationBreakpointInstrumentation\nprotocol/debugger SetInstrumentationBreakpointInstrumentation","url":"protocol/debugger.html#SetInstrumentationBreakpointInstrumentation"},{"doc":"protocol/debugger","title":"SetInstrumentationBreakpointResponse","content":"pub type SetInstrumentationBreakpointResponse {\n  SetInstrumentationBreakpointResponse(\n    breakpoint_id: BreakpointId,\n  )\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `set_instrumentation_breakpoint`\nSetInstrumentationBreakpointResponse(breakpoint_id: BreakpointId)\n\nbreakpoint_id\n&lt;p&gt;Id of the created breakpoint for further reference.&lt;/p&gt;\n\nSynonyms:\nprotocol/debugger.SetInstrumentationBreakpointResponse\nprotocol/debugger SetInstrumentationBreakpointResponse","url":"protocol/debugger.html#SetInstrumentationBreakpointResponse"},{"doc":"protocol/debugger","title":"SetPauseOnExceptionsState","content":"pub type SetPauseOnExceptionsState {\n  SetPauseOnExceptionsStateNone\n  SetPauseOnExceptionsStateCaught\n  SetPauseOnExceptionsStateUncaught\n  SetPauseOnExceptionsStateAll\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `state` of `setPauseOnExceptions`\nSetPauseOnExceptionsStateNone\n\n\nSetPauseOnExceptionsStateCaught\n\n\nSetPauseOnExceptionsStateUncaught\n\n\nSetPauseOnExceptionsStateAll\n\n\nSynonyms:\nprotocol/debugger.SetPauseOnExceptionsState\nprotocol/debugger SetPauseOnExceptionsState","url":"protocol/debugger.html#SetPauseOnExceptionsState"},{"doc":"protocol/debugger","title":"SetScriptSourceResponse","content":"pub type SetScriptSourceResponse {\n  SetScriptSourceResponse(\n    exception_details: option.Option(runtime.ExceptionDetails),\n  )\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `set_script_source`\nSetScriptSourceResponse(\n  exception_details: option.Option(runtime.ExceptionDetails),\n)\n\nexception_details\n&lt;p&gt;Exception details if any. Only present when &lt;code&gt;status&lt;/code&gt; is &lt;code&gt;CompileError&lt;/code&gt;.&lt;/p&gt;\n\nSynonyms:\nprotocol/debugger.SetScriptSourceResponse\nprotocol/debugger SetScriptSourceResponse","url":"protocol/debugger.html#SetScriptSourceResponse"},{"doc":"protocol/debugger","title":"continue_to_location","content":"pub fn continue_to_location(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  location location: Location,\n  target_call_frames target_call_frames: Option(\n    ContinueToLocationTargetCallFrames,\n  ),\n) -&gt; a\n Continues execution until specific location is reached.\n \n Parameters:  \n  - `location` : Location to continue to.\n  - `target_call_frames`\n \n Returns:  \n \nSynonyms:\nprotocol/debugger.continue_to_location\nprotocol/debugger continue_to_location","url":"protocol/debugger.html#continue_to_location"},{"doc":"protocol/debugger","title":"disable","content":"pub fn disable(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n Disables debugger for given page.\n \nSynonyms:\nprotocol/debugger.disable\nprotocol/debugger disable","url":"protocol/debugger.html#disable"},{"doc":"protocol/debugger","title":"enable","content":"pub fn enable(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n Enables debugger for the given page. Clients should not assume that the debugging has been\n enabled until the result for this command is received.\n \n Parameters:  \n \n Returns:  \n \nSynonyms:\nprotocol/debugger.enable\nprotocol/debugger enable","url":"protocol/debugger.html#enable"},{"doc":"protocol/debugger","title":"evaluate_on_call_frame","content":"pub fn evaluate_on_call_frame(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  call_frame_id call_frame_id: CallFrameId,\n  expression expression: String,\n  object_group object_group: Option(String),\n  include_command_line_api include_command_line_api: Option(Bool),\n  silent silent: Option(Bool),\n  return_by_value return_by_value: Option(Bool),\n  throw_on_side_effect throw_on_side_effect: Option(Bool),\n) -&gt; Result(EvaluateOnCallFrameResponse, RequestError)\n Evaluates expression on a given call frame.\n \n Parameters:  \n  - `call_frame_id` : Call frame identifier to evaluate on.\n  - `expression` : Expression to evaluate.\n  - `object_group` : String object group name to put result into (allows rapid releasing resulting object handles\n using `releaseObjectGroup`).\n  - `include_command_line_api` : Specifies whether command line API should be available to the evaluated expression, defaults\n to false.\n  - `silent` : In silent mode exceptions thrown during evaluation are not reported and do not pause\n execution. Overrides `setPauseOnException` state.\n  - `return_by_value` : Whether the result is expected to be a JSON object that should be sent by value.\n  - `throw_on_side_effect` : Whether to throw an exception if side effect cannot be ruled out during evaluation.\n \n Returns:  \n  - `result` : Object wrapper for the evaluation result.\n  - `exception_details` : Exception details.\n \nSynonyms:\nprotocol/debugger.evaluate_on_call_frame\nprotocol/debugger evaluate_on_call_frame","url":"protocol/debugger.html#evaluate_on_call_frame"},{"doc":"protocol/debugger","title":"get_possible_breakpoints","content":"pub fn get_possible_breakpoints(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  start start: Location,\n  end end: Option(Location),\n  restrict_to_function restrict_to_function: Option(Bool),\n) -&gt; Result(GetPossibleBreakpointsResponse, RequestError)\n Returns possible locations for breakpoint. scriptId in start and end range locations should be\n the same.\n \n Parameters:  \n  - `start` : Start of range to search possible breakpoint locations in.\n  - `end` : End of range to search possible breakpoint locations in (excluding). When not specified, end\n of scripts is used as end of range.\n  - `restrict_to_function` : Only consider locations which are in the same (non-nested) function as start.\n \n Returns:  \n  - `locations` : List of the possible breakpoint locations.\n \nSynonyms:\nprotocol/debugger.get_possible_breakpoints\nprotocol/debugger get_possible_breakpoints","url":"protocol/debugger.html#get_possible_breakpoints"},{"doc":"protocol/debugger","title":"get_script_source","content":"pub fn get_script_source(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  script_id script_id: ScriptId,\n) -&gt; Result(GetScriptSourceResponse, RequestError)\n Returns source for the script with given id.\n \n Parameters:  \n  - `script_id` : Id of the script to get source for.\n \n Returns:  \n  - `script_source` : Script source (empty in case of Wasm bytecode).\n  - `bytecode` : Wasm bytecode. (Encoded as a base64 string when passed over JSON)\n \nSynonyms:\nprotocol/debugger.get_script_source\nprotocol/debugger get_script_source","url":"protocol/debugger.html#get_script_source"},{"doc":"protocol/debugger","title":"pause","content":"pub fn pause(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n Stops on the next JavaScript statement.\n \nSynonyms:\nprotocol/debugger.pause\nprotocol/debugger pause","url":"protocol/debugger.html#pause"},{"doc":"protocol/debugger","title":"remove_breakpoint","content":"pub fn remove_breakpoint(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  breakpoint_id breakpoint_id: BreakpointId,\n) -&gt; a\n Removes JavaScript breakpoint.\n \n Parameters:  \n  - `breakpoint_id`\n \n Returns:  \n \nSynonyms:\nprotocol/debugger.remove_breakpoint\nprotocol/debugger remove_breakpoint","url":"protocol/debugger.html#remove_breakpoint"},{"doc":"protocol/debugger","title":"restart_frame","content":"pub fn restart_frame(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  call_frame_id call_frame_id: CallFrameId,\n) -&gt; a\n Restarts particular call frame from the beginning. The old, deprecated\n behavior of `restartFrame` is to stay paused and allow further CDP commands\n after a restart was scheduled. This can cause problems with restarting, so\n we now continue execution immediatly after it has been scheduled until we\n reach the beginning of the restarted frame.\n \n To stay back-wards compatible, `restartFrame` now expects a `mode`\n parameter to be present. If the `mode` parameter is missing, `restartFrame`\n errors out.\n \n The various return values are deprecated and `callFrames` is always empty.\n Use the call frames from the `Debugger#paused` events instead, that fires\n once V8 pauses at the beginning of the restarted function.\n \n Parameters:  \n  - `call_frame_id` : Call frame identifier to evaluate on.\n \n Returns:  \n \nSynonyms:\nprotocol/debugger.restart_frame\nprotocol/debugger restart_frame","url":"protocol/debugger.html#restart_frame"},{"doc":"protocol/debugger","title":"resume","content":"pub fn resume(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  terminate_on_resume terminate_on_resume: Option(Bool),\n) -&gt; a\n Resumes JavaScript execution.\n \n Parameters:  \n  - `terminate_on_resume` : Set to true to terminate execution upon resuming execution. In contrast\n to Runtime.terminateExecution, this will allows to execute further\n JavaScript (i.e. via evaluation) until execution of the paused code\n is actually resumed, at which point termination is triggered.\n If execution is currently not paused, this parameter has no effect.\n \n Returns:  \n \nSynonyms:\nprotocol/debugger.resume\nprotocol/debugger resume","url":"protocol/debugger.html#resume"},{"doc":"protocol/debugger","title":"search_in_content","content":"pub fn search_in_content(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  script_id script_id: ScriptId,\n  query query: String,\n  case_sensitive case_sensitive: Option(Bool),\n  is_regex is_regex: Option(Bool),\n) -&gt; Result(SearchInContentResponse, RequestError)\n Searches for given string in script content.\n \n Parameters:  \n  - `script_id` : Id of the script to search in.\n  - `query` : String to search for.\n  - `case_sensitive` : If true, search is case sensitive.\n  - `is_regex` : If true, treats string parameter as regex.\n \n Returns:  \n  - `result` : List of search matches.\n \nSynonyms:\nprotocol/debugger.search_in_content\nprotocol/debugger search_in_content","url":"protocol/debugger.html#search_in_content"},{"doc":"protocol/debugger","title":"set_async_call_stack_depth","content":"pub fn set_async_call_stack_depth(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  max_depth max_depth: Int,\n) -&gt; a\n Enables or disables async call stacks tracking.\n \n Parameters:  \n  - `max_depth` : Maximum depth of async call stacks. Setting to `0` will effectively disable collecting async\n call stacks (default).\n \n Returns:  \n \nSynonyms:\nprotocol/debugger.set_async_call_stack_depth\nprotocol/debugger set_async_call_stack_depth","url":"protocol/debugger.html#set_async_call_stack_depth"},{"doc":"protocol/debugger","title":"set_breakpoint","content":"pub fn set_breakpoint(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  location location: Location,\n  condition condition: Option(String),\n) -&gt; Result(SetBreakpointResponse, RequestError)\n Sets JavaScript breakpoint at a given location.\n \n Parameters:  \n  - `location` : Location to set breakpoint in.\n  - `condition` : Expression to use as a breakpoint condition. When specified, debugger will only stop on the\n breakpoint if this expression evaluates to true.\n \n Returns:  \n  - `breakpoint_id` : Id of the created breakpoint for further reference.\n  - `actual_location` : Location this breakpoint resolved into.\n \nSynonyms:\nprotocol/debugger.set_breakpoint\nprotocol/debugger set_breakpoint","url":"protocol/debugger.html#set_breakpoint"},{"doc":"protocol/debugger","title":"set_breakpoint_by_url","content":"pub fn set_breakpoint_by_url(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  line_number line_number: Int,\n  url url: Option(String),\n  url_regex url_regex: Option(String),\n  script_hash script_hash: Option(String),\n  column_number column_number: Option(Int),\n  condition condition: Option(String),\n) -&gt; Result(SetBreakpointByUrlResponse, RequestError)\n Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this\n command is issued, all existing parsed scripts will have breakpoints resolved and returned in\n `locations` property. Further matching script parsing will result in subsequent\n `breakpointResolved` events issued. This logical breakpoint will survive page reloads.\n \n Parameters:  \n  - `line_number` : Line number to set breakpoint at.\n  - `url` : URL of the resources to set breakpoint on.\n  - `url_regex` : Regex pattern for the URLs of the resources to set breakpoints on. Either `url` or\n `urlRegex` must be specified.\n  - `script_hash` : Script hash of the resources to set breakpoint on.\n  - `column_number` : Offset in the line to set breakpoint at.\n  - `condition` : Expression to use as a breakpoint condition. When specified, debugger will only stop on the\n breakpoint if this expression evaluates to true.\n \n Returns:  \n  - `breakpoint_id` : Id of the created breakpoint for further reference.\n  - `locations` : List of the locations this breakpoint resolved into upon addition.\n \nSynonyms:\nprotocol/debugger.set_breakpoint_by_url\nprotocol/debugger set_breakpoint_by_url","url":"protocol/debugger.html#set_breakpoint_by_url"},{"doc":"protocol/debugger","title":"set_breakpoints_active","content":"pub fn set_breakpoints_active(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  active active: Bool,\n) -&gt; a\n Activates / deactivates all breakpoints on the page.\n \n Parameters:  \n  - `active` : New value for breakpoints active state.\n \n Returns:  \n \nSynonyms:\nprotocol/debugger.set_breakpoints_active\nprotocol/debugger set_breakpoints_active","url":"protocol/debugger.html#set_breakpoints_active"},{"doc":"protocol/debugger","title":"set_instrumentation_breakpoint","content":"pub fn set_instrumentation_breakpoint(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  instrumentation instrumentation: SetInstrumentationBreakpointInstrumentation,\n) -&gt; Result(SetInstrumentationBreakpointResponse, RequestError)\n Sets instrumentation breakpoint.\n \n Parameters:  \n  - `instrumentation` : Instrumentation name.\n \n Returns:  \n  - `breakpoint_id` : Id of the created breakpoint for further reference.\n \nSynonyms:\nprotocol/debugger.set_instrumentation_breakpoint\nprotocol/debugger set_instrumentation_breakpoint","url":"protocol/debugger.html#set_instrumentation_breakpoint"},{"doc":"protocol/debugger","title":"set_pause_on_exceptions","content":"pub fn set_pause_on_exceptions(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  state state: SetPauseOnExceptionsState,\n) -&gt; a\n Defines pause on exceptions state. Can be set to stop on all exceptions, uncaught exceptions,\n or caught exceptions, no exceptions. Initial pause on exceptions state is `none`.\n \n Parameters:  \n  - `state` : Pause on exceptions mode.\n \n Returns:  \n \nSynonyms:\nprotocol/debugger.set_pause_on_exceptions\nprotocol/debugger set_pause_on_exceptions","url":"protocol/debugger.html#set_pause_on_exceptions"},{"doc":"protocol/debugger","title":"set_script_source","content":"pub fn set_script_source(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  script_id script_id: ScriptId,\n  script_source script_source: String,\n  dry_run dry_run: Option(Bool),\n) -&gt; Result(SetScriptSourceResponse, RequestError)\n Edits JavaScript source live.\n \n In general, functions that are currently on the stack can not be edited with\n a single exception: If the edited function is the top-most stack frame and\n that is the only activation of that function on the stack. In this case\n the live edit will be successful and a `Debugger.restartFrame` for the\n top-most function is automatically triggered.\n \n Parameters:  \n  - `script_id` : Id of the script to edit.\n  - `script_source` : New content of the script.\n  - `dry_run` : If true the change will not actually be applied. Dry run may be used to get result\n description without actually modifying the code.\n \n Returns:  \n  - `exception_details` : Exception details if any. Only present when `status` is `CompileError`.\n \nSynonyms:\nprotocol/debugger.set_script_source\nprotocol/debugger set_script_source","url":"protocol/debugger.html#set_script_source"},{"doc":"protocol/debugger","title":"set_skip_all_pauses","content":"pub fn set_skip_all_pauses(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  skip skip: Bool,\n) -&gt; a\n Makes page not interrupt on any pauses (breakpoint, exception, dom exception etc).\n \n Parameters:  \n  - `skip` : New value for skip pauses state.\n \n Returns:  \n \nSynonyms:\nprotocol/debugger.set_skip_all_pauses\nprotocol/debugger set_skip_all_pauses","url":"protocol/debugger.html#set_skip_all_pauses"},{"doc":"protocol/debugger","title":"set_variable_value","content":"pub fn set_variable_value(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  scope_number scope_number: Int,\n  variable_name variable_name: String,\n  new_value new_value: CallArgument,\n  call_frame_id call_frame_id: CallFrameId,\n) -&gt; a\n Changes value of variable in a callframe. Object-based scopes are not supported and must be\n mutated manually.\n \n Parameters:  \n  - `scope_number` : 0-based number of scope as was listed in scope chain. Only &#39;local&#39;, &#39;closure&#39; and &#39;catch&#39;\n scope types are allowed. Other scopes could be manipulated manually.\n  - `variable_name` : Variable name.\n  - `new_value` : New variable value.\n  - `call_frame_id` : Id of callframe that holds variable.\n \n Returns:  \n \nSynonyms:\nprotocol/debugger.set_variable_value\nprotocol/debugger set_variable_value","url":"protocol/debugger.html#set_variable_value"},{"doc":"protocol/debugger","title":"step_into","content":"pub fn step_into(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n Steps into the function call.\n \n Parameters:  \n \n Returns:  \n \nSynonyms:\nprotocol/debugger.step_into\nprotocol/debugger step_into","url":"protocol/debugger.html#step_into"},{"doc":"protocol/debugger","title":"step_out","content":"pub fn step_out(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n Steps out of the function call.\n \nSynonyms:\nprotocol/debugger.step_out\nprotocol/debugger step_out","url":"protocol/debugger.html#step_out"},{"doc":"protocol/debugger","title":"step_over","content":"pub fn step_over(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n Steps over the statement.\n \n Parameters:  \n \n Returns:  \n \nSynonyms:\nprotocol/debugger.step_over\nprotocol/debugger step_over","url":"protocol/debugger.html#step_over"},{"doc":"protocol/debugger","title":"protocol/debugger","content":" &gt; ⚙️  This module was generated from the Chrome DevTools Protocol version **1.3**\n ## Debugger Domain  \n\n Debugger domain exposes JavaScript debugging capabilities. It allows setting and removing\n breakpoints, stepping through execution, exploring stack traces, etc.  \n\n [📖   View this domain on the DevTools Protocol API Docs](https://chromedevtools.github.io/devtools-protocol/1-3/Debugger/)","url":"protocol/debugger.html"},{"doc":"protocol/dom_debugger","title":"DOMBreakpointType","content":"pub type DOMBreakpointType {\n  DOMBreakpointTypeSubtreeModified\n  DOMBreakpointTypeAttributeModified\n  DOMBreakpointTypeNodeRemoved\n}\n DOM breakpoint type.\nDOMBreakpointTypeSubtreeModified\n\n\nDOMBreakpointTypeAttributeModified\n\n\nDOMBreakpointTypeNodeRemoved\n\n\nSynonyms:\nprotocol/dom_debugger.DOMBreakpointType\nprotocol/dom_debugger DOMBreakpointType","url":"protocol/dom_debugger.html#DOMBreakpointType"},{"doc":"protocol/dom_debugger","title":"EventListener","content":"pub type EventListener {\n  EventListener(\n    type_: String,\n    use_capture: Bool,\n    passive: Bool,\n    once: Bool,\n    script_id: runtime.ScriptId,\n    line_number: Int,\n    column_number: Int,\n    handler: option.Option(runtime.RemoteObject),\n    original_handler: option.Option(runtime.RemoteObject),\n    backend_node_id: option.Option(dom.BackendNodeId),\n  )\n}\n Object event listener.\nEventListener(\n  type_: String,\n  use_capture: Bool,\n  passive: Bool,\n  once: Bool,\n  script_id: runtime.ScriptId,\n  line_number: Int,\n  column_number: Int,\n  handler: option.Option(runtime.RemoteObject),\n  original_handler: option.Option(runtime.RemoteObject),\n  backend_node_id: option.Option(dom.BackendNodeId),\n)\n\ntype_\n&lt;p&gt;&lt;code&gt;EventListener&lt;/code&gt;’s type.&lt;/p&gt;\n\nuse_capture\n&lt;p&gt;&lt;code&gt;EventListener&lt;/code&gt;’s useCapture.&lt;/p&gt;\n\npassive\n&lt;p&gt;&lt;code&gt;EventListener&lt;/code&gt;’s passive flag.&lt;/p&gt;\n\nonce\n&lt;p&gt;&lt;code&gt;EventListener&lt;/code&gt;’s once flag.&lt;/p&gt;\n\nscript_id\n&lt;p&gt;Script id of the handler code.&lt;/p&gt;\n\nline_number\n&lt;p&gt;Line number in the script (0-based).&lt;/p&gt;\n\ncolumn_number\n&lt;p&gt;Column number in the script (0-based).&lt;/p&gt;\n\nhandler\n&lt;p&gt;Event handler function value.&lt;/p&gt;\n\noriginal_handler\n&lt;p&gt;Event original handler function value.&lt;/p&gt;\n\nbackend_node_id\n&lt;p&gt;Node the listener is added to (if any).&lt;/p&gt;\n\nSynonyms:\nprotocol/dom_debugger.EventListener\nprotocol/dom_debugger EventListener","url":"protocol/dom_debugger.html#EventListener"},{"doc":"protocol/dom_debugger","title":"GetEventListenersResponse","content":"pub type GetEventListenersResponse {\n  GetEventListenersResponse(listeners: List(EventListener))\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `get_event_listeners`\nGetEventListenersResponse(listeners: List(EventListener))\n\nlisteners\n&lt;p&gt;Array of relevant listeners.&lt;/p&gt;\n\nSynonyms:\nprotocol/dom_debugger.GetEventListenersResponse\nprotocol/dom_debugger GetEventListenersResponse","url":"protocol/dom_debugger.html#GetEventListenersResponse"},{"doc":"protocol/dom_debugger","title":"get_event_listeners","content":"pub fn get_event_listeners(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  object_id object_id: RemoteObjectId,\n  depth depth: Option(Int),\n  pierce pierce: Option(Bool),\n) -&gt; Result(GetEventListenersResponse, RequestError)\n Returns event listeners of the given object.\n \n Parameters:  \n  - `object_id` : Identifier of the object to return listeners for.\n  - `depth` : The maximum depth at which Node children should be retrieved, defaults to 1. Use -1 for the\n entire subtree or provide an integer larger than 0.\n  - `pierce` : Whether or not iframes and shadow roots should be traversed when returning the subtree\n (default is false). Reports listeners for all contexts if pierce is enabled.\n \n Returns:  \n  - `listeners` : Array of relevant listeners.\n \nSynonyms:\nprotocol/dom_debugger.get_event_listeners\nprotocol/dom_debugger get_event_listeners","url":"protocol/dom_debugger.html#get_event_listeners"},{"doc":"protocol/dom_debugger","title":"remove_dom_breakpoint","content":"pub fn remove_dom_breakpoint(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  node_id node_id: NodeId,\n  type_ type_: DOMBreakpointType,\n) -&gt; a\n Removes DOM breakpoint that was set using `setDOMBreakpoint`.\n \n Parameters:  \n  - `node_id` : Identifier of the node to remove breakpoint from.\n  - `type_` : Type of the breakpoint to remove.\n \n Returns:  \n \nSynonyms:\nprotocol/dom_debugger.remove_dom_breakpoint\nprotocol/dom_debugger remove_dom_breakpoint","url":"protocol/dom_debugger.html#remove_dom_breakpoint"},{"doc":"protocol/dom_debugger","title":"remove_event_listener_breakpoint","content":"pub fn remove_event_listener_breakpoint(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  event_name event_name: String,\n) -&gt; a\n Removes breakpoint on particular DOM event.\n \n Parameters:  \n  - `event_name` : Event name.\n \n Returns:  \n \nSynonyms:\nprotocol/dom_debugger.remove_event_listener_breakpoint\nprotocol/dom_debugger remove_event_listener_breakpoint","url":"protocol/dom_debugger.html#remove_event_listener_breakpoint"},{"doc":"protocol/dom_debugger","title":"remove_xhr_breakpoint","content":"pub fn remove_xhr_breakpoint(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  url url: String,\n) -&gt; a\n Removes breakpoint from XMLHttpRequest.\n \n Parameters:  \n  - `url` : Resource URL substring.\n \n Returns:  \n \nSynonyms:\nprotocol/dom_debugger.remove_xhr_breakpoint\nprotocol/dom_debugger remove_xhr_breakpoint","url":"protocol/dom_debugger.html#remove_xhr_breakpoint"},{"doc":"protocol/dom_debugger","title":"set_dom_breakpoint","content":"pub fn set_dom_breakpoint(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  node_id node_id: NodeId,\n  type_ type_: DOMBreakpointType,\n) -&gt; a\n Sets breakpoint on particular operation with DOM.\n \n Parameters:  \n  - `node_id` : Identifier of the node to set breakpoint on.\n  - `type_` : Type of the operation to stop upon.\n \n Returns:  \n \nSynonyms:\nprotocol/dom_debugger.set_dom_breakpoint\nprotocol/dom_debugger set_dom_breakpoint","url":"protocol/dom_debugger.html#set_dom_breakpoint"},{"doc":"protocol/dom_debugger","title":"set_event_listener_breakpoint","content":"pub fn set_event_listener_breakpoint(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  event_name event_name: String,\n) -&gt; a\n Sets breakpoint on particular DOM event.\n \n Parameters:  \n  - `event_name` : DOM Event name to stop on (any DOM event will do).\n \n Returns:  \n \nSynonyms:\nprotocol/dom_debugger.set_event_listener_breakpoint\nprotocol/dom_debugger set_event_listener_breakpoint","url":"protocol/dom_debugger.html#set_event_listener_breakpoint"},{"doc":"protocol/dom_debugger","title":"set_xhr_breakpoint","content":"pub fn set_xhr_breakpoint(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  url url: String,\n) -&gt; a\n Sets breakpoint on XMLHttpRequest.\n \n Parameters:  \n  - `url` : Resource URL substring. All XHRs having this substring in the URL will get stopped upon.\n \n Returns:  \n \nSynonyms:\nprotocol/dom_debugger.set_xhr_breakpoint\nprotocol/dom_debugger set_xhr_breakpoint","url":"protocol/dom_debugger.html#set_xhr_breakpoint"},{"doc":"protocol/dom_debugger","title":"protocol/dom_debugger","content":" &gt; ⚙️  This module was generated from the Chrome DevTools Protocol version **1.3**\n ## DOMDebugger Domain  \n\n DOM debugging allows setting breakpoints on particular DOM operations and events. JavaScript\n execution will stop on these operations as if there was a regular breakpoint set.  \n\n [📖   View this domain on the DevTools Protocol API Docs](https://chromedevtools.github.io/devtools-protocol/1-3/DOMDebugger/)","url":"protocol/dom_debugger.html"},{"doc":"protocol/emulation","title":"DevicePosture","content":"pub type DevicePosture {\n  DevicePosture(type_: DevicePostureType)\n}\n\nDevicePosture(type_: DevicePostureType)\n\ntype_\n&lt;p&gt;Current posture of the device&lt;/p&gt;\n\nSynonyms:\nprotocol/emulation.DevicePosture\nprotocol/emulation DevicePosture","url":"protocol/emulation.html#DevicePosture"},{"doc":"protocol/emulation","title":"DevicePostureType","content":"pub type DevicePostureType {\n  DevicePostureTypeContinuous\n  DevicePostureTypeFolded\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `type` of `DevicePosture`\nDevicePostureTypeContinuous\n\n\nDevicePostureTypeFolded\n\n\nSynonyms:\nprotocol/emulation.DevicePostureType\nprotocol/emulation DevicePostureType","url":"protocol/emulation.html#DevicePostureType"},{"doc":"protocol/emulation","title":"DisplayFeature","content":"pub type DisplayFeature {\n  DisplayFeature(\n    orientation: DisplayFeatureOrientation,\n    offset: Int,\n    mask_length: Int,\n  )\n}\n\nDisplayFeature(\n  orientation: DisplayFeatureOrientation,\n  offset: Int,\n  mask_length: Int,\n)\n\norientation\n&lt;p&gt;Orientation of a display feature in relation to screen&lt;/p&gt;\n\noffset\n&lt;p&gt;The offset from the screen origin in either the x (for vertical\norientation) or y (for horizontal orientation) direction.&lt;/p&gt;\n\nmask_length\n&lt;p&gt;A display feature may mask content such that it is not physically\ndisplayed - this length along with the offset describes this area.\nA display feature that only splits content will have a 0 mask_length.&lt;/p&gt;\n\nSynonyms:\nprotocol/emulation.DisplayFeature\nprotocol/emulation DisplayFeature","url":"protocol/emulation.html#DisplayFeature"},{"doc":"protocol/emulation","title":"DisplayFeatureOrientation","content":"pub type DisplayFeatureOrientation {\n  DisplayFeatureOrientationVertical\n  DisplayFeatureOrientationHorizontal\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `orientation` of `DisplayFeature`\nDisplayFeatureOrientationVertical\n\n\nDisplayFeatureOrientationHorizontal\n\n\nSynonyms:\nprotocol/emulation.DisplayFeatureOrientation\nprotocol/emulation DisplayFeatureOrientation","url":"protocol/emulation.html#DisplayFeatureOrientation"},{"doc":"protocol/emulation","title":"MediaFeature","content":"pub type MediaFeature {\n  MediaFeature(name: String, value: String)\n}\n\nMediaFeature(name: String, value: String)\n\n\nSynonyms:\nprotocol/emulation.MediaFeature\nprotocol/emulation MediaFeature","url":"protocol/emulation.html#MediaFeature"},{"doc":"protocol/emulation","title":"ScreenOrientation","content":"pub type ScreenOrientation {\n  ScreenOrientation(type_: ScreenOrientationType, angle: Int)\n}\n Screen orientation.\nScreenOrientation(type_: ScreenOrientationType, angle: Int)\n\ntype_\n&lt;p&gt;Orientation type.&lt;/p&gt;\n\nangle\n&lt;p&gt;Orientation angle.&lt;/p&gt;\n\nSynonyms:\nprotocol/emulation.ScreenOrientation\nprotocol/emulation ScreenOrientation","url":"protocol/emulation.html#ScreenOrientation"},{"doc":"protocol/emulation","title":"ScreenOrientationType","content":"pub type ScreenOrientationType {\n  ScreenOrientationTypePortraitPrimary\n  ScreenOrientationTypePortraitSecondary\n  ScreenOrientationTypeLandscapePrimary\n  ScreenOrientationTypeLandscapeSecondary\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `type` of `ScreenOrientation`\nScreenOrientationTypePortraitPrimary\n\n\nScreenOrientationTypePortraitSecondary\n\n\nScreenOrientationTypeLandscapePrimary\n\n\nScreenOrientationTypeLandscapeSecondary\n\n\nSynonyms:\nprotocol/emulation.ScreenOrientationType\nprotocol/emulation ScreenOrientationType","url":"protocol/emulation.html#ScreenOrientationType"},{"doc":"protocol/emulation","title":"SetEmulatedVisionDeficiencyType","content":"pub type SetEmulatedVisionDeficiencyType {\n  SetEmulatedVisionDeficiencyTypeNone\n  SetEmulatedVisionDeficiencyTypeBlurredVision\n  SetEmulatedVisionDeficiencyTypeReducedContrast\n  SetEmulatedVisionDeficiencyTypeAchromatopsia\n  SetEmulatedVisionDeficiencyTypeDeuteranopia\n  SetEmulatedVisionDeficiencyTypeProtanopia\n  SetEmulatedVisionDeficiencyTypeTritanopia\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `type` of `setEmulatedVisionDeficiency`\nSetEmulatedVisionDeficiencyTypeNone\n\n\nSetEmulatedVisionDeficiencyTypeBlurredVision\n\n\nSetEmulatedVisionDeficiencyTypeReducedContrast\n\n\nSetEmulatedVisionDeficiencyTypeAchromatopsia\n\n\nSetEmulatedVisionDeficiencyTypeDeuteranopia\n\n\nSetEmulatedVisionDeficiencyTypeProtanopia\n\n\nSetEmulatedVisionDeficiencyTypeTritanopia\n\n\nSynonyms:\nprotocol/emulation.SetEmulatedVisionDeficiencyType\nprotocol/emulation SetEmulatedVisionDeficiencyType","url":"protocol/emulation.html#SetEmulatedVisionDeficiencyType"},{"doc":"protocol/emulation","title":"clear_device_metrics_override","content":"pub fn clear_device_metrics_override(\n  callback__: fn(String, Option(a)) -&gt; b,\n) -&gt; b\n Clears the overridden device metrics.\n \nSynonyms:\nprotocol/emulation.clear_device_metrics_override\nprotocol/emulation clear_device_metrics_override","url":"protocol/emulation.html#clear_device_metrics_override"},{"doc":"protocol/emulation","title":"clear_geolocation_override","content":"pub fn clear_geolocation_override(\n  callback__: fn(String, Option(a)) -&gt; b,\n) -&gt; b\n Clears the overridden Geolocation Position and Error.\n \nSynonyms:\nprotocol/emulation.clear_geolocation_override\nprotocol/emulation clear_geolocation_override","url":"protocol/emulation.html#clear_geolocation_override"},{"doc":"protocol/emulation","title":"clear_idle_override","content":"pub fn clear_idle_override(\n  callback__: fn(String, Option(a)) -&gt; b,\n) -&gt; b\n Clears Idle state overrides.\n \nSynonyms:\nprotocol/emulation.clear_idle_override\nprotocol/emulation clear_idle_override","url":"protocol/emulation.html#clear_idle_override"},{"doc":"protocol/emulation","title":"set_cpu_throttling_rate","content":"pub fn set_cpu_throttling_rate(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  rate rate: Float,\n) -&gt; a\n Enables CPU throttling to emulate slow CPUs.\n \n Parameters:  \n  - `rate` : Throttling rate as a slowdown factor (1 is no throttle, 2 is 2x slowdown, etc).\n \n Returns:  \n \nSynonyms:\nprotocol/emulation.set_cpu_throttling_rate\nprotocol/emulation set_cpu_throttling_rate","url":"protocol/emulation.html#set_cpu_throttling_rate"},{"doc":"protocol/emulation","title":"set_default_background_color_override","content":"pub fn set_default_background_color_override(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  color color: Option(RGBA),\n) -&gt; a\n Sets or clears an override of the default background color of the frame. This override is used\n if the content does not specify one.\n \n Parameters:  \n  - `color` : RGBA of the default background color. If not specified, any existing override will be\n cleared.\n \n Returns:  \n \nSynonyms:\nprotocol/emulation.set_default_background_color_override\nprotocol/emulation set_default_background_color_override","url":"protocol/emulation.html#set_default_background_color_override"},{"doc":"protocol/emulation","title":"set_device_metrics_override","content":"pub fn set_device_metrics_override(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  width width: Int,\n  height height: Int,\n  device_scale_factor device_scale_factor: Float,\n  mobile mobile: Bool,\n  screen_orientation screen_orientation: Option(ScreenOrientation),\n) -&gt; a\n Overrides the values of device screen dimensions (window.screen.width, window.screen.height,\n window.innerWidth, window.innerHeight, and &quot;device-width&quot;/&quot;device-height&quot;-related CSS media\n query results).\n \n Parameters:  \n  - `width` : Overriding width value in pixels (minimum 0, maximum 10000000). 0 disables the override.\n  - `height` : Overriding height value in pixels (minimum 0, maximum 10000000). 0 disables the override.\n  - `device_scale_factor` : Overriding device scale factor value. 0 disables the override.\n  - `mobile` : Whether to emulate mobile device. This includes viewport meta tag, overlay scrollbars, text\n autosizing and more.\n  - `screen_orientation` : Screen orientation override.\n \n Returns:  \n \nSynonyms:\nprotocol/emulation.set_device_metrics_override\nprotocol/emulation set_device_metrics_override","url":"protocol/emulation.html#set_device_metrics_override"},{"doc":"protocol/emulation","title":"set_emulated_media","content":"pub fn set_emulated_media(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  media media: Option(String),\n  features features: Option(List(MediaFeature)),\n) -&gt; a\n Emulates the given media type or media feature for CSS media queries.\n \n Parameters:  \n  - `media` : Media type to emulate. Empty string disables the override.\n  - `features` : Media features to emulate.\n \n Returns:  \n \nSynonyms:\nprotocol/emulation.set_emulated_media\nprotocol/emulation set_emulated_media","url":"protocol/emulation.html#set_emulated_media"},{"doc":"protocol/emulation","title":"set_emulated_vision_deficiency","content":"pub fn set_emulated_vision_deficiency(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  type_ type_: SetEmulatedVisionDeficiencyType,\n) -&gt; a\n Emulates the given vision deficiency.\n \n Parameters:  \n  - `type_` : Vision deficiency to emulate. Order: best-effort emulations come first, followed by any\n physiologically accurate emulations for medically recognized color vision deficiencies.\n \n Returns:  \n \nSynonyms:\nprotocol/emulation.set_emulated_vision_deficiency\nprotocol/emulation set_emulated_vision_deficiency","url":"protocol/emulation.html#set_emulated_vision_deficiency"},{"doc":"protocol/emulation","title":"set_geolocation_override","content":"pub fn set_geolocation_override(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  latitude latitude: Option(Float),\n  longitude longitude: Option(Float),\n  accuracy accuracy: Option(Float),\n) -&gt; a\n Overrides the Geolocation Position or Error. Omitting any of the parameters emulates position\n unavailable.\n \n Parameters:  \n  - `latitude` : Mock latitude\n  - `longitude` : Mock longitude\n  - `accuracy` : Mock accuracy\n \n Returns:  \n \nSynonyms:\nprotocol/emulation.set_geolocation_override\nprotocol/emulation set_geolocation_override","url":"protocol/emulation.html#set_geolocation_override"},{"doc":"protocol/emulation","title":"set_idle_override","content":"pub fn set_idle_override(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  is_user_active is_user_active: Bool,\n  is_screen_unlocked is_screen_unlocked: Bool,\n) -&gt; a\n Overrides the Idle state.\n \n Parameters:  \n  - `is_user_active` : Mock isUserActive\n  - `is_screen_unlocked` : Mock isScreenUnlocked\n \n Returns:  \n \nSynonyms:\nprotocol/emulation.set_idle_override\nprotocol/emulation set_idle_override","url":"protocol/emulation.html#set_idle_override"},{"doc":"protocol/emulation","title":"set_script_execution_disabled","content":"pub fn set_script_execution_disabled(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  value value: Bool,\n) -&gt; a\n Switches script execution in the page.\n \n Parameters:  \n  - `value` : Whether script execution should be disabled in the page.\n \n Returns:  \n \nSynonyms:\nprotocol/emulation.set_script_execution_disabled\nprotocol/emulation set_script_execution_disabled","url":"protocol/emulation.html#set_script_execution_disabled"},{"doc":"protocol/emulation","title":"set_timezone_override","content":"pub fn set_timezone_override(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  timezone_id timezone_id: String,\n) -&gt; a\n Overrides default host system timezone with the specified one.\n \n Parameters:  \n  - `timezone_id` : The timezone identifier. List of supported timezones:\n https://source.chromium.org/chromium/chromium/deps/icu.git/+/faee8bc70570192d82d2978a71e2a615788597d1:source/data/misc/metaZones.txt\n If empty, disables the override and restores default host system timezone.\n \n Returns:  \n \nSynonyms:\nprotocol/emulation.set_timezone_override\nprotocol/emulation set_timezone_override","url":"protocol/emulation.html#set_timezone_override"},{"doc":"protocol/emulation","title":"set_touch_emulation_enabled","content":"pub fn set_touch_emulation_enabled(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  enabled enabled: Bool,\n  max_touch_points max_touch_points: Option(Int),\n) -&gt; a\n Enables touch on platforms which do not support them.\n \n Parameters:  \n  - `enabled` : Whether the touch event emulation should be enabled.\n  - `max_touch_points` : Maximum touch points supported. Defaults to one.\n \n Returns:  \n \nSynonyms:\nprotocol/emulation.set_touch_emulation_enabled\nprotocol/emulation set_touch_emulation_enabled","url":"protocol/emulation.html#set_touch_emulation_enabled"},{"doc":"protocol/emulation","title":"set_user_agent_override","content":"pub fn set_user_agent_override(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  user_agent user_agent: String,\n  accept_language accept_language: Option(String),\n  platform platform: Option(String),\n) -&gt; a\n Allows overriding user agent with the given string.\n `userAgentMetadata` must be set for Client Hint headers to be sent.\n \n Parameters:  \n  - `user_agent` : User agent to use.\n  - `accept_language` : Browser language to emulate.\n  - `platform` : The platform navigator.platform should return.\n \n Returns:  \n \nSynonyms:\nprotocol/emulation.set_user_agent_override\nprotocol/emulation set_user_agent_override","url":"protocol/emulation.html#set_user_agent_override"},{"doc":"protocol/emulation","title":"protocol/emulation","content":" &gt; ⚙️  This module was generated from the Chrome DevTools Protocol version **1.3**\n ## Emulation Domain  \n\n This domain emulates different environments for the page.  \n\n [📖   View this domain on the DevTools Protocol API Docs](https://chromedevtools.github.io/devtools-protocol/1-3/Emulation/)","url":"protocol/emulation.html"},{"doc":"protocol/io","title":"ReadResponse","content":"pub type ReadResponse {\n  ReadResponse(\n    base64_encoded: option.Option(Bool),\n    data: String,\n    eof: Bool,\n  )\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `read`\nReadResponse(\n  base64_encoded: option.Option(Bool),\n  data: String,\n  eof: Bool,\n)\n\nbase64_encoded\n&lt;p&gt;Set if the data is base64-encoded&lt;/p&gt;\n\ndata\n&lt;p&gt;Data that were read.&lt;/p&gt;\n\neof\n&lt;p&gt;Set if the end-of-file condition occurred while reading.&lt;/p&gt;\n\nSynonyms:\nprotocol/io.ReadResponse\nprotocol/io ReadResponse","url":"protocol/io.html#ReadResponse"},{"doc":"protocol/io","title":"ResolveBlobResponse","content":"pub type ResolveBlobResponse {\n  ResolveBlobResponse(uuid: String)\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `resolve_blob`\nResolveBlobResponse(uuid: String)\n\nuuid\n&lt;p&gt;UUID of the specified Blob.&lt;/p&gt;\n\nSynonyms:\nprotocol/io.ResolveBlobResponse\nprotocol/io ResolveBlobResponse","url":"protocol/io.html#ResolveBlobResponse"},{"doc":"protocol/io","title":"StreamHandle","content":"pub type StreamHandle {\n  StreamHandle(String)\n}\n This is either obtained from another method or specified as `blob:&lt;uuid&gt;` where\n `&lt;uuid&gt;` is an UUID of a Blob.\nStreamHandle(String)\n\n\nSynonyms:\nprotocol/io.StreamHandle\nprotocol/io StreamHandle","url":"protocol/io.html#StreamHandle"},{"doc":"protocol/io","title":"close","content":"pub fn close(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  handle handle: StreamHandle,\n) -&gt; a\n Close the stream, discard any temporary backing storage.\n \n Parameters:  \n  - `handle` : Handle of the stream to close.\n \n Returns:  \n \nSynonyms:\nprotocol/io.close\nprotocol/io close","url":"protocol/io.html#close"},{"doc":"protocol/io","title":"read","content":"pub fn read(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  handle handle: StreamHandle,\n  offset offset: Option(Int),\n  size size: Option(Int),\n) -&gt; Result(ReadResponse, RequestError)\n Read a chunk of the stream\n \n Parameters:  \n  - `handle` : Handle of the stream to read.\n  - `offset` : Seek to the specified offset before reading (if not specified, proceed with offset\n following the last read). Some types of streams may only support sequential reads.\n  - `size` : Maximum number of bytes to read (left upon the agent discretion if not specified).\n \n Returns:  \n  - `base64_encoded` : Set if the data is base64-encoded\n  - `data` : Data that were read.\n  - `eof` : Set if the end-of-file condition occurred while reading.\n \nSynonyms:\nprotocol/io.read\nprotocol/io read","url":"protocol/io.html#read"},{"doc":"protocol/io","title":"resolve_blob","content":"pub fn resolve_blob(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  object_id object_id: RemoteObjectId,\n) -&gt; Result(ResolveBlobResponse, RequestError)\n Return UUID of Blob object specified by a remote object id.\n \n Parameters:  \n  - `object_id` : Object id of a Blob object wrapper.\n \n Returns:  \n  - `uuid` : UUID of the specified Blob.\n \nSynonyms:\nprotocol/io.resolve_blob\nprotocol/io resolve_blob","url":"protocol/io.html#resolve_blob"},{"doc":"protocol/io","title":"protocol/io","content":" &gt; ⚙️  This module was generated from the Chrome DevTools Protocol version **1.3**\n ## IO Domain  \n\n Input/Output operations for streams produced by DevTools.  \n\n [📖   View this domain on the DevTools Protocol API Docs](https://chromedevtools.github.io/devtools-protocol/1-3/IO/)","url":"protocol/io.html"},{"doc":"protocol/fetch","title":"AuthChallenge","content":"pub type AuthChallenge {\n  AuthChallenge(\n    source: option.Option(AuthChallengeSource),\n    origin: String,\n    scheme: String,\n    realm: String,\n  )\n}\n Authorization challenge for HTTP status code 401 or 407.\nAuthChallenge(\n  source: option.Option(AuthChallengeSource),\n  origin: String,\n  scheme: String,\n  realm: String,\n)\n\nsource\n&lt;p&gt;Source of the authentication challenge.&lt;/p&gt;\n\norigin\n&lt;p&gt;Origin of the challenger.&lt;/p&gt;\n\nscheme\n&lt;p&gt;The authentication scheme used, such as basic or digest&lt;/p&gt;\n\nrealm\n&lt;p&gt;The realm of the challenge. May be empty.&lt;/p&gt;\n\nSynonyms:\nprotocol/fetch.AuthChallenge\nprotocol/fetch AuthChallenge","url":"protocol/fetch.html#AuthChallenge"},{"doc":"protocol/fetch","title":"AuthChallengeResponse","content":"pub type AuthChallengeResponse {\n  AuthChallengeResponse(\n    response: AuthChallengeResponseResponse,\n    username: option.Option(String),\n    password: option.Option(String),\n  )\n}\n Response to an AuthChallenge.\nAuthChallengeResponse(\n  response: AuthChallengeResponseResponse,\n  username: option.Option(String),\n  password: option.Option(String),\n)\n\nresponse\n&lt;p&gt;The decision on what to do in response to the authorization challenge.  Default means\ndeferring to the default behavior of the net stack, which will likely either the Cancel\nauthentication or display a popup dialog box.&lt;/p&gt;\n\nusername\n&lt;p&gt;The username to provide, possibly empty. Should only be set if response is\nProvideCredentials.&lt;/p&gt;\n\npassword\n&lt;p&gt;The password to provide, possibly empty. Should only be set if response is\nProvideCredentials.&lt;/p&gt;\n\nSynonyms:\nprotocol/fetch.AuthChallengeResponse\nprotocol/fetch AuthChallengeResponse","url":"protocol/fetch.html#AuthChallengeResponse"},{"doc":"protocol/fetch","title":"AuthChallengeResponseResponse","content":"pub type AuthChallengeResponseResponse {\n  AuthChallengeResponseResponseDefault\n  AuthChallengeResponseResponseCancelAuth\n  AuthChallengeResponseResponseProvideCredentials\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `response` of `AuthChallengeResponse`\nAuthChallengeResponseResponseDefault\n\n\nAuthChallengeResponseResponseCancelAuth\n\n\nAuthChallengeResponseResponseProvideCredentials\n\n\nSynonyms:\nprotocol/fetch.AuthChallengeResponseResponse\nprotocol/fetch AuthChallengeResponseResponse","url":"protocol/fetch.html#AuthChallengeResponseResponse"},{"doc":"protocol/fetch","title":"AuthChallengeSource","content":"pub type AuthChallengeSource {\n  AuthChallengeSourceServer\n  AuthChallengeSourceProxy\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `source` of `AuthChallenge`\nAuthChallengeSourceServer\n\n\nAuthChallengeSourceProxy\n\n\nSynonyms:\nprotocol/fetch.AuthChallengeSource\nprotocol/fetch AuthChallengeSource","url":"protocol/fetch.html#AuthChallengeSource"},{"doc":"protocol/fetch","title":"GetResponseBodyResponse","content":"pub type GetResponseBodyResponse {\n  GetResponseBodyResponse(body: String, base64_encoded: Bool)\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `get_response_body`\nGetResponseBodyResponse(body: String, base64_encoded: Bool)\n\nbody\n&lt;p&gt;Response body.&lt;/p&gt;\n\nbase64_encoded\n&lt;p&gt;True, if content was sent as base64.&lt;/p&gt;\n\nSynonyms:\nprotocol/fetch.GetResponseBodyResponse\nprotocol/fetch GetResponseBodyResponse","url":"protocol/fetch.html#GetResponseBodyResponse"},{"doc":"protocol/fetch","title":"HeaderEntry","content":"pub type HeaderEntry {\n  HeaderEntry(name: String, value: String)\n}\n Response HTTP header entry\nHeaderEntry(name: String, value: String)\n\n\nSynonyms:\nprotocol/fetch.HeaderEntry\nprotocol/fetch HeaderEntry","url":"protocol/fetch.html#HeaderEntry"},{"doc":"protocol/fetch","title":"RequestId","content":"pub type RequestId {\n  RequestId(String)\n}\n Unique request identifier.\nRequestId(String)\n\n\nSynonyms:\nprotocol/fetch.RequestId\nprotocol/fetch RequestId","url":"protocol/fetch.html#RequestId"},{"doc":"protocol/fetch","title":"RequestPattern","content":"pub type RequestPattern {\n  RequestPattern(\n    url_pattern: option.Option(String),\n    resource_type: option.Option(network.ResourceType),\n    request_stage: option.Option(RequestStage),\n  )\n}\n\nRequestPattern(\n  url_pattern: option.Option(String),\n  resource_type: option.Option(network.ResourceType),\n  request_stage: option.Option(RequestStage),\n)\n\nurl_pattern\n&lt;p&gt;Wildcards (&lt;code&gt;&#39;*&#39;&lt;/code&gt; -&amp;gt; zero or more, &lt;code&gt;&#39;?&#39;&lt;/code&gt; -&amp;gt; exactly one) are allowed. Escape character is\nbackslash. Omitting is equivalent to &lt;code&gt;&quot;*&quot;&lt;/code&gt;.&lt;/p&gt;\n\nresource_type\n&lt;p&gt;If set, only requests for matching resource types will be intercepted.&lt;/p&gt;\n\nrequest_stage\n&lt;p&gt;Stage at which to begin intercepting requests. Default is Request.&lt;/p&gt;\n\nSynonyms:\nprotocol/fetch.RequestPattern\nprotocol/fetch RequestPattern","url":"protocol/fetch.html#RequestPattern"},{"doc":"protocol/fetch","title":"RequestStage","content":"pub type RequestStage {\n  RequestStageRequest\n  RequestStageResponse\n}\n Stages of the request to handle. Request will intercept before the request is\n sent. Response will intercept after the response is received (but before response\n body is received).\nRequestStageRequest\n\n\nRequestStageResponse\n\n\nSynonyms:\nprotocol/fetch.RequestStage\nprotocol/fetch RequestStage","url":"protocol/fetch.html#RequestStage"},{"doc":"protocol/fetch","title":"TakeResponseBodyAsStreamResponse","content":"pub type TakeResponseBodyAsStreamResponse {\n  TakeResponseBodyAsStreamResponse(stream: io.StreamHandle)\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `take_response_body_as_stream`\nTakeResponseBodyAsStreamResponse(stream: io.StreamHandle)\n\n\nSynonyms:\nprotocol/fetch.TakeResponseBodyAsStreamResponse\nprotocol/fetch TakeResponseBodyAsStreamResponse","url":"protocol/fetch.html#TakeResponseBodyAsStreamResponse"},{"doc":"protocol/fetch","title":"continue_request","content":"pub fn continue_request(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  request_id request_id: RequestId,\n  url url: Option(String),\n  method method: Option(String),\n  post_data post_data: Option(String),\n  headers headers: Option(List(HeaderEntry)),\n) -&gt; a\n Continues the request, optionally modifying some of its parameters.\n \n Parameters:  \n  - `request_id` : An id the client received in requestPaused event.\n  - `url` : If set, the request url will be modified in a way that&#39;s not observable by page.\n  - `method` : If set, the request method is overridden.\n  - `post_data` : If set, overrides the post data in the request. (Encoded as a base64 string when passed over JSON)\n  - `headers` : If set, overrides the request headers. Note that the overrides do not\n extend to subsequent redirect hops, if a redirect happens. Another override\n may be applied to a different request produced by a redirect.\n \n Returns:  \n \nSynonyms:\nprotocol/fetch.continue_request\nprotocol/fetch continue_request","url":"protocol/fetch.html#continue_request"},{"doc":"protocol/fetch","title":"continue_with_auth","content":"pub fn continue_with_auth(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  request_id request_id: RequestId,\n  auth_challenge_response auth_challenge_response: AuthChallengeResponse,\n) -&gt; a\n Continues a request supplying authChallengeResponse following authRequired event.\n \n Parameters:  \n  - `request_id` : An id the client received in authRequired event.\n  - `auth_challenge_response` : Response to  with an authChallenge.\n \n Returns:  \n \nSynonyms:\nprotocol/fetch.continue_with_auth\nprotocol/fetch continue_with_auth","url":"protocol/fetch.html#continue_with_auth"},{"doc":"protocol/fetch","title":"disable","content":"pub fn disable(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n Disables the fetch domain.\n \nSynonyms:\nprotocol/fetch.disable\nprotocol/fetch disable","url":"protocol/fetch.html#disable"},{"doc":"protocol/fetch","title":"enable","content":"pub fn enable(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  patterns patterns: Option(List(RequestPattern)),\n  handle_auth_requests handle_auth_requests: Option(Bool),\n) -&gt; a\n Enables issuing of requestPaused events. A request will be paused until client\n calls one of failRequest, fulfillRequest or continueRequest/continueWithAuth.\n \n Parameters:  \n  - `patterns` : If specified, only requests matching any of these patterns will produce\n fetchRequested event and will be paused until clients response. If not set,\n all requests will be affected.\n  - `handle_auth_requests` : If true, authRequired events will be issued and requests will be paused\n expecting a call to continueWithAuth.\n \n Returns:  \n \nSynonyms:\nprotocol/fetch.enable\nprotocol/fetch enable","url":"protocol/fetch.html#enable"},{"doc":"protocol/fetch","title":"fail_request","content":"pub fn fail_request(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  request_id request_id: RequestId,\n  error_reason error_reason: ErrorReason,\n) -&gt; a\n Causes the request to fail with specified reason.\n \n Parameters:  \n  - `request_id` : An id the client received in requestPaused event.\n  - `error_reason` : Causes the request to fail with the given reason.\n \n Returns:  \n \nSynonyms:\nprotocol/fetch.fail_request\nprotocol/fetch fail_request","url":"protocol/fetch.html#fail_request"},{"doc":"protocol/fetch","title":"fulfill_request","content":"pub fn fulfill_request(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  request_id request_id: RequestId,\n  response_code response_code: Int,\n  response_headers response_headers: Option(List(HeaderEntry)),\n  binary_response_headers binary_response_headers: Option(String),\n  body body: Option(String),\n  response_phrase response_phrase: Option(String),\n) -&gt; a\n Provides response to the request.\n \n Parameters:  \n  - `request_id` : An id the client received in requestPaused event.\n  - `response_code` : An HTTP response code.\n  - `response_headers` : Response headers.\n  - `binary_response_headers` : Alternative way of specifying response headers as a \\0-separated\n series of name: value pairs. Prefer the above method unless you\n need to represent some non-UTF8 values that can&#39;t be transmitted\n over the protocol as text. (Encoded as a base64 string when passed over JSON)\n  - `body` : A response body. If absent, original response body will be used if\n the request is intercepted at the response stage and empty body\n will be used if the request is intercepted at the request stage. (Encoded as a base64 string when passed over JSON)\n  - `response_phrase` : A textual representation of responseCode.\n If absent, a standard phrase matching responseCode is used.\n \n Returns:  \n \nSynonyms:\nprotocol/fetch.fulfill_request\nprotocol/fetch fulfill_request","url":"protocol/fetch.html#fulfill_request"},{"doc":"protocol/fetch","title":"get_response_body","content":"pub fn get_response_body(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  request_id request_id: RequestId,\n) -&gt; Result(GetResponseBodyResponse, RequestError)\n Causes the body of the response to be received from the server and\n returned as a single string. May only be issued for a request that\n is paused in the Response stage and is mutually exclusive with\n takeResponseBodyForInterceptionAsStream. Calling other methods that\n affect the request or disabling fetch domain before body is received\n results in an undefined behavior.\n Note that the response body is not available for redirects. Requests\n paused in the _redirect received_ state may be differentiated by\n `responseCode` and presence of `location` response header, see\n comments to `requestPaused` for details.\n \n Parameters:  \n  - `request_id` : Identifier for the intercepted request to get body for.\n \n Returns:  \n  - `body` : Response body.\n  - `base64_encoded` : True, if content was sent as base64.\n \nSynonyms:\nprotocol/fetch.get_response_body\nprotocol/fetch get_response_body","url":"protocol/fetch.html#get_response_body"},{"doc":"protocol/fetch","title":"take_response_body_as_stream","content":"pub fn take_response_body_as_stream(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  request_id request_id: RequestId,\n) -&gt; Result(TakeResponseBodyAsStreamResponse, RequestError)\n Returns a handle to the stream representing the response body.\n The request must be paused in the HeadersReceived stage.\n Note that after this command the request can&#39;t be continued\n as is -- client either needs to cancel it or to provide the\n response body.\n The stream only supports sequential read, IO.read will fail if the position\n is specified.\n This method is mutually exclusive with getResponseBody.\n Calling other methods that affect the request or disabling fetch\n domain before body is received results in an undefined behavior.\n \n Parameters:  \n  - `request_id`\n \n Returns:  \n  - `stream`\n \nSynonyms:\nprotocol/fetch.take_response_body_as_stream\nprotocol/fetch take_response_body_as_stream","url":"protocol/fetch.html#take_response_body_as_stream"},{"doc":"protocol/fetch","title":"protocol/fetch","content":" &gt; ⚙️  This module was generated from the Chrome DevTools Protocol version **1.3**\n ## Fetch Domain  \n\n A domain for letting clients substitute browser&#39;s network layer with client code.  \n\n [📖   View this domain on the DevTools Protocol API Docs](https://chromedevtools.github.io/devtools-protocol/1-3/Fetch/)","url":"protocol/fetch.html"},{"doc":"protocol/log","title":"LogEntry","content":"pub type LogEntry {\n  LogEntry(\n    source: LogEntrySource,\n    level: LogEntryLevel,\n    text: String,\n    category: option.Option(LogEntryCategory),\n    timestamp: runtime.Timestamp,\n    url: option.Option(String),\n    line_number: option.Option(Int),\n    stack_trace: option.Option(runtime.StackTrace),\n    network_request_id: option.Option(network.RequestId),\n    worker_id: option.Option(String),\n    args: option.Option(List(runtime.RemoteObject)),\n  )\n}\n Log entry.\nLogEntry(\n  source: LogEntrySource,\n  level: LogEntryLevel,\n  text: String,\n  category: option.Option(LogEntryCategory),\n  timestamp: runtime.Timestamp,\n  url: option.Option(String),\n  line_number: option.Option(Int),\n  stack_trace: option.Option(runtime.StackTrace),\n  network_request_id: option.Option(network.RequestId),\n  worker_id: option.Option(String),\n  args: option.Option(List(runtime.RemoteObject)),\n)\n\nsource\n&lt;p&gt;Log entry source.&lt;/p&gt;\n\nlevel\n&lt;p&gt;Log entry severity.&lt;/p&gt;\n\ntext\n&lt;p&gt;Logged text.&lt;/p&gt;\n\ntimestamp\n&lt;p&gt;Timestamp when this entry was added.&lt;/p&gt;\n\nurl\n&lt;p&gt;URL of the resource if known.&lt;/p&gt;\n\nline_number\n&lt;p&gt;Line number in the resource.&lt;/p&gt;\n\nstack_trace\n&lt;p&gt;JavaScript stack trace.&lt;/p&gt;\n\nnetwork_request_id\n&lt;p&gt;Identifier of the network request associated with this entry.&lt;/p&gt;\n\nworker_id\n&lt;p&gt;Identifier of the worker associated with this entry.&lt;/p&gt;\n\nargs\n&lt;p&gt;Call arguments.&lt;/p&gt;\n\nSynonyms:\nprotocol/log.LogEntry\nprotocol/log LogEntry","url":"protocol/log.html#LogEntry"},{"doc":"protocol/log","title":"LogEntryCategory","content":"pub type LogEntryCategory {\n  LogEntryCategoryCors\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `category` of `LogEntry`\nLogEntryCategoryCors\n\n\nSynonyms:\nprotocol/log.LogEntryCategory\nprotocol/log LogEntryCategory","url":"protocol/log.html#LogEntryCategory"},{"doc":"protocol/log","title":"LogEntryLevel","content":"pub type LogEntryLevel {\n  LogEntryLevelVerbose\n  LogEntryLevelInfo\n  LogEntryLevelWarning\n  LogEntryLevelError\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `level` of `LogEntry`\nLogEntryLevelVerbose\n\n\nLogEntryLevelInfo\n\n\nLogEntryLevelWarning\n\n\nLogEntryLevelError\n\n\nSynonyms:\nprotocol/log.LogEntryLevel\nprotocol/log LogEntryLevel","url":"protocol/log.html#LogEntryLevel"},{"doc":"protocol/log","title":"LogEntrySource","content":"pub type LogEntrySource {\n  LogEntrySourceXml\n  LogEntrySourceJavascript\n  LogEntrySourceNetwork\n  LogEntrySourceStorage\n  LogEntrySourceAppcache\n  LogEntrySourceRendering\n  LogEntrySourceSecurity\n  LogEntrySourceDeprecation\n  LogEntrySourceWorker\n  LogEntrySourceViolation\n  LogEntrySourceIntervention\n  LogEntrySourceRecommendation\n  LogEntrySourceOther\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `source` of `LogEntry`\nLogEntrySourceXml\n\n\nLogEntrySourceJavascript\n\n\nLogEntrySourceNetwork\n\n\nLogEntrySourceStorage\n\n\nLogEntrySourceAppcache\n\n\nLogEntrySourceRendering\n\n\nLogEntrySourceSecurity\n\n\nLogEntrySourceDeprecation\n\n\nLogEntrySourceWorker\n\n\nLogEntrySourceViolation\n\n\nLogEntrySourceIntervention\n\n\nLogEntrySourceRecommendation\n\n\nLogEntrySourceOther\n\n\nSynonyms:\nprotocol/log.LogEntrySource\nprotocol/log LogEntrySource","url":"protocol/log.html#LogEntrySource"},{"doc":"protocol/log","title":"ViolationSetting","content":"pub type ViolationSetting {\n  ViolationSetting(name: ViolationSettingName, threshold: Float)\n}\n Violation configuration setting.\nViolationSetting(name: ViolationSettingName, threshold: Float)\n\nname\n&lt;p&gt;Violation type.&lt;/p&gt;\n\nthreshold\n&lt;p&gt;Time threshold to trigger upon.&lt;/p&gt;\n\nSynonyms:\nprotocol/log.ViolationSetting\nprotocol/log ViolationSetting","url":"protocol/log.html#ViolationSetting"},{"doc":"protocol/log","title":"ViolationSettingName","content":"pub type ViolationSettingName {\n  ViolationSettingNameLongTask\n  ViolationSettingNameLongLayout\n  ViolationSettingNameBlockedEvent\n  ViolationSettingNameBlockedParser\n  ViolationSettingNameDiscouragedApiUse\n  ViolationSettingNameHandler\n  ViolationSettingNameRecurringHandler\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `name` of `ViolationSetting`\nViolationSettingNameLongTask\n\n\nViolationSettingNameLongLayout\n\n\nViolationSettingNameBlockedEvent\n\n\nViolationSettingNameBlockedParser\n\n\nViolationSettingNameDiscouragedApiUse\n\n\nViolationSettingNameHandler\n\n\nViolationSettingNameRecurringHandler\n\n\nSynonyms:\nprotocol/log.ViolationSettingName\nprotocol/log ViolationSettingName","url":"protocol/log.html#ViolationSettingName"},{"doc":"protocol/log","title":"clear","content":"pub fn clear(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n Clears the log.\n \nSynonyms:\nprotocol/log.clear\nprotocol/log clear","url":"protocol/log.html#clear"},{"doc":"protocol/log","title":"disable","content":"pub fn disable(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n Disables log domain, prevents further log entries from being reported to the client.\n \nSynonyms:\nprotocol/log.disable\nprotocol/log disable","url":"protocol/log.html#disable"},{"doc":"protocol/log","title":"enable","content":"pub fn enable(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n Enables log domain, sends the entries collected so far to the client by means of the\n `entryAdded` notification.\n \nSynonyms:\nprotocol/log.enable\nprotocol/log enable","url":"protocol/log.html#enable"},{"doc":"protocol/log","title":"start_violations_report","content":"pub fn start_violations_report(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  config config: List(ViolationSetting),\n) -&gt; a\n start violation reporting.\n \n Parameters:  \n  - `config` : Configuration for violations.\n \n Returns:  \n \nSynonyms:\nprotocol/log.start_violations_report\nprotocol/log start_violations_report","url":"protocol/log.html#start_violations_report"},{"doc":"protocol/log","title":"stop_violations_report","content":"pub fn stop_violations_report(\n  callback__: fn(String, Option(a)) -&gt; b,\n) -&gt; b\n Stop violation reporting.\n \nSynonyms:\nprotocol/log.stop_violations_report\nprotocol/log stop_violations_report","url":"protocol/log.html#stop_violations_report"},{"doc":"protocol/log","title":"protocol/log","content":" &gt; ⚙️  This module was generated from the Chrome DevTools Protocol version **1.3**\n ## Log Domain  \n\n Provides access to log entries.  \n\n [📖   View this domain on the DevTools Protocol API Docs](https://chromedevtools.github.io/devtools-protocol/1-3/Log/)","url":"protocol/log.html"},{"doc":"protocol/performance","title":"EnableTimeDomain","content":"pub type EnableTimeDomain {\n  EnableTimeDomainTimeTicks\n  EnableTimeDomainThreadTicks\n}\n This type is not part of the protocol spec, it has been generated dynamically \n to represent the possible values of the enum property `timeDomain` of `enable`\nEnableTimeDomainTimeTicks\n\n\nEnableTimeDomainThreadTicks\n\n\nSynonyms:\nprotocol/performance.EnableTimeDomain\nprotocol/performance EnableTimeDomain","url":"protocol/performance.html#EnableTimeDomain"},{"doc":"protocol/performance","title":"GetMetricsResponse","content":"pub type GetMetricsResponse {\n  GetMetricsResponse(metrics: List(Metric))\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `get_metrics`\nGetMetricsResponse(metrics: List(Metric))\n\nmetrics\n&lt;p&gt;Current values for run-time metrics.&lt;/p&gt;\n\nSynonyms:\nprotocol/performance.GetMetricsResponse\nprotocol/performance GetMetricsResponse","url":"protocol/performance.html#GetMetricsResponse"},{"doc":"protocol/performance","title":"Metric","content":"pub type Metric {\n  Metric(name: String, value: Float)\n}\n Run-time execution metric.\nMetric(name: String, value: Float)\n\nname\n&lt;p&gt;Metric name.&lt;/p&gt;\n\nvalue\n&lt;p&gt;Metric value.&lt;/p&gt;\n\nSynonyms:\nprotocol/performance.Metric\nprotocol/performance Metric","url":"protocol/performance.html#Metric"},{"doc":"protocol/performance","title":"disable","content":"pub fn disable(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n Disable collecting and reporting metrics.\n \nSynonyms:\nprotocol/performance.disable\nprotocol/performance disable","url":"protocol/performance.html#disable"},{"doc":"protocol/performance","title":"enable","content":"pub fn enable(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  time_domain time_domain: Option(EnableTimeDomain),\n) -&gt; a\n Enable collecting and reporting metrics.\n \n Parameters:  \n  - `time_domain` : Time domain to use for collecting and reporting duration metrics.\n \n Returns:  \n \nSynonyms:\nprotocol/performance.enable\nprotocol/performance enable","url":"protocol/performance.html#enable"},{"doc":"protocol/performance","title":"get_metrics","content":"pub fn get_metrics(\n  callback__: fn(String, Option(a)) -&gt;\n    Result(Dynamic, RequestError),\n) -&gt; Result(GetMetricsResponse, RequestError)\n Retrieve current values of run-time metrics.\n  - `metrics` : Current values for run-time metrics.\n \nSynonyms:\nprotocol/performance.get_metrics\nprotocol/performance get_metrics","url":"protocol/performance.html#get_metrics"},{"doc":"protocol/performance","title":"protocol/performance","content":" &gt; ⚙️  This module was generated from the Chrome DevTools Protocol version **1.3**\n ## Performance Domain  \n\n This protocol domain has no description.  \n\n [📖   View this domain on the DevTools Protocol API Docs](https://chromedevtools.github.io/devtools-protocol/1-3/Performance/)","url":"protocol/performance.html"},{"doc":"protocol/profiler","title":"CoverageRange","content":"pub type CoverageRange {\n  CoverageRange(start_offset: Int, end_offset: Int, count: Int)\n}\n Coverage data for a source range.\nCoverageRange(start_offset: Int, end_offset: Int, count: Int)\n\nstart_offset\n&lt;p&gt;JavaScript script source offset for the range start.&lt;/p&gt;\n\nend_offset\n&lt;p&gt;JavaScript script source offset for the range end.&lt;/p&gt;\n\ncount\n&lt;p&gt;Collected execution count of the source range.&lt;/p&gt;\n\nSynonyms:\nprotocol/profiler.CoverageRange\nprotocol/profiler CoverageRange","url":"protocol/profiler.html#CoverageRange"},{"doc":"protocol/profiler","title":"FunctionCoverage","content":"pub type FunctionCoverage {\n  FunctionCoverage(\n    function_name: String,\n    ranges: List(CoverageRange),\n    is_block_coverage: Bool,\n  )\n}\n Coverage data for a JavaScript function.\nFunctionCoverage(\n  function_name: String,\n  ranges: List(CoverageRange),\n  is_block_coverage: Bool,\n)\n\nfunction_name\n&lt;p&gt;JavaScript function name.&lt;/p&gt;\n\nranges\n&lt;p&gt;Source ranges inside the function with coverage data.&lt;/p&gt;\n\nis_block_coverage\n&lt;p&gt;Whether coverage data for this function has block granularity.&lt;/p&gt;\n\nSynonyms:\nprotocol/profiler.FunctionCoverage\nprotocol/profiler FunctionCoverage","url":"protocol/profiler.html#FunctionCoverage"},{"doc":"protocol/profiler","title":"GetBestEffortCoverageResponse","content":"pub type GetBestEffortCoverageResponse {\n  GetBestEffortCoverageResponse(result: List(ScriptCoverage))\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `get_best_effort_coverage`\nGetBestEffortCoverageResponse(result: List(ScriptCoverage))\n\nresult\n&lt;p&gt;Coverage data for the current isolate.&lt;/p&gt;\n\nSynonyms:\nprotocol/profiler.GetBestEffortCoverageResponse\nprotocol/profiler GetBestEffortCoverageResponse","url":"protocol/profiler.html#GetBestEffortCoverageResponse"},{"doc":"protocol/profiler","title":"PositionTickInfo","content":"pub type PositionTickInfo {\n  PositionTickInfo(line: Int, ticks: Int)\n}\n Specifies a number of samples attributed to a certain source position.\nPositionTickInfo(line: Int, ticks: Int)\n\nline\n&lt;p&gt;Source line number (1-based).&lt;/p&gt;\n\nticks\n&lt;p&gt;Number of samples attributed to the source line.&lt;/p&gt;\n\nSynonyms:\nprotocol/profiler.PositionTickInfo\nprotocol/profiler PositionTickInfo","url":"protocol/profiler.html#PositionTickInfo"},{"doc":"protocol/profiler","title":"Profile","content":"pub type Profile {\n  Profile(\n    nodes: List(ProfileNode),\n    start_time: Float,\n    end_time: Float,\n    samples: option.Option(List(Int)),\n    time_deltas: option.Option(List(Int)),\n  )\n}\n Profile.\nProfile(\n  nodes: List(ProfileNode),\n  start_time: Float,\n  end_time: Float,\n  samples: option.Option(List(Int)),\n  time_deltas: option.Option(List(Int)),\n)\n\nnodes\n&lt;p&gt;The list of profile nodes. First item is the root node.&lt;/p&gt;\n\nstart_time\n&lt;p&gt;Profiling start timestamp in microseconds.&lt;/p&gt;\n\nend_time\n&lt;p&gt;Profiling end timestamp in microseconds.&lt;/p&gt;\n\nsamples\n&lt;p&gt;Ids of samples top nodes.&lt;/p&gt;\n\ntime_deltas\n&lt;p&gt;Time intervals between adjacent samples in microseconds. The first delta is relative to the\nprofile startTime.&lt;/p&gt;\n\nSynonyms:\nprotocol/profiler.Profile\nprotocol/profiler Profile","url":"protocol/profiler.html#Profile"},{"doc":"protocol/profiler","title":"ProfileNode","content":"pub type ProfileNode {\n  ProfileNode(\n    id: Int,\n    call_frame: runtime.CallFrame,\n    hit_count: option.Option(Int),\n    children: option.Option(List(Int)),\n    deopt_reason: option.Option(String),\n    position_ticks: option.Option(List(PositionTickInfo)),\n  )\n}\n Profile node. Holds callsite information, execution statistics and child nodes.\nProfileNode(\n  id: Int,\n  call_frame: runtime.CallFrame,\n  hit_count: option.Option(Int),\n  children: option.Option(List(Int)),\n  deopt_reason: option.Option(String),\n  position_ticks: option.Option(List(PositionTickInfo)),\n)\n\nid\n&lt;p&gt;Unique id of the node.&lt;/p&gt;\n\ncall_frame\n&lt;p&gt;Function location.&lt;/p&gt;\n\nhit_count\n&lt;p&gt;Number of samples where this node was on top of the call stack.&lt;/p&gt;\n\nchildren\n&lt;p&gt;Child node ids.&lt;/p&gt;\n\ndeopt_reason\n&lt;p&gt;The reason of being not optimized. The function may be deoptimized or marked as don’t\noptimize.&lt;/p&gt;\n\nposition_ticks\n&lt;p&gt;An array of source position ticks.&lt;/p&gt;\n\nSynonyms:\nprotocol/profiler.ProfileNode\nprotocol/profiler ProfileNode","url":"protocol/profiler.html#ProfileNode"},{"doc":"protocol/profiler","title":"ScriptCoverage","content":"pub type ScriptCoverage {\n  ScriptCoverage(\n    script_id: runtime.ScriptId,\n    url: String,\n    functions: List(FunctionCoverage),\n  )\n}\n Coverage data for a JavaScript script.\nScriptCoverage(\n  script_id: runtime.ScriptId,\n  url: String,\n  functions: List(FunctionCoverage),\n)\n\nscript_id\n&lt;p&gt;JavaScript script id.&lt;/p&gt;\n\nurl\n&lt;p&gt;JavaScript script name or url.&lt;/p&gt;\n\nfunctions\n&lt;p&gt;Functions contained in the script that has coverage data.&lt;/p&gt;\n\nSynonyms:\nprotocol/profiler.ScriptCoverage\nprotocol/profiler ScriptCoverage","url":"protocol/profiler.html#ScriptCoverage"},{"doc":"protocol/profiler","title":"StartPreciseCoverageResponse","content":"pub type StartPreciseCoverageResponse {\n  StartPreciseCoverageResponse(timestamp: Float)\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `start_precise_coverage`\nStartPreciseCoverageResponse(timestamp: Float)\n\ntimestamp\n&lt;p&gt;Monotonically increasing time (in seconds) when the coverage update was taken in the backend.&lt;/p&gt;\n\nSynonyms:\nprotocol/profiler.StartPreciseCoverageResponse\nprotocol/profiler StartPreciseCoverageResponse","url":"protocol/profiler.html#StartPreciseCoverageResponse"},{"doc":"protocol/profiler","title":"StopResponse","content":"pub type StopResponse {\n  StopResponse(profile: Profile)\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `stop`\nStopResponse(profile: Profile)\n\nprofile\n&lt;p&gt;Recorded profile.&lt;/p&gt;\n\nSynonyms:\nprotocol/profiler.StopResponse\nprotocol/profiler StopResponse","url":"protocol/profiler.html#StopResponse"},{"doc":"protocol/profiler","title":"TakePreciseCoverageResponse","content":"pub type TakePreciseCoverageResponse {\n  TakePreciseCoverageResponse(\n    result: List(ScriptCoverage),\n    timestamp: Float,\n  )\n}\n This type is not part of the protocol spec, it has been generated dynamically\n to represent the response to the command `take_precise_coverage`\nTakePreciseCoverageResponse(\n  result: List(ScriptCoverage),\n  timestamp: Float,\n)\n\nresult\n&lt;p&gt;Coverage data for the current isolate.&lt;/p&gt;\n\ntimestamp\n&lt;p&gt;Monotonically increasing time (in seconds) when the coverage update was taken in the backend.&lt;/p&gt;\n\nSynonyms:\nprotocol/profiler.TakePreciseCoverageResponse\nprotocol/profiler TakePreciseCoverageResponse","url":"protocol/profiler.html#TakePreciseCoverageResponse"},{"doc":"protocol/profiler","title":"disable","content":"pub fn disable(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n This generated protocol command has no description\n \nSynonyms:\nprotocol/profiler.disable\nprotocol/profiler disable","url":"protocol/profiler.html#disable"},{"doc":"protocol/profiler","title":"enable","content":"pub fn enable(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n This generated protocol command has no description\n \nSynonyms:\nprotocol/profiler.enable\nprotocol/profiler enable","url":"protocol/profiler.html#enable"},{"doc":"protocol/profiler","title":"get_best_effort_coverage","content":"pub fn get_best_effort_coverage(\n  callback__: fn(String, Option(a)) -&gt;\n    Result(Dynamic, RequestError),\n) -&gt; Result(GetBestEffortCoverageResponse, RequestError)\n Collect coverage data for the current isolate. The coverage data may be incomplete due to\n garbage collection.\n  - `result` : Coverage data for the current isolate.\n \nSynonyms:\nprotocol/profiler.get_best_effort_coverage\nprotocol/profiler get_best_effort_coverage","url":"protocol/profiler.html#get_best_effort_coverage"},{"doc":"protocol/profiler","title":"set_sampling_interval","content":"pub fn set_sampling_interval(\n  callback__: fn(String, Option(Json)) -&gt; a,\n  interval interval: Int,\n) -&gt; a\n Changes CPU profiler sampling interval. Must be called before CPU profiles recording started.\n \n Parameters:  \n  - `interval` : New sampling interval in microseconds.\n \n Returns:  \n \nSynonyms:\nprotocol/profiler.set_sampling_interval\nprotocol/profiler set_sampling_interval","url":"protocol/profiler.html#set_sampling_interval"},{"doc":"protocol/profiler","title":"start","content":"pub fn start(callback__: fn(String, Option(a)) -&gt; b) -&gt; b\n This generated protocol command has no description\n \nSynonyms:\nprotocol/profiler.start\nprotocol/profiler start","url":"protocol/profiler.html#start"},{"doc":"protocol/profiler","title":"start_precise_coverage","content":"pub fn start_precise_coverage(\n  callback__: fn(String, Option(Json)) -&gt;\n    Result(Dynamic, RequestError),\n  call_count call_count: Option(Bool),\n  detailed detailed: Option(Bool),\n  allow_triggered_updates allow_triggered_updates: Option(Bool),\n) -&gt; Result(StartPreciseCoverageResponse, RequestError)\n Enable precise code coverage. Coverage data for JavaScript executed before enabling precise code\n coverage may be incomplete. Enabling prevents running optimized code and resets execution\n counters.\n \n Parameters:  \n  - `call_count` : Collect accurate call counts beyond simple &#39;covered&#39; or &#39;not covered&#39;.\n  - `detailed` : Collect block-based coverage.\n  - `allow_triggered_updates` : Allow the backend to send updates on its own initiative\n \n Returns:  \n  - `timestamp` : Monotonically increasing time (in seconds) when the coverage update was taken in the backend.\n \nSynonyms:\nprotocol/profiler.start_precise_coverage\nprotocol/profiler start_precise_coverage","url":"protocol/profiler.html#start_precise_coverage"},{"doc":"protocol/profiler","title":"stop","content":"pub fn stop(\n  callback__: fn(String, Option(a)) -&gt;\n    Result(Dynamic, RequestError),\n) -&gt; Result(StopResponse, RequestError)\n This generated protocol command has no description\n  - `profile` : Recorded profile.\n \nSynonyms:\nprotocol/profiler.stop\nprotocol/profiler stop","url":"protocol/profiler.html#stop"},{"doc":"protocol/profiler","title":"stop_precise_coverage","content":"pub fn stop_precise_coverage(\n  callback__: fn(String, Option(a)) -&gt; b,\n) -&gt; b\n Disable precise code coverage. Disabling releases unnecessary execution count records and allows\n executing optimized code.\n \nSynonyms:\nprotocol/profiler.stop_precise_coverage\nprotocol/profiler stop_precise_coverage","url":"protocol/profiler.html#stop_precise_coverage"},{"doc":"protocol/profiler","title":"take_precise_coverage","content":"pub fn take_precise_coverage(\n  callback__: fn(String, Option(a)) -&gt;\n    Result(Dynamic, RequestError),\n) -&gt; Result(TakePreciseCoverageResponse, RequestError)\n Collect coverage data for the current isolate, and resets execution counters. Precise code\n coverage needs to have started.\n  - `result` : Coverage data for the current isolate.\n  - `timestamp` : Monotonically increasing time (in seconds) when the coverage update was taken in the backend.\n \nSynonyms:\nprotocol/profiler.take_precise_coverage\nprotocol/profiler take_precise_coverage","url":"protocol/profiler.html#take_precise_coverage"},{"doc":"protocol/profiler","title":"protocol/profiler","content":" &gt; ⚙️  This module was generated from the Chrome DevTools Protocol version **1.3**\n ## Profiler Domain  \n\n This protocol domain has no description.  \n\n [📖   View this domain on the DevTools Protocol API Docs](https://chromedevtools.github.io/devtools-protocol/1-3/Profiler/)","url":"protocol/profiler.html"}]);